/*
	Re produces the results in Section 3 of 
	"Earnings Dynamics and Its Intergenerational Transmission: 
	Evidence from Norway" by Halvorsen, Ozkan, and Salgado
	May, 11, 2022
	
	This code generates the macro figures on the paper. 
	All the rest of the figures for Section 3 are generated using 
	
	7_Paper_Figs.do
	
	after the main results are generated. 
*/

// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//NEW FIGURES WITH LONG SAMPLE 
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

// Main directory
global maindir ="..."

// Where the firgures are going to be saved 
global folderfile = "..."	

// Read initialize and plotting code. Do not change myplots.do
qui: do "$maindir/doJul302020_SO/0_Initialize.do"
qui: do "$maindir${sep}doJul302020_SO${sep}myplots.do"		

// Define these variables for your dataset
global yrfirst = 1970 		// First year in the dataset 
global yrlast =  2017 		// Last year in the dataset

// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medlarge"	
	global legesize =     "large"	
	global linewidth = "thick"
	
// Mobility years
global receyears = "1975,1988,1989,1990,1993,1993,1995,2002,2003,2004,2009,2010,2015"	
	
// Where the figs are going to be saved
	capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaperLNG"
	   
// Cd to folder with out 
	cd "$maindir${sep}" // Cd to the folder containing the files

*---------------------------------------------------------------	
*FIGURE 1A
*---------------------------------------------------------------
	   
*CPI 
import excel "agg/STA_NOR/STATS_CPI.xlsx", sheet(Worksheet) cellrange(A1:N95) clear first 	
rename (A Yavg2) (year CPIA)
destring CPIA, replace force
drop if year > 2019
sort year
save "agg/STA_NOR/auxtemp.dta", replace

*GDP data
import excel "agg/STA_NOR/Norway GDP per capita.xlsx", sheet(Priser) cellrange(A4:F54) clear 	
drop D
rename A year
rename B GDP
rename C GDP_mainland
rename E GDP_PC
rename F GDP_PC_mainland
destring year, replace 
drop if year > 2019	
merge 1:1 year using "agg/STA_NOR/auxtemp.dta", keep(1 3) nogenerate keepusing(CPIA) 

gen RGDP_PC = GDP_PC*100/CPIA
gen RGDP_PC_US = RGDP_PC/8.255 	

gen RGDP_PC_mainland = GDP_PC_mainland*100/CPIA
gen RGDP_PC_mainland_US = RGDP_PC_mainland/8.255 
gen rece = inlist(year,${receyears})

replace RGDP_PC_mainland_US = RGDP_PC_mainland_US/1000
replace RGDP_PC_US = RGDP_PC_US/1000

tspltAREALimPA "RGDP_PC_US RGDP_PC_mainland_US" /// Which variables?
   "year" ///
   1970 2020 10 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
   "GDP per capita" "GDP per capita (Mainland)" ""  "" "" "" "" "" "" /// Labels 
   "1" "11" ///
   "" /// x axis title
   "Real GDP Per Capita (000s of US$)" /// y axis title 
   "" ///  Plot title
   "" ///
   "1A_RWAGE_MAINLAND_US"	/// Figure name
   "" "" ""				/// ylimits
   "" 				/// If legend is active or nor	
   "blue red blue blue maroon forest_green purple gray orange"			/// Colors
   "O S D" "" "" "" "solid solid solid" 
   

*---------------------------------------------------------------	
*FIGURE 1B
*---------------------------------------------------------------	

import excel "agg/STA_NOR/STA_RWAGE.xlsx", sheet(Arslonn) cellrange(A3:G54) clear first 	
rename A year
destring year, force replace
drop if year > 2019	
merge 1:1 year using "agg/STA_NOR/auxtemp.dta", keep(1 3) nogenerate keepusing(CPIA)
gen rece = inlist(year,${receyears})
gen RWAGE = AnnualearningsNOK1000*100/CPIA
gen RWAGE_US = RWAGE/8.255 						// Transforms to US dollars 

tspltAREALimPA "RWAGE_US" /// Which variables?
"year" ///
1970 2020 10 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
"" "" ""  "" "" "" "" "" "" /// Labels 
"1" "5" ///
"" /// x axis title
"Real Average Wage (000s of US$)" /// y axis title 
"" ///  Plot title
"" ///
"1B_RWAGE_US"	/// Figure name
"20" "70" "10"				/// ylimits
"off" 						/// If legend is active or nor	
"blue red blue blue maroon forest_green purple gray orange"			/// Colors
"O S D" "" "" "" "solid solid solid" 	 


*---------------------------------------------------------------	
*FIGURE 1C
*---------------------------------------------------------------	
import excel "agg/STA_NOR/STATS_PRIMEAGE.xlsx", sheet(Prosent) cellrange(A3:I153) clear first 
rename (A B C) (gender age year)
replace gender = gender[_n-1] if gender == ""
replace age = age[_n-1] if gender == ""
destring year Personstotal Labourforcetotal Employedpersons Unemployed Personsoutsideofthelabourfo, force replace
drop if year == .
drop D age
rename (Personstotal Labourforcetotal Employedpersons Unemployed Personsoutsideofthelabourfo) ///
	(Pop LF EMP UNEMP OLF)
replace gender = "All" if gender == "Both sexes"
reshape wide Pop LF EMP UNEMP OLF, i(year) j(gender) string

*Ploting
gen rece = inlist(year,${receyears})
drop if year > 2019	


tspltAREALimPA "EMPAll EMPFemales EMPMales" /// Which variables?
"year" ///
1970 2020 10 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
"All" "Women" "Men"  "" "" "" "" "" "" /// Labels 
"1" "5" ///
"" /// x axis title
"Employment Rate (%)" /// y axis title 
"" ///  Plot title
"" ///
"1C_EMPRATE_DATA"	/// Figure name
"50" "100" "10"				/// ylimits
"" 						/// If legend is active or nor	
"black red blue blue maroon forest_green purple gray orange"			/// Colors
"O S D" "" "" "" "solid solid solid" 	  

*---------------------------------------------------------------	
*FIGURE 1D
*---------------------------------------------------------------	

tspltAREALimPA "UNEMPAll UNEMPFemales UNEMPMales" /// Which variables?
"year" ///
1970 2020 10 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
"All" "Women" "Men"  "" "" "" "" "" "" /// Labels 
"1" "11" ///
"" /// x axis title
"Unenployment Rate (%)" /// y axis title 
"" ///  Plot title
"" ///
"1D_UNEMP_DATA"	/// Figure name
"0" "6" "2"				/// ylimits
"" 						/// If legend is active or nor	
"black red blue blue maroon forest_green purple gray orange"			/// Colors
"O S D" "" "" "" "solid solid solid"   

