////////////////////////////////////////////////////////////////////////////////
// Requires access to the following administrative registers (in Norwegian):
// Inntekt, FD-trygd (for sykepenger & foreldrepenger 1993-2005), Utdanning & Befolkning 
////////////////////////////////////////////////////////////////////////////////

// Variables from Inntekt: lonn, wlonn, kjonn, lopenr_person, aar
// Variables from FD-trygd: sykepenger (F_SP), foreldrepenger (F_FP), lopenr_person, aar
// Variables from Utdanning: bu, lopenr_person, aar
// Variables from Befolkning: foedselsaar, doedsaar, lopenr_person, aar

clear
set more off

cd /path/data  /*specify path for data*/

**************************************************************************************

u lonn wlonn kjonn lopenr_person aar using "/path/data/inntekt.dta",clear
save temp_income,replace

u sykepenger foreldrepenger lopenr_person aar using "/path/data/FDtrygd.dta",clear
save temp_benefits,replace

u bu lopenr_person using "/path/data/utdanning.dta",clear
save temp_educ,replace

u foedselsaar doedsaar lopenr_person using "/path/data/befolkning.dta",clear
save temp_person,replace

**************************************************************************************

u temp_income, clear
merge lopenr_person using temp_person
drop if _merge==2
drop _merge

merge lopenr_person using temp_educ
drop if _merge==2
drop _merge

merge lopenr_person aar using temp_benefits
drop if _merge==2
drop _merge

replace sykepenger = 0 if sykepenger == .
replace foreldrepenger = 0 if foreldrepenger == .
replace lonn = wlonn - sykepenger - foreldrepenger if aar < 2006

gen male = (kjonn == 1)

gen utd = substr(bu,1,1)
gen utdnivaa = 0
replace utdnivaa = 1 if utd == "1" | utd == "2" 
replace utdnivaa = 2 if utd == "3" | utd == "4" | utd == "5"
replace utdnivaa = 3 if utd == "6" | utd == "7" | utd == "8"

drop wlonn sykepenger foreldrepenger kjonn utd ub

save regdata1993_2017.dta 

// Define the variable names in your dataset.
global personid_var="lopenr_person" 	// The variable name for person identity number.
global male_var="male" 					// The variable name for gender: 1 if male, 0 o/w.
global yob_var="foedselsaar" 	   		// The variable name for year of birth.
global yod_var="doedsaar" 				// The variable name for year of death.
global educ_var="utdnivaa" 				// The variable name for educational level.
global labor_var="lonn"     			// The variable name for total annual labor earnings from all jobs during the year.  
global year_var="aar" 					// The variable name for year if the data is in long format
