// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the sample with father's lifetime income percentile
// First version Jan 11, 2020
// This  version Oct 08, 2021
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

// PLEASE MAKE THE APPROPRIATE CHANGES BELOW. 
// You should change the below directory. 

global sep="/"

//Please change the below to the name of the actual data set (bys year: gen immigrant = _n <=  2.5*_N/100)
global datafile="$maindir${sep}dta${sep}father_son_long.dta" 


global yrfirst = 1967 		// First year in the dataset (Here it is 1967)
global yrlast = 2017 		// Last year in the dataset. (Here it is 2017)
global begin_age = 25 		// Begin age for income
global end_age = 60			// End age of income 
global end_age_wlt = 80		// End age for wealth---Age is winsorized at 85

global base_price = 2018	// The base year nominal values are converted to real. 
global winsor=99.999999		// The values above this percentile are going to be set to this percentile. 
global noise=0.00001	    // Adding white noise
global father_min_obs_wlth=3 // father has to be in our sample at least father_min_obs years
global father_min_obs_pos=5 // father has to have positive income at least father_min_obs_pos 


// Define the variable names in your dataset.
global personid_var="idnr" 	// The variable name for person identity number.
global father_id="father_id" 	// The variable name for father identity number.
global yob_var="b_year" 	// The variable name for year of birth.
global yod_var="yod" 		// The variable name for year of death.
global inc_var="wage_inc" // The variable name for total annual labor earnings from all jobs during the year.  
global year_var="year" 		// The variable name for year if the data is in long format
global male_var="male" 		// The variable name for gender: 1 if male, 0 o/w.

global wealth_var = "wealth"
global cap_inc_var = "cap_inc"

global immigrant = "immigrant"
global public = "public"
global edu_var = "educ"

// If there are missing observations for earnings between $begin_age and $end_age
// set the below global to 1. Otherwise, the code will convert all missing earnings
// observations to zero.
global miss_earn=1 

// Define utility globals
global kyear = 5
	// This controls the years for which the empirical densities will be calculated.
	// The densisity is calculated every mod(year/kyear) == 0. Set to 1 if 
	// every year is needed (If need changes, contact  Ozkan/Salgado)
	
global nquantiles = 40
	// Number of quantiles used in the statistics conditioning on permanent income
	// One additional quintile will be added at the top for a total of 41 (see Guidelines)
		
global nquantilesalt = 40
	// Number of quantiles used in the statistics conditioning on the alternative measure of permanent income
	
global nquantilestran = 10 
	// Number of quantiles used in the age transition matrix
	
global qpercent = 99	
	// Top percentile for which the change in top-share will be calculated. 
	// In this case 99 implies top 1%. 
	// Calculations are made using  Matthieu Gomez's paper
	
global mergecohort = 2
	// Number of cohorts to be merged to prevent too few observations in year/age cells 
	
global hetgroup = `" male age educ "male age" "male educ" "male educ age" "' 
	// Define heterogenous groups for which time series stats will be calculated 



global cpi2018 = 110.007		// Set the value of the CPI in 2018. 
matrix cpimat = /*  CPI between ${yrfirst}  and ${yrlast}
*/ (20.951, 21.841, 22.586, /*
*/ 20.951, 21.841, 22.586, 23.802, 26.280, 28.470, 30.032, 31.986, 34.211, 37.250,  /*
*/ 41.262, 44.959, 47.456, 49.475, 51.343, 53.134, 54.290, 55.964, 58.150, 60.690,  /*
*/ 63.355, 65.473, 67.218, 68.892, 70.330, 71.811, 73.346, 74.623, 75.216, 76.338, /*
*/ 78.235, 79.738, 80.789, 82.358, 84.411, 86.813, 89.174, 91.438, 94.180, 94.094,  /*
*/ 95.705, 98.130, 100.000, 101.347, 102.868, 103.126, 104.235, 106.073 )'

matrix cpimat = cpimat/${cpi2018}


matrix exrate = /*  Nominal average exchange rate from FRED between ${yrfirst}  and ${yrlast} (LC per dollar)
*/ (7.0222, 6.5875, 5.7535,5.5255,   /* SO: I couldn't find these numbers from FRED
*/  7.0222,6.5875, 5.7535,5.5255,5.2283,5.4590,5.3240,5.2467,5.0651,4.9382, /*
*/	5.7431,6.4568,7.3013,8.1597,8.5934,7.3985,6.7409,6.5243, /* 
*/  6.9131,6.2621,6.4912,6.2142, /*
*/  7.101,7.055,6.335,6.459,7.086,7.552,7.807,8.813,8.996,7.984, /*
*/	7.080,6.740,6.441,6.409,5.856,5.637,6.291,6.045,5.602,5.818, /*
*/	5.877,6.297,8.0681,8.3936,8.2679)'


// Define years for recession bars/ These will be used to generate a variable called rece used in the plots
global receyears = "1993,1995,2002,2003,2004,2009,2010,2015"

// Define the year that will be use for normalization. 
global normyear = ${yrfirst}


/*DO NOT CHANGE THIS SECTION**********************************************
THIS SECTION DEFINES THE REAL EXCHANGE CHANGE USING THE LOCAL AND US CPI
*/
global cpi2018us = 108.231		// DO NOT CHANGE. This is the US PCE  
								// Annual average from https://fred.stlouisfed.org/series/PCEPI#0
matrix cpimatus = /*  PCE between 1965  and 2018
*/ ( 17.536, 17.979, 18.431, 19.153, 20.015, /*
*/ 20.951, 21.841, 22.586, 23.802, 26.280, 28.470, 30.032, 31.986, 34.211, 37.250,  /*
*/ 41.262, 44.959, 47.456, 49.475, 51.343, 53.134, 54.290, 55.964, 58.150, 60.690,  /*
*/ 63.355, 65.473, 67.218, 68.892, 70.330, 71.811, 73.346, 74.623, 75.216, 76.338, /*
*/ 78.235, 79.738, 80.789, 82.358, 84.411, 86.813, 89.174, 91.438, 94.180, 94.094,  /*
*/ 95.705, 98.130, 100.000, 101.347, 102.868, 103.126, 104.235, 106.073, 108.231 )'

matrix cpimatus = cpimatus/${cpi2018us}

forvalues yr =  $yrfirst/$yrlast{
	local ee = `yr' - ${yrfirst} + 1
	local ii = `yr' - 1965 + 1
	matrix exrate[`ee',1] = exrate[`ee',1]*(cpimatus[`ii',1]/cpimat[`ee',1])
			// Coverting nominal exchange rate to real exchange rate
}

// CREATING MINIMUM INCOME THRESHOLD USING US MINIMUM WAGE  
// We need to change to this to Norway !!!

matrix minwgus = /* Nominal minimum wage 1959-2018 in the US
*/ (1.00,1.00,1.00,1.15,1.15,1.25,1.25,1.25,1.25,1.40,1.60,1.60,1.60,1.60,/*
*/  1.60,1.60,2.00,2.10,2.10,2.30,2.65,2.90,3.10,3.35,3.35,3.35,3.35,3.35,/*
*/  3.35,3.35,3.35,3.35,3.80,4.25,4.25,4.25,4.25,4.25,4.75,5.15,5.15,5.15,/*
*/  5.15,5.15,5.15,5.15,5.15,5.15,5.15,5.85,6.55,7.25,7.25,7.25,7.25,7.25,/*
*/  7.25,7.25,7.25)'

local yinic = ${yrfirst} - 1959 + 1						
local yend = ${yrlast} - 1959 + 1

matrix minincus = 260*minwgus[`yinic'..`yend',1]		// Nominal min income in the US
														// This uses the factor of 260 given in the Guidelines
matrix rmininc = J(${yrlast}-${yrfirst}+1,1,0)
local tnum = ${yrlast}-${yrfirst}+1

forvalues i = 1(1)`tnum'{
	local ii = `i' + ${yrfirst} - 1965
	matrix rmininc[`i',1] = minincus[`i',1]*exrate[`i',1]/cpimatus[`ii',1]				
					// real min income threshold in local currency 
}

// PLEASE DO NOT CHANGE THIS PART. IF NEEDS TO BE CHANGED, CONTACT Ozkan/Salgado

*global yrlist = ///
*	"${yrfirst} 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 ${yrlast}"
*	// Define the years for which the inequality and concetration measures are calculated

global  yrlist = ""
forvalues yr = $yrfirst(1)$yrlast{
	global yrlist = "${yrlist} `yr'"
}		
	
*global d1yrlist = ///
*	"1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012"
	// Define years for which one-year log-changes measures are calculated

global d1yrlist = ""
local tempyr = $yrlast-1
forvalues yr = $yrfirst(1)`tempyr'{
	global d1yrlist = "${d1yrlist} `yr'"
}
	
*global d5yrlist = ///
*	"1993,1994,1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008"
	// Define years t for which five-years log-changes between t+5 and t are calculated
	
global d5yrlist = "$yrfirst"
local tempyrb = $yrfirst+1
local tempyr = $yrlast-5
forvalues yr = `tempyrb'(1)`tempyr'{
	local tmp = ",`yr'"
	global d5yrlist = "${d5yrlist}`tmp'"
}	
	
*global perm3yrlist = /// 
*	"1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,${yrlast}"
	// Define the ending years (t) to construct permanent income between t-2 and t 
	
local tempyrb = $yrfirst+2	
global perm3yrlist = "`tempyrb'"
local tempyrb = $yrfirst+3	
local tempyre = $yrlast
forvalues yr = `tempyrb'(1)`tempyre'{
	local tmp = ",`yr'"
	global perm3yrlist = "${perm3yrlist}`tmp'"
}	

// END OF DO-FILE
//////////////////////////////////////////////
