// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the sample with father's lifetime income percentile
// First version Jan  11, 2020
// This  version Oct  20, 2021
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
clear all
set more off 


global maindir ="..."
do "$maindir/do/0_Initialize_minage25.do"

global logname=c(current_date)
global logname="$logname FatherSample"
capture log close
capture noisily log using "$maindir${sep}log${sep}$logname.log", replace
global lsample = "no"		// Turn yes to run the creation of growth rates and such.

cd "$maindir${sep}dta${sep}"

use $personid_var $year_var $father_id $yob_var $yod_var $male_var ${edu_var} ${inc_var} ${wealth_var} ///
if ${year_var} >= ${yrfirst} & ${year_var} <= ${yrlast} using ${datafile} , clear

describe
tab ${year_var}

/*
	CREATE EDUCATION VARIABLES: we can erase this later
	sort  idnr year
	bys idnr: keep if _n==1
	gen educ = . 
	gen u1 = runiform()*(49 - 21) + 21
	gen u2 = round(u1)
	gen u3 = runiform()
	replace u2 = 9 if u3 < 0.01
	replace u2 = 1 if u3 >= 0.1 & u3 <= 0.15
	replace u2 = 2 if u3 >= 0.15 & u3 <= 0.25
	replace educ = u2
	keep idnr educ
	save tempo.dta, replace
	merge m:1 idnr using tempo.dta, nogenerate
*/

/*  The default STATA reshape commend is slow! 
timer clear 1
timer on 1
sort $personid_var $year_var
reshape wide $labor_var, i($personid_var) j($year_var)
timer off 1
timer list 1
*/

/*USE EDUCATION VARIABLES: WE KEEP THE MAX EDUCATIONAL ATTAINTMENT*/



// The below part reshapes data in long format to wide. Faster than RESHAPE commend. 
sort $personid_var $year_var
forvalues yr = $yrfirst/$yrlast{
	preserve
	keep if $year_var ==`yr'
	
	rename $inc_var $inc_var`yr'
	rename $wealth_var $wealth_var`yr'	
	rename $edu_var educ`yr'	
	
	keep $personid_var $inc_var`yr' $wealth_var`yr' $father_id $yob_var $yod_var ${male_var} educ`yr'	
		// Need to keep all variable. If only keep for first year, we 
		// miss the data for observations that enter in the sample after 
		// the first year. 
	
	sort $personid_var
	save "temp`yr'.dta",replace
	restore
}
	
local first=$yrfirst+1
use "temp$yrfirst.dta", clear
erase temp${yrfirst}.dta
forvalues yr=`first'/$yrlast{
	merge 1:1 $personid_var using "temp`yr'.dta", nogen update replace
			// update replace makes sure the variables such as year of birth 
			// are replaced by noin missing values for observations that enter 
			// in the sample after the first year. 
	erase temp`yr'.dta
	sort $personid_var
}

order $personid_var $yob_var $yod_var ${male_var} $father_id ${inc_var}* ${wealth_var}*  educ*


rename ${personid_var} personid
rename ${yob_var} yob
rename ${yod_var} yod
rename ${male_var} male
rename ${father_id} father_id

// Drop anybody who is too old or too young or too dead. 
// Criteria 1 (Age) in CS Sample
drop if yob==.
drop if $yrlast-yob+1<$begin_age // We don't drop anybody because s/he is too old. This is b/c we want to keep the data of wealth for old individuals 
								// for the rest of the intergenerational analysis.								
drop if yod<=$yrfirst & yod~=.
// describe

/* Adjust Education variable*/
gen educ = .
forvalues yr = $yrlast(-1)$yrfirst{			
	*Replace for max attaintment
	replace educ = educ`yr' if educ == . & educ`yr' != . 	
	drop educ`yr'
}

global base_price_index = ${base_price}-${yrfirst}+1	// The base year nominal values are converted to real. 
foreach varx in inc_var wealth_var{

	forvalues yr = $yrfirst/$yrlast{	
			
		if "`varx'" == "inc_var"{
			local vary = "labor"			// Notice we call it labor, but the variable here is more than labor income
											// we keep the name labor to make it consistent across file
		}			
		if "`varx'" == "wealth_var"{
			local vary = "wealth"
		}			
		
		rename ${`varx'}`yr' `vary'`yr'
		
		label var `vary'`yr' "Real `vary' in `yr'"

		// Covert to real values
		// Criteria d (Inflation) in CS Sample
		
		local cpi_index = `yr'-${yrfirst}+1
		replace `vary'`yr'=`vary'`yr'/cpimat[`cpi_index',1]		//Coverting to real values
		
		// Winsorization
		gen temp=`vary'`yr' if `yr'-yob+1>= $begin_age & `yr'- yob+1<= $end_age & `yr'< yod  // yod=. id very big number  
		_pctile temp, p($winsor)
		replace `vary'`yr'= r(r1) if `vary'`yr'>=r(r1) & `vary'`yr'!=. 
		drop temp
			
		// Add a small noise
		gen temp=${noise}*(uniform()-0.5)
		replace `vary'`yr'=`vary'`yr'+`vary'`yr'*temp 
		drop temp

		if(${miss_earn}==0){
		// Any earnings that are missing inside of $begin_age and $end_age are set to zero.
		replace `vary'`yr'= 0 if `vary'`yr'== . &  ///
		   `yr'-yob+1 >= $begin_age & `yr'- yob+1<=$end_age & `yr'< yod
		}
			
		// Assing missing if outside of $begin_age and $end_age
		if "`vary'" == "wealth"{
			replace `vary'`yr'= . if `yr'-yob+1 < $begin_age // do not miss obs because old
			replace `vary'`yr'= . if `yr'>= yod & yod~=.  // (yod=. is very big number)
		}
		else {
			replace `vary'`yr'= . if `yr'-yob+1 < $begin_age | `yr'- yob+1>$end_age 
			replace `vary'`yr'= . if `yr'>= yod & yod~=.  // (yod=. is very big number)
		}
	}
}	// END loop over var ex

// Base sample creation completed.
order personid yob yod male father_id educ labor* wealth* 
	compress	
	// Comment this section later			
// 		replace labor2015 = labor2014 
// 		replace labor2016 = labor2013 
// 		replace labor2017 = labor2012
save "$maindir${sep}dta${sep}fatherson_wide.dta", replace

// Creating normalized income
cd "$maindir${sep}dta${sep}"
foreach varx in wealth labor {	
	// Suffix and year
	if "`varx'" == "labor"{
		local sfx = "inc"
		local ymin = "$yrfirst"		
	}
	else if "`varx'" == "wealth"{
		local sfx = "wlt"
		local ymin = 1993
	}	
	
	forvalues yr = `ymin'/$yrlast{	
		use personid male yob yod educ `varx'`yr' using ///
		"$maindir${sep}dta${sep}fatherson_wide.dta" if `varx'`yr'~=. , clear   

		// Create year
		gen year=`yr'
		
		// Create age 
		gen age = `yr'-yob+1
		if "`varx'" == "wealth"{
			drop if age<${begin_age} // We don't drop anybody too old 
			replace age = $end_age_wlt if age > $end_age_wlt // Winsoriza age at $end_age_wlt
		}
		else{
			drop if age<${begin_age} | age>${end_age}
		}
		
		bys male age: egen avg=mean(`varx'`yr')
		
		gen res`sfx'`yr' = `varx'`yr'/avg 
		drop if res`sfx'`yr'==.
		
		if "`varx'" == "wealth"{
			keep personid yob yod res`sfx'`yr'
		}
		else{
			keep personid educ `varx'`yr' res`sfx'`yr'
		}

		// Save data set for later append
		sort personid		
		label var res`sfx'`yr' "Residualized `varx' of year `yr'"
		save "res`sfx'`yr'.dta", replace
	}

	forvalues yr = `ymin'/$yrlast{
		if (`yr' == $yrfirst){
			use res`sfx'`yr'.dta, clear
			erase res`sfx'`yr'.dta
		}
		else{
			merge 1:1 personid using res`sfx'`yr'.dta, nogen
			erase res`sfx'`yr'.dta
		}
		sort personid
	}


// END: Residuals calculation complete. Calculate average lifetime value

	// Suffix and year
	if "`varx'" == "labor"{		
		// Compute lifetime income residualized variables for all years available
		gen LT`sfx'=0
		gen numobs`varx'=0
		gen numobs_pos`varx'=0
		forvalues yr = `ymin'/$yrlast{	
			replace LT`sfx' = LT`sfx' + res`sfx'`yr' if res`sfx'`yr'~=.
			replace numobs`varx' = numobs`varx' + 1 if res`sfx'`yr'~=.
			replace numobs_pos`varx' = numobs_pos`varx' + 1 if res`sfx'`yr'~=. & ///
						`varx'`yr'>=rmininc[`yr'-${yrfirst}+1,1] 
		}
		replace LT`sfx' = . if numobs_pos`varx' < $father_min_obs_pos
		replace LT`sfx' = LT`sfx'/numobs`varx'

	}
	else if "`varx'" == "wealth"{
		// Compute average values using 55/65 (or closest ages) data for wealth	
		gen LT`sfx'=0
		gen numobs`varx'=0
		gen age = .
		gen ageidx = .
		
		gen agefst =  `ymin' - yob + 1		// SS: does it matter that this variable is negative some times?
											
		gen agelst = min($yrlast - yob + 1,yod - yob + 1)
											// SS: and this is less that 25 some times?
		
		// Choosing ages closest to 55/65 
		gen ageL = max(min(max(agefst,55),agelst-10),${begin_age})
		gen ageU = min(ageL + 10,${end_age_wlt})
					
		forvalues yr = `ymin'/$yrlast{	
			replace age = `yr'-yob+1
			replace ageidx = 0
			replace ageidx = 1 if (age>= ageL & age <= ageU) 
									// Probably the second conditioning takes care of the previous
									// and we need only this?
			replace LT`sfx' = LT`sfx' + res`sfx'`yr'*ageidx if res`sfx'`yr'~=.
			replace numobs`varx' = numobs`varx' + ageidx if res`sfx'`yr'~=.
		}
		replace LT`sfx' = . if numobs`varx' < $father_min_obs_wlth
		replace LT`sfx' = LT`sfx'/numobs`varx'
		drop age ageidx agefst agelst ageL ageU
		
	}		
	save "res`sfx'.dta", replace 
	
}	// END loop over variables


// Save data from fathers
foreach sfx in inc wlt{
	use "res`sfx'.dta", clear
	if "`sfx'" == "inc"{
		keep personid LT`sfx' educ numobslabor numobs_poslabor
		rename (personid LT`sfx' numobslabor numobs_poslabor educ) (father_id LT`sfx'_f numobslabor_f numobs_poslabor_f educ_f)
	}	
	else{
		keep personid LT`sfx'
		rename (personid LT`sfx') (father_id LT`sfx'_f)
	}	
	
	tempfile fathers_`sfx'
	save  "`fathers_`sfx''"
}

use "$maindir${sep}dta${sep}fatherson_wide.dta", clear
foreach sfx in inc wlt{
	merge m:1 father_id using "`fathers_`sfx''", keep(master match) nogen
}
save "$maindir${sep}dta${sep}fatherson_wide.dta", replace

// Merge all data sets to a master code
use "$maindir${sep}dta${sep}fatherson_wide.dta", clear 
foreach sfx in inc wlt {
	merge 1:1 personid using "res`sfx'.dta", nogen 		
	erase "res`sfx'.dta"
}

drop if $yrlast-yob+1<$begin_age // Now we can drop if s/he is too old. 
compress

order  personid male yob yod father_id  labor* wealth*  resinc* reswlt* ///
	LTinc_f LTwlt_f LTinc LTwlt educ educ_f numobs*

save "$maindir${sep}dta${sep}fatherson_wide.dta", replace 


if "${lsample}" == "yes"{
	//FROM HERE, IT COMES COMES FROM 1_GEN_BASE_SAMPLE.do
	// Creating residuals of log-earnings and saving the coefficients

	forvalues yr = $yrfirst/$yrlast{	
	// 	local yr = 2015		// to debug
		use personid male educ yob labor`yr' using ///
		"$maindir${sep}dta${sep}fatherson_wide.dta" if labor`yr'~=. , clear   

		// 
		rename labor`yr' labor`yr'
		
		// Create year
		gen year=`yr'
		
		// Create age 
		gen age = `yr'-yob+1
		drop if age<${begin_age} | age>${end_age}
		
		// Create log earn if earnings above the min treshold
		// Criteria c (Trimming) in CS Sample
		// Notice we do not drop the observations but log-earnings are generated for those with
		// income below 1/3*min threshold. Variable logearn`yr'c is used for growth rates conditional
		// on permanent income only
		
		gen logearn`yr' = log(labor`yr') if labor`yr'>=rmininc[`yr'-${yrfirst}+1,1] & labor`yr'!=. 
		gen logearnc`yr' = log(labor`yr') if labor`yr'>=(1/3)*rmininc[`yr'-${yrfirst}+1,1] & labor`yr'!=. 
		
		
		// Create dummies for age and education groups
		tab age, gen(agedum)
		drop agedum1
		tab educ, gen(educdum)
		drop educdum1

		// Regression for residuals earnigs
		statsby _b,  by(year) saving(age_yr`yr'_m,replace):  ///
		regress logearn`yr' agedum* if male==1
		
		predict temp_m if e(sample)==1, resid
		
		statsby _b,  by(year) saving(age_yr`yr'_f,replace):  ///
		regress logearn`yr' agedum* if male==0
		
		predict temp_f if e(sample)==1, resid
		
		// Regressions for residuals earnings with income above 1/3*minincome
		regress logearnc`yr' agedum* if male==1
		predict temp_m_c if e(sample)==1, resid
		
		regress logearnc`yr' agedum* if male==0
		predict temp_f_c if e(sample)==1, resid
		
		// Regressions for profiles
		statsby _b,  by(year) saving(age_educ_yr`yr'_m,replace):  ///
		regress logearn`yr' educdum* agedum* if male==1
		
		statsby _b,  by(year) saving(age_educ_yr`yr'_f,replace):  ///
		regress logearn`yr' educdum* agedum* if male==0
			
		// Generate the residuals by year and save a database for later append.
		gen researn`yr'= temp_m
		replace researn`yr'= temp_f if male==0
		
		gen researnc`yr'= temp_m_c
		replace researnc`yr'= temp_f_c if male==0 
		

		keep personid researn`yr' researnc`yr' logearn`yr' logearnc`yr' labor`yr' male age
		sort personid
		
		// Save data set for later append
		label var researn`yr' "Residual of real log-labor earnings of year `yr'"
		label var logearn`yr' "Real log-labor earnings of year `yr' above min threshold"
		label var researnc`yr' "Residual of real log-labor earnings of year `yr' above 1/3*min threshold"
		label var logearnc`yr' "Real log-labor earnings of year `yr' above 1/3*min threshold"
		save "researn`yr'.dta", replace
	}

	forvalues yr = $yrfirst/$yrlast{
		if (`yr' == $yrfirst){
			use researn`yr'.dta, clear
			erase researn`yr'.dta
		}
		else{
			merge 1:1 personid using researn`yr'.dta, nogen
			erase researn`yr'.dta
		}
		sort personid
	}
	save "researn.dta", replace 
	// END: Residuals calculation complete


	// Appending coefficients of agen and education for gender groups 
	clear
	forvalues yr = $yrfirst/$yrlast{
		append using age_educ_yr`yr'_m.dta
		cap: gen male = 1 
		cap: replace male = 1 if male == . 
		erase age_educ_yr`yr'_m.dta
		append using age_educ_yr`yr'_f.dta
		cap: replace male = 0 if male == . 
		erase age_educ_yr`yr'_f.dta	
	}
	order year male 
	save "age_educ_dums.dta", replace 

	// Appending coefficients of age for gender groups 
	clear
	forvalues yr = $yrfirst/$yrlast{
		append using age_yr`yr'_m.dta
		cap: gen male = 1 
		cap: replace male = 1 if male == .
		erase age_yr`yr'_m.dta
		append using age_yr`yr'_f.dta
		cap: replace male = 0 if male == . 
		erase age_yr`yr'_f.dta	
	}
	order year male 
	save "age_dums.dta", replace 
	// END: coefficients appending complete

	// Calculate growth of (residual) earnings (Section 2.e and 2.f)
	clear
	foreach k in 1 5{

		// Given the jump k, calculate the growth rate for each worker in each year

		local lastyr=$yrlast-`k'
		forvalues yr = $yrfirst/`lastyr'{
		
			local yrnext=`yr'+`k'

			use personid male age researn`yr' researn`yrnext' researnc`yrnext' labor`yrnext' labor`yr' using "researn.dta", clear
			
			bys male age: egen avelabor`yrnext' = mean(labor`yrnext')
			bys male age: egen avelabor`yr' = mean(labor`yr')
			
			gen researn`k'F`yr'= researnc`yrnext'-researn`yr'		// Growth with earninbgs above mininc in t and 1/3*mininc in t+k
			gen arcearn`k'F`yr'= (labor`yrnext'/avelabor`yrnext' - labor`yr'/avelabor`yr')/(0.5*(labor`yrnext'/avelabor`yrnext' + labor`yr'/avelabor`yr'))
			
			label var researn`k'F`yr'  "Residual earnings growth between `yrnext' and `yr'"
			label var arcearn`k'F`yr'  "Arc-percent earnings growth between `yrnext' and `yr'"

			keep personid researn`k'F`yr' arcearn`k'F`yr'
			save researn`k'F`yr'.dta, replace
			
		}
		
		// Merge data across all years
		forvalues yr = $yrfirst/`lastyr'{
		
			if (`yr' == $yrfirst){
			use researn`k'F`yr'.dta, clear
			erase researn`k'F`yr'.dta
			}
			else{
				merge 1:1 personid using researn`k'F`yr'.dta, nogen
				erase researn`k'F`yr'.dta
			}
			sort personid
		}
		
		compress 
		save "researn`k'F.dta", replace 
		
	}
	// END calculate growth rates


	// Calculate permanent income
	clear
	local firstyr=$yrfirst+2
	forvalues yr = `firstyr'/$yrlast{
		local yrL1=`yr'-1
		local yrL2=`yr'-2	

		use personid male yob educ labor`yrL2' labor`yrL1' labor`yr' using ///
		"$maindir${sep}dta${sep}fatherson_wide.dta" if labor`yr'~=. , clear  
		
		// Create year
		gen year=`yr'
		
		// Create age 
		gen age = `yr'-yob+1
		drop if age<${begin_age} | age>${end_age}
		
		// Create average income for those with at least 2 years of income above 
		// the treshold income between t-1 and t-3
		gen totearn=0
		gen numobs=0
		
		*replace numobs = -5 if labor`yr' < rmininc[`yr'-${yrfirst}+1,1]
		// This ensures that permanent income is only constructed for those 
		// with income above the threshold in t-1
			
		
		forvalues yrp=`yrL2'/`yr'{
			replace totearn=totearn+labor`yrp' if labor`yrp'~=.
			replace numobs=numobs+1 if labor`yrp'>=rmininc[`yrp'-${yrfirst}+1,1] & labor`yrp'~=.		
			// Notice earnings below the min threshold are still used to get totearn
		}
			
		replace totearn=totearn/numobs if numobs>=2			// Average income
		drop	if numobs<2									// Drop if less than 2 obs
		
		// Create log earn
		replace totearn = log(totearn) 
		drop if totearn==.
		
		// Gen dummies for regressions
		tab age, gen(agedum)
		drop agedum1
		
		// Regression to get residuals permanent income
		regress totearn agedum* if male==1
		predict temp_m if e(sample)==1, resid
		
		qui regress totearn agedum* if male==0
		predict temp_f if e(sample)==1, resid
		
		gen permearn`yr'= temp_m
		replace permearn`yr'= temp_f if male==0

		// Save 
		keep personid permearn`yr'
		label var permearn`yr' "Residual permanent income between `yr' and `yrL2'"
		
		compress 
		sort personid
		save "permearn`yr'.dta", replace
		
	}

	clear
	local firstyr=$yrfirst+2
	forvalues yr = `firstyr'/$yrlast{

		if (`yr' == `firstyr'){
			use permearn`yr'.dta, clear
			erase permearn`yr'.dta
		}
		else{
			merge 1:1 personid using permearn`yr'.dta, nogen
			erase permearn`yr'.dta
		}
		sort personid
	}
	save "permearn.dta", replace 
}	// END of long sample moments

// Merge all data sets to a master code
use personid yob yod male father_id labor* wealth* resinc* reswlt* ///
	LTinc_f LTwlt_f educ_f LTinc LTwlt educ numobs* using ///
	"$maindir${sep}dta${sep}fatherson_wide.dta",  clear 
merge 1:1 personid using "permearn.dta", nogen 			
merge 1:1 personid using "researn.dta", nogen 
merge 1:1 personid using "researn1F.dta", nogen 
merge 1:1 personid using "researn5F.dta", nogen 
compress
order  personid male yob yod  labor* wealth* resinc* reswlt* ///
	LTinc_f LTwlt_f LTinc LTwlt logearn* permearn* researn* 
save "$maindir${sep}dta${sep}master_sample_fs.dta", replace 

capture log close

// END OF DO-FILE
//////////////////////////////////////////////
