/*RUNNING INDIVIDUALS LEVEL REGRESSION
	First version Nov 05, 2020
	This  version Dec 04, 2021
*/

global maindir =".."
do "$maindir/do/0_Initialize_minage23.do"

capture log close
capture noisily log using "$outfolder.log", replace
do "$maindir${sep}do${sep}myprogs.do"
global varoi="perminc"

global minnumyearLAB = 10 		// Min number of years for the transition matrix
global minnumyear = 20			// Keep those with at least xx years of data
global nqtiles = 100			// Binscatters
global nquantilestran = 10		// Ranks

global publicupdate = "no"
global run3yrs = "no"	// Turn yes to re run the bin scatter with 3 years
global runregs = "no"	// Turn yes to re run the individual regressions
global runols = "no"	// Tunr yes to run the OLS regressions
global runbinscat = "no"	// Turn yes to run binscatters
global runlongols = "no"	// Turn yes to run old regs and binscatters
global runshortols = "yes" // Run binscatter regressiosn

global outfolder=c(current_date)
global outfolder="$outfolder IndReg_EDUCMORE_DEC04_${minnumyear}"
capture noisily mkdir "$maindir${sep}out${sep}$outfolder"
cd "$maindir${sep}out${sep}$outfolder"

//---------------------------------------------------------------------------------------
// Update data for public vs. private groups
//---------------------------------------------------------------------------------------

if "${publicupdate}"=="yes"{
	/* Adjust Education variable: we keep the last education value that is not missing*/	
	forvalues yr = $yrfirst/$yrlast{	
		*Keep public
		use $personid_var year $public_var if year == `yr' using ${datafile}, clear	
		rename $personid_var personid
		rename $public_var public
		rename public public`yr'	
		save "tempo_puc`yr'.dta", replace 
	}
	
	clear 
	forvalues yr = $yrfirst/$yrlast{		
		if `yr' == $yrfirst{
			use "tempo_puc`yr'.dta", clear
		}	
		else{			
			merge 1:1 personid using "tempo_puc`yr'.dta", nogenerate
		}
		erase "tempo_puc`yr'.dta"	
	}
	
	save "tempo_pucALL.dta", replace
	
	// Merge with rest of the data 
	use "$maindir${sep}wk24${sep}master_sample_fs23.dta", clear
	merge 1:1 personid using "tempo_pucALL.dta", nogenerate
	erase "tempo_pucALL.dta"
	compress
	save "$maindir${sep}wk24${sep}master_sample_fs23.dta", replace	
}

/* ------------------------------------------------
 CALCULATE LIFE TIME BINSCATTER WITH TEN YEARS
* ------------------------------------------------- */

if "${run3yrs}" == "yes"{
// Load data
use  LTinc LTinc_f LTwlt LTwlt_f male personid father_id labor* numobs* yob yod using  ///
	"$maindir${sep}wk24${sep}master_sample_fs23.dta" if LTinc_f ~=. & LTinc ~=. , clear

	
// Keep only those with at least x-year of data of parents and children
	keep if numobslabor >= ${minnumyear}
	keep if numobslabor_f >= ${minnumyear}	
	keep if numobs_poslabor >= ${minnumyearLAB} 
	keep if numobs_poslabor_f >= ${minnumyearLAB}	
	
// Create log variables
foreach vv in LTinc LTinc_f LTwlt LTwlt_f{
	gen l`vv' = log(`vv')
}

// Calculate transission matrix
foreach oo in LTinc LTwlt{	
	// Varis 
	gen vari = "`oo'"			
				
	// Rank kids	
	qui: gen rankt = .					// Re uses the rank on perm income alt
	qui: bys male: bymyxtile `oo' rankt "${nquantilestran}"
	bys male: egen aux1 = pctile(`oo'), p(97.5)
	bys male: egen aux2 = pctile(`oo'), p(99)
	bys male: egen aux3 = pctile(`oo'), p(99.9)
	
	replace rankt = ${nquantilestran} + 1   if `oo' > aux1 & `oo' <= aux2 & `oo' !=. 
	replace rankt = ${nquantilestran} + 2 if `oo' > aux2 & `oo' <= aux3 & `oo' !=. 
	replace rankt = ${nquantilestran} + 3  if `oo' > aux3 & `oo' !=. 
	drop aux1 aux2 aux3
	
		
	// Rank parents	
	qui: gen frankt = .					// Re uses the rank on perm income alt
	qui: bymyxtile `oo'_f frankt "${nquantilestran}"
	bys male: egen aux1 = pctile(`oo'_f), p(97.5)
	bys male: egen aux2 = pctile(`oo'_f), p(99)
	bys male: egen aux3 = pctile(`oo'_f), p(99.9)
	
	replace frankt = ${nquantilestran} + 1    if `oo'_f > aux1 & `oo'_f <= aux2 & `oo'_f !=. 
	replace frankt = ${nquantilestran} + 2 if `oo'_f > aux2 & `oo'_f <= aux3 & `oo'_f !=. 
	replace frankt = ${nquantilestran} + 3  if `oo'_f > aux3 & `oo'_f !=. 
	drop aux1 aux2 aux3
	
	// Calculate
	qui: bymyTranMat "frank" "rank" "R_`oo'" "vari male"

	// Calculate moments
	bymysum_detail "yob" "L_" "`oo'" "male frank rank vari"
	bymyPCT "yob" "S_" "`oo'" "male frank rank vari"
	bymysum_detail "LTwlt" "L_" "`oo'" "male frank rank vari"
	bymyPCT "LTwlt" "S_" "`oo'" "male frank rank vari"
	drop frankt rankt vari 			
}
	

// Bin scatter of life time income with all data (minnumyearLAB years of data or more)	
foreach varx in LTinc LTwlt lLTinc lLTwlt{
	binscatter `varx' `varx'_f, nq(100) savedata(bs_3yrs_`varx') nodraw replace
	erase bs_3yrs_`varx'.do

	binscatter `varx' `varx'_f if male == 1, nq(100) savedata(bs_3yrs_men_`varx') nodraw replace
	erase bs_3yrs_men_`varx'.do

	binscatter `varx' `varx'_f if male == 0, nq(100) savedata(bs_3yrs_women_`varx') nodraw replace
	erase bs_3yrs_women_`varx'.do
	
	eststo clear
	eststo model_all1: regress `varx' `varx'_f 
	eststo model_all2: regress `varx' `varx'_f if male == 1
	eststo model_all3: regress `varx' `varx'_f  if male == 0
	esttab model_all* using  "Table_${minnumyearLAB}yrs_`varx'.tex", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se				
	esttab model_all* using  "Table_${minnumyearLAB}yrs_`varx'.csv", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se	
	eststo clear
}	

// Saving Results 
	clear 
	foreach oo in LTinc LTwlt{	
		append using "R_`oo'rank_varimale.dta"
		erase "R_`oo'rank_varimale.dta"
	}
	outsheet using "R_${minnumyearLAB}yrs_rank_varimale.csv", replace comma
	
	clear 
	foreach oo in LTinc LTwlt{	
		foreach ii in yob LTwlt{	
			use "S_L_`ii'`oo'.dta", clear
			merge 1:1 male frank rank vari using "PC_S_`ii'`oo'.dta", nogenerate 
			erase "S_L_`ii'`oo'.dta"
			erase "PC_S_`ii'`oo'.dta"
			outsheet using "S_${minnumyearLAB}yrs_`ii'_`oo'.csv", replace comma		
		}
	}	

}	
***

/* -------------------------------------------
 CALCULATE LIFE TIME REGRESSIONS
* ------------------------------------------- */

if "${runregs}" == "yes"{	
	
// Load data 
use  LTinc LTinc_f LTwlt LTwlt_f male personid father_id labor* numobs* educ educ_f yob yod using  ///
	"$maindir${sep}wk24${sep}master_sample_fs23.dta" if LTinc ~=. , clear
	
// Require at least ${minnumyear} income observations
*gen yrobs = min(${yrlast}-max(${yrlast}-yob+1-${end_age},0),yod-1) - ///
*			 (${yrfirst}-min(${yrfirst}-yob+1-${begin_age},0)) + 1
*drop if yrobs<${minnumyear}
	
// Keep only those with at least x-year of data of parents and children
	keep if numobslabor >= ${minnumyear}	
	keep if numobs_poslabor >= ${minnumyearLAB} 	

// Calculate modified permanent income. We consider all individuals even those with zero earnings 3 years in a row.*/
local firstyr=$yrfirst+2
forvalues yr = `firstyr'/$yrlast{	
	// Years
	local yrL1=`yr'-1
	local yrL2=`yr'-2			
		
	// Create average income for those with at least 2 years of income 
	gen perminc`yr'=0
	gen numobs=0
	forvalues yrp=`yrL2'/`yr'{
		replace perminc`yr'=perminc`yr'+labor`yrp' if labor`yrp'~=.
		replace numobs=numobs+1 if labor`yrp'~=.
		// Notice earnings below the min threshold are still used to get totearn
		// This ensure we do not consider income of individuals when they were 24 yrs old or less
	}

	// Replace for those out of the age range	
	replace perminc`yr'=perminc`yr'/numobs
	replace perminc`yr' = . if `yr'-yob+1<${begin_age} + 2 | `yr'-yob+1>${end_age}			
	replace perminc`yr' = . if yod <= `yr' 
	replace perminc`yr' = . if numobs<2	
	drop labor`yrL2' numobs
}


// Calculate life time growth 
local yr1=$yrlast-1
drop labor$yrlast labor`yr1' 			
		
		
matrix avg${varoi}m = J($yrlast-$yrfirst+1,1, 0.0)
matrix logavg${varoi}m = J($yrlast-$yrfirst+1,1, 0.0)
global mean${varoi}all = 0
local N${varoi} = 0
// gen ${varoi}emp=0
// gen numobs=0
gen numobs_L=0

gen tot${varoi}L=0
gen age = 0
local firstyr=$yrfirst+2
forvalues yr = `firstyr'/$yrlast{
	
// 	qui replace ${varoi}emp=${varoi}emp+1 if ${varoi}`yr'>rmininc[`yr'-${yrfirst}+1,1] & ${varoi}`yr'~=.
	replace  ${varoi}`yr'=rmininc[`yr'-${yrfirst}+1,1] if ${varoi}`yr'<=rmininc[`yr'-${yrfirst}+1,1] & ${varoi}`yr'~=.
// 	qui replace numobs=numobs+1 if ${varoi}`yr'~=. 
	
	// Calculating average permanent income in year `yr'
	// so that we can use it to measure aggregate fluctuations
	qui sum ${varoi}`yr', meanonly 
	matrix avg${varoi}m[`yr'-$yrfirst+1,1]=r(mean)
	global mean${varoi}all = ${mean${varoi}all} + avg${varoi}m[`yr'-$yrfirst+1,1]*r(N)
	matrix logavg${varoi}m[`yr'-$yrfirst+1,1] = log(r(mean))
	local N${varoi}= `N${varoi}' + r(N)

	gen log${varoi}`yr'=log(${varoi}`yr')
	drop ${varoi}`yr'
	if(`yr'>$yrfirst+2){
		local yrprev = `yr'-1
		gen ${varoi}L=log${varoi}`yr'-log${varoi}`yrprev'

		replace age = yob - `yr' + 1
		bys age: egen  ave${varoi}L = mean(${varoi}L)
		replace ${varoi}L= ${varoi}L-ave${varoi}L

		replace tot${varoi}L=tot${varoi}L+${varoi}L if ${varoi}L ~=.
		qui replace numobs_L=numobs_L + 1 if ${varoi}L~=.

		drop ave${varoi}L ${varoi}L
	}
}

// Drop those with less than min number of obs
// drop if numobs<${minnumyear}
// drop if ${varoi}emp<numobs/2
global mean${varoi}all = ${mean${varoi}all}/`N${varoi}'
global logmean${varoi}all=log(${mean${varoi}all})

replace tot${varoi}L=tot${varoi}L/numobs_L
drop age

sort personid
gen id=_n
save "$maindir${sep}wk24${sep}PermInc_IndStats_data23.dta", replace	

// Create regression groups
qui sum id
local idmax=r(max)
global idsub=0
global inc=1000
disp `idmax'
forvalues i = 1(${inc})`idmax'{
	preserve
	global idsub=$idsub+1
	keep if id>=`i' & id<`i'+${inc}
	save subLTdata${idsub}.dta, replace
	restore
}

// Run individual/level regressions
** Generate i) change btw t and t-1; ii) change btw t and t-3; and iii) residual from a quadratic regression
// global idsub = 25
forvalues idj=1/$idsub{

	disp "-------------------------------------"
	display "subsample: `idj' of $idsub"
	disp "-------------------------------------"
	capture drop _all
	use subLTdata`idj'.dta
	erase subLTdata`idj'.dta
	reshape long log${varoi}, i(id) j(year)
	sort id year
	xtset id year

	gen age=year-yob+1
	drop if age < ${begin_age} | age > ${end_age}
	drop if log${varoi} == .

	gen avg${varoi}=logavg${varoi}m[year-$yrfirst+1,1] - ${logmean${varoi}all}

	replace age=age-${begin_age} +1

	qui statsby _b, by(id) saving(coeffs${varoi}`idj',replace): reg log${varoi} age avg${varoi}

	sort id
	merge m:1 id using coeffs${varoi}`idj'.dta

	erase coeffs${varoi}`idj'.dta
	drop _merge
	tsset id year

	gen resid${varoi}=log${varoi}-(age*_b_age + _b_avg${varoi}*avg${varoi} + _b_cons)

	gen log${varoi}L1=log${varoi}-L1.log${varoi}
	gen log${varoi}L3=log${varoi}-L3.log${varoi}
	gen log${varoi}L5=log${varoi}-L5.log${varoi}

	gen resid${varoi}L1 = resid${varoi} - L1.resid${varoi}
	gen resid${varoi}L3 = resid${varoi} - L3.resid${varoi}
	gen resid${varoi}L5 = resid${varoi} - L5.resid${varoi}

	** For each person, compute several statistics based on our measures (L1, L3, and residual wage).
	** These statistics include the usual stuff (mean, stdev, skewness, etc.) as well as some 'intuitive" statistics.
	foreach v in log${varoi}L1 log${varoi}L3  log${varoi}L5 resid${varoi} resid${varoi}L1 resid${varoi}L3 resid${varoi}L5{
		disp("`v'")
		qui statsby mean`v'_id=r(mean) sd`v'_id=r(sd) skew`v'_id=r(skewness) kurt`v'_id=r(kurtosis) p1`v'_id=r(p1) p5`v'_id=r(p5) 	///
			p10`v'_id=r(p10) p25`v'_id=r(p25) p50`v'_id=r(p50) p75`v'_id=r(p75) p90`v'_id=r(p90) p95`v'_id=r(p95) p99`v'_id=r(p99)	///
			,by(id) saving (`v'_stats_`idj',replace): sum `v', detail

		sort id

		merge m:1 id using `v'_stats_`idj'.dta
		erase `v'_stats_`idj'.dta
		drop _merge
	}

	drop year log${varoi} age avg${varoi} resid${varoi} log${varoi}L1 log${varoi}L3 log${varoi}L5 ///
		resid${varoi}L1 resid${varoi}L3 resid${varoi}L5 
	duplicates drop
	save subfactor`idj'.dta, replace
}

// Put things together and save
capture drop _all
forvalues idj=1/$idsub{
	append using subfactor`idj'
	erase subfactor`idj'.dta
}
sort id

rename _b_avg${varoi} beta
rename _b_cons b_cons
rename _b_age b_age


// Comment this
// sort yob	
// replace personid = _n
// replace father_id = int(_N/2) + _n
save "$maindir${sep}wk24${sep}PermInc_IndStats23.dta", replace

}
***


/* --------------------------------------------------
CALCULATE BIN SCATTERS, REGRESSIONS, AND HISTOGRAMS
 ---------------------------------------------------- */
if "${runlongols}" == "yes"{	
/*
	UPDATING REGRESSION SAMPLE
*/

use personid public* labor* using "$maindir${sep}wk24${sep}master_sample_fs23.dta", clear 


gen publicall = 0 
gen laborall = 0 
forvalues yr = $yrfirst/$yrlast{
	replace publicall = publicall + 1 if public`yr' == 1 & labor`yr' != . & labor`yr' > 0
	replace laborall = laborall + 1 if labor`yr' != . & labor`yr' > 0
}
gen public = publicall/laborall > 0.5			// Worker is a public worker if s/he worked more than 1/4 of all time in public sector
keep public personid 
save "$maindir${sep}wk24${sep}aux_public.dta", replace
 
// Save a dta for fathers with at least ${minnumyear} years of data

*Save fathers data
use "$maindir${sep}wk24${sep}PermInc_IndStats23.dta", clear
// drop if numobs<${minnumyear}
drop father_id LTinc_f LTwlt_f id 
drop if male == 0
rename (beta b_* *_id) (beta_f b_*_f *_id_f)
rename (personid LTinc LTwlt) (father_id LTinc_f LTwlt_f)

gen lLTinc_f = log(LTinc_f) 
gen lLTwlt_f = log(LTwlt_f)
rename (tot${varoi}L) (tot${varoi}L_f)
save "$maindir${sep}wk24${sep}fathers_indstat_wide${minnumyear}.dta", replace

*Load childrens data 
use "$maindir${sep}wk24${sep}PermInc_IndStats23.dta", clear
// drop if numobs<${minnumyear}  // keep only those with at least ${minnumyear} years of data
drop LTinc_f LTwlt_f // Drop variables from fathers (we need this otherwise data does not get replaced)

gen lLTinc = log(LTinc) 		// Create the own log values
gen lLTwlt = log(LTwlt)

merge m:1 father_id using "$maindir${sep}wk24${sep}fathers_indstat_wide${minnumyear}.dta", keep(3) nogenerate
merge 1:1 personid using "$maindir${sep}wk24${sep}aux_public.dta", keep(3) nogenerate

// Create  percentile based individual specific moments
foreach fa in "" "_f"{
	foreach vv in log${varoi}L1_id log${varoi}L3_id log${varoi}L5_id resid${varoi}_id resid${varoi}L1_id resid${varoi}L3_id resid${varoi}L5_id{
		gen cku`vv'`fa' = (p95`vv'`fa'-p5`vv'`fa')/(p75`vv'`fa'-p25`vv'`fa')
		gen ksk`vv'`fa' = (p90`vv'`fa'+p10`vv'`fa'-2*p50`vv'`fa')/(p90`vv'`fa'-p10`vv'`fa')
		gen p9010`vv'`fa' = (p90`vv'`fa'-p10`vv'`fa')
		gen p9050`vv'`fa' = (p90`vv'`fa'-p50`vv'`fa')
		gen p5010`vv'`fa' = (p50`vv'`fa'-p10`vv'`fa')
	}
}

// Create dummy if fathers and children have the same education level (narrow and broad)

foreach ee in "" "_f"{
	gen educrec`ee' = .
	replace educrec`ee' = 1 if inlist(educ`ee',1,2,21,211,22,23,24,25,26,27)	// Vocational or less
	replace educrec`ee' = 2 if inlist(educ`ee',31,32,33,310)				// BA
	replace educrec`ee' = 3 if inlist(educ`ee',36,37,38,39)					// BA health or STEM
	replace educrec`ee' = 4 if inlist(educ`ee',41,42,43,410)				// MA
	replace educrec`ee' = 5 if inlist(educ`ee',46,47,491)					// MA health or STEM 
	replace educrec`ee' = 6 if inlist(educ`ee',35,45)						// Finance (BA or MA)
	replace educrec`ee' = 7 if inlist(educ`ee',44)							// Law
	replace educrec`ee' = 8 if inlist(educ`ee',48,49)						// MD Doctor or Dentist
	replace educrec`ee' = 9 if inlist(educ`ee',9)								// 0 if not classified		
}

gen dumm_same_educ = educ_f==educ						// Detailed 
gen dumm_same_educ_bd = educrec_f==educrec				// Broad

// Create cuadratic terms
gen lLTinc2 = lLTinc^2 
gen lLTinc_f2 = lLTinc_f^2


// Data for regressions and binscatters
save "$maindir${sep}wk24${sep}dataforregressions_dec02.dta", replace

/*------------------------------
 Short regressions 
--------------------------------*/

_pctile lLTinc_f, p(5 95)
local pp5 = r(r1)
local pp95 = r(r2)

foreach smpl in "_WL" "_NWL" "_BL"{

	local wvar = ""
	if "`smpl'" == "_WL"{
		preserve 
		keep if LTwlt_f != . 		
		local wvar = "lLTwlt_f"
	}	
	if "`smpl'" == "_NWL"{
		preserve 
		keep if lLTwlt_f != . 		
	}	
	
	// Level Regressions
	eststo clear
	eststo model_all1: regress lLTinc lLTinc_f `wvar'
	eststo model_all2: regress lLTinc lLTinc_f `wvar' if male == 1
	eststo model_all3: regress lLTinc lLTinc_f `wvar' if male == 0
	
	// Level if below 95
	eststo model_all4: regress lLTinc lLTinc_f `wvar' if lLTinc_f < `pp95'
	eststo model_all5: regress lLTinc lLTinc_f `wvar' if male == 1 & lLTinc_f < `pp95'
	eststo model_all6: regress lLTinc lLTinc_f `wvar' if male == 0 & lLTinc_f < `pp95'
	
	// Level if above 5
	eststo model_all7: regress lLTinc lLTinc_f `wvar' if lLTinc_f > `pp5'
	eststo model_all8: regress lLTinc lLTinc_f `wvar' if male == 1 & lLTinc_f > `pp5'
	eststo model_all9: regress lLTinc lLTinc_f `wvar' if male == 0 & lLTinc_f > `pp5'
	
	// Between 95/5
	eststo model_all10: regress lLTinc lLTinc_f `wvar' if lLTinc_f > `pp5' & lLTinc_f < `pp95'
	eststo model_all11: regress lLTinc lLTinc_f `wvar' if male == 1 & lLTinc_f > `pp5' & lLTinc_f < `pp95'
	eststo model_all12: regress lLTinc lLTinc_f `wvar' if male == 0 & lLTinc_f > `pp5' & lLTinc_f < `pp95'
	
	
	esttab model_all* using  "Table_LTinc`smpl'_PP95P5.tex", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se				
	esttab model_all* using  "Table_LTinc`smpl'_PP95P5.csv", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se	
	eststo clear
	
	// Restore if necessary
	if "`smpl'" == "_WL" |  "`smpl'" == "_NWL"{
		restore
	}
}


/*------------------------------
Run Regressions
--------------------------------*/
if "${runols}" == "yes"{
foreach smpl in "_WL"{	// "_NWL" "_BL"

	local wvar = ""
	if "`smpl'" == "_WL"{
		preserve 
		keep if LTwlt_f != . 		
		local wvar = "lLTwlt_f"
	}	
	if "`smpl'" == "_NWL"{
		preserve 
		keep if lLTwlt_f != . 		
	}	
	
	// Level Regressions
	eststo clear
	eststo model_all1: regress lLTinc lLTinc_f `wvar'
	eststo model_all2: regress lLTinc lLTinc_f `wvar' if male == 1
	eststo model_all3: regress lLTinc lLTinc_f `wvar' if male == 0
	esttab model_all* using  "Table_LTinc`smpl'.tex", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se				
	esttab model_all* using  "Table_LTinc`smpl'.csv", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se	
	eststo clear


	// Moment Regressions
	foreach vv in log{	// resid
		foreach ii in 1{		//  3 5
			foreach mome in mean p50 sd p9010 skew ksk{
				
				if inlist("`mome'","mean","p50"){
					local regvar1 = "p9010"
					local regvar2 = "ksk"
				}
				if inlist("`mome'","sd","p9010"){
					local regvar1 = "p50"
					local regvar2 = "ksk"
				}
				if inlist("`mome'","skew","ksk"){
					local regvar1 = "p50"
					local regvar2 = "p9010"
				}
				
				// Baseline only education and public dummies				
				eststo clear
				eststo model_all1: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f `wvar'  i.educ public
				eststo model_all2: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc `wvar' i.educ public
				eststo model_all3: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc_f `wvar' i.educ public
				eststo model_all4: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar' i.educ public
				eststo model_all5: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f i.educ public
				eststo model_all6: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id `regvar2'`vv'${varoi}L`ii'_id `regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f ///
							i.educ public
											
				forvalues mm = 0/1{
				eststo model_male`mm'1: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f `wvar' i.educ public if male == `mm'  
				eststo model_male`mm'2: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc `wvar' i.educ public if male == `mm'
				eststo model_male`mm'3: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc_f `wvar' i.educ public if male == `mm'
				eststo model_male`mm'4: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar' i.educ public if male == `mm'
				eststo model_male`mm'5: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f i.educ public if male == `mm'
				eststo model_male`mm'6: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id `regvar2'`vv'${varoi}L`ii'_id `regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f i.educ public if male == `mm'
						
				}
				
				esttab model_all* model_male0* model_male1* using  "Table_`mome'_`ii'_`vv'`smpl'_DEC01.tex", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se			
				esttab model_all* model_male0* model_male1* using  "Table_`mome'_`ii'_`vv'`smpl'_DEC01.csv", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se
				eststo clear			
				
				
// 				// Baseline w/ Detailed education and quadratic terms
// 				local dummyedu = "dumm_same_educ"
// 				eststo clear
// 				eststo model_all1: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f `wvar' `dummyedu' public
// 				eststo model_all2: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc2 i.educ `wvar' `dummyedu' public
// 				eststo model_all3: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc_f lLTinc_f2 i.educ_f `wvar' `dummyedu' public
// 				eststo model_all4: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f lLTinc2 lLTinc_f2 i.educ i.educ_f `wvar' `dummyedu' public
// 				eststo model_all5: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f lLTinc2 lLTinc_f2 i.educ i.educ_f  `wvar' `dummyedu' public  ///
// 						`regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f
// 				eststo model_all6: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f lLTinc2 lLTinc_f2 i.educ i.educ_f  `wvar' `dummyedu' public  ///
// 						`regvar1'`vv'${varoi}L`ii'_id `regvar2'`vv'${varoi}L`ii'_id `regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f 			
											
// 				forvalues mm = 0/1{
// 				eststo model_male`mm'1: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f `wvar' `dummyedu' public if male == `mm'  
// 				eststo model_male`mm'2: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc2 i.educ `wvar' `dummyedu' public if male == `mm'
// 				eststo model_male`mm'3: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc_f lLTinc_f2 i.educ_f  `wvar' `dummyedu' public if male == `mm'
// 				eststo model_male`mm'4: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f lLTinc2 lLTinc_f2 i.educ i.educ_f  `wvar' `dummyedu' public if male == `mm'
// 				eststo model_male`mm'5: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f lLTinc2 lLTinc_f2 i.educ i.educ_f  `wvar' `dummyedu' public  ///
// 						`regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f if male == `mm'
// 				eststo model_male`mm'6: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f lLTinc2 lLTinc_f2 i.educ i.educ_f  `wvar' `dummyedu' public  ///
// 						`regvar1'`vv'${varoi}L`ii'_id `regvar2'`vv'${varoi}L`ii'_id `regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f if male == `mm'
						
// 				}				
// 				esttab model_all* model_male0* model_male1* using  "Table_`mome'_`ii'_`vv'`smpl'_edu_DEC01.tex", replace   ///
// 				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se			
// 				esttab model_all* model_male0* model_male1* using  "Table_`mome'_`ii'_`vv'`smpl'_edu_DEC01.csv", replace   ///
// 				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se
// 				eststo clear													
				
			}
						
		}
	}	// END of moments loop
	
	if "`smpl'" == "_WL" |  "`smpl'" == "_NWL"{
		restore
	}
	
}	// END of slp loop	
}	
	
/*--------------------------------
Run binscatters and Stats
--------------------------------*/


if  "${runbinscat}" == "yes"{
// Which variables are going to be in the binscatter
local vlist = "LTinc lLTinc LTwlt lLTwlt tot${varoi}L beta b_cons b_age"
foreach ii in 1 5 {
	foreach vv in log resid{
		local vlist = "`vlist'" + " mean`vv'${varoi}L`ii'_id sd`vv'${varoi}L`ii'_id skew`vv'${varoi}L`ii'_id kurt`vv'${varoi}L`ii'_id cku`vv'${varoi}L`ii'_id"
		local vlist = "`vlist'" + " p50`vv'${varoi}L`ii'_id  ksk`vv'${varoi}L`ii'_id p9010`vv'${varoi}L`ii'_id p9050`vv'${varoi}L`ii'_id p5010`vv'${varoi}L`ii'_id"
	}
}
disp "`vlist'"
	

// Summary Stats for Fathers and Children Variables
foreach varx of local vlist{	
	//Gen vari 
	gen vari = "`varx'"
	gen vari_f = "`varx'_f"
	gen v = `varx'
	gen v_f = `varx'_f
	
	// Drop if missing vari 
	qui: drop if `varx' == .
	qui: drop if `varx'_f == .
	
	// Calculate the moments
	bymysum_detail "v" "L_" "`varx'" "vari male"
	bymyPCT "v" "L_" "`varx'" "vari male"	
	
	bymysum_detail "v_f" "L_" "`varx'_f" "vari_f"
	bymyPCT "v_f" "L_" "`varx'_f" "vari_f"	
	
		
	// Drop varis 
	drop vari vari_f v v_f
}	

// Binscatters 
foreach varx of local vlist{		
	preserve 
		//Gen vari 
		gen vari = "`varx'"
		gen v = `varx'
		
		// Drop if missing vari 
		drop if `varx' == .
		drop if `varx'_f == .
		
// 		// Calculate ranks of moments in x-axis and moments in y-axis
			
// 		// Rank fathers and children			
// 		local het="male"  				// we are always ranking within gender and age (not agegp)
// 		foreach t in "" "_f"{ 			//Calculate the ranking in `yr' and `yrp'
// 			gen rankt`t'=.
// 			sort `het' `varx'`t'
// 			by `het' : egen numobs_aux=count(`varx'`t')
// 			by `het' : replace rankt`t' = _n/numobs_aux 
// 			if ("`t'" == "_f"){				
// 				replace rankt`t' = 100 if rankt`t' > 0.999 			
			
// 				replace rankt`t' = 99.9 if rankt`t' > 0.99 & rankt`t' <= 0.999 
// 				replace rankt`t' = 99   if rankt`t' > 0.975 & rankt`t' <= 0.99 
				
// 				replace rankt`t' = (100/${nqtiles})* ///
// 								(floor(numobs*rankt`t'*${nqtiles}/(1+numobs))+1)	///
// 								if rankt`t'<=0.975
// 			}
// 			else{
// 				replace rankt`t' =100*rankt`t'
// 			}
// 			drop numobs_aux				
// 		}
		
		
		
// 		// Calculate moments for "rank-rank"	
// 		bymysum_meanonly "rankt" "L_" "`varx'_mom" "rankt_f vari male"		
		
		// Calculate Binscatters--PARENTS IN THE X-AXIS
			
		// All
		binscatter `varx' `varx'_f, nq(100) savedata(bs_`varx') nodraw replace
		erase bs_`varx'.do
		qui: reg `varx' `varx'_f
		local b`varx' = _b[`varx'_f]
		local se`varx' = _se[`varx'_f]
		
		// Men
		binscatter `varx' `varx'_f if male == 1, nq(100) savedata(bs_men_`varx') nodraw replace		
		erase bs_men_`varx'.do
		qui: reg `varx' `varx'_f if male == 1
		local b`varx'm1 = _b[`varx'_f]
		local se`varx'm1 = _se[`varx'_f]
		

		// Women
		binscatter `varx' `varx'_f if male == 0, nq(100) savedata(bs_women_`varx') nodraw replace
		erase bs_women_`varx'.do
		qui: reg `varx' `varx'_f if male == 0
		local b`varx'm0 = _b[`varx'_f]
		local se`varx'm0 = _se[`varx'_f]
		
		// Calculate Binscatters--CHILDREN IN THE X AXIS

		// All
		binscatter `varx'_f `varx', nq(100) savedata(bs_`varx'_ALT) nodraw replace
		erase bs_`varx'_ALT.do
		
		// Men
		binscatter `varx'_f `varx' if male == 1, nq(100) savedata(bs_men_`varx'_ALT) nodraw replace
		erase bs_men_`varx'_ALT.do
		
		// Women
		binscatter `varx'_f `varx' if male == 0, nq(100) savedata(bs_women_`varx'_ALT) nodraw replace
		erase bs_women_`varx'_ALT.do

		// Calculate Binscatters--FATHERS INCOME IN THE X AXIS AND CHILDRENS MOMENTS IN THE X AXIS
		
		// All
		binscatter `varx' LTinc_f, nq(100) savedata(bs_`varx'_LFT) nodraw replace
		erase bs_`varx'_LFT.do

		// Men
		binscatter `varx' LTinc_f if male == 1, nq(100) savedata(bs_men_`varx'_LFT) nodraw replace
		erase bs_men_`varx'_LFT.do

		// Women
		binscatter `varx' LTinc_f if male == 0, nq(100) savedata(bs_women_`varx'_LFT) nodraw replace
		erase bs_women_`varx'_LFT.do
		
		// Calculate Binscatters--FATHERS WEALTH IN THE X AXIS AND CHILDRENS MOMENTS IN THE X AXIS		
		// All
		binscatter `varx' LTwlt_f, nq(100) savedata(bs_`varx'_WLT) nodraw replace
		erase bs_`varx'_WLT.do

		// Men
		binscatter `varx' LTwlt_f if male == 1, nq(100) savedata(bs_men_`varx'_WLT) nodraw replace
		erase bs_men_`varx'_WLT.do

		// Women
		binscatter `varx' LTwlt_f if male == 0, nq(100) savedata(bs_women_`varx'_WLT) nodraw replace
		erase bs_women_`varx'_WLT.do			
			
// 		// Calculate ranks: rank of father in the x-axis, moments in the y-axis	
// 		// Rank parents		
// 		local t = "_LTF"
// 		gen rankt`t'=.
// 		sort LTinc_f
// 		egen numobs_aux=count(LTinc_f)
// 		replace rankt`t' = _n/numobs_aux 
				
// 		replace rankt`t' = 100 if rankt`t' > 0.999 			
		
// 		replace rankt`t' = 99.9 if rankt`t' > 0.99 & rankt`t' <= 0.999 
// 		replace rankt`t' = 99   if rankt`t' > 0.975 & rankt`t' <= 0.99 
		
// 		replace rankt`t' = (100/${nqtiles})* ///
// 						(floor(numobs*rankt`t'*${nqtiles}/(1+numobs))+1) if rankt`t'<=0.975	
// 		drop numobs_aux		
		
// 		// Calculate the moments
// 		bymysum_detail "v" "L_" "`varx'`t'" "rankt`t' vari male"
// 		bymyPCT "v" "L_" "`varx'`t'" "rankt`t' vari male"	
		
		drop vari v 
// 		rankt_f rankt	
	restore 		
}

// Save coefs
clear
set obs 1
gen i = 1
foreach varx of local vlist{		
	gen b`varx' = `b`varx''
	gen se`varx' = `se`varx''
	
	gen b`varx'm1 = `b`varx'm1'
	gen se`varx'm1 = `se`varx'm1'
	
	gen b`varx'm0 =  `b`varx'm0'
	gen se`varx'm0 = `se`varx'm0'
}	

reshape long b se, i(i) j(vari) string 

	
// Collect Results

// Rank rank	
// clear 
// foreach oo of local vlist{
// 	append using "S_L_rankt`oo'_mom.dta"
// 	erase  "S_L_rankt`oo'_mom.dta"
// }
// outsheet using Rank_Rank_male_FatherSon.csv, replace comma	

foreach t in "" "_ALT" "_LFT"{
	foreach mm in "" "_men" "_women"{
		clear 
		foreach oo of local vlist{
			insheet using "bs`mm'_`oo'`t'.csv", clear comma 
			gen idex = _n
			save "bs`mm'_`oo'`t'.dta", replace
			erase "bs`mm'_`oo'`t'.csv"	
		}
		clear
		local jj = 1				
		foreach oo of local vlist{
			
			if `jj' == 1{
				use "bs`mm'_`oo'`t'.dta", clear
				erase "bs`mm'_`oo'`t'.dta"
				local jj = 2
			}
			else {
				merge 1:1 idex using "bs`mm'_`oo'`t'.dta", nogenerate keep(3)			
				erase "bs`mm'_`oo'`t'.dta"
			}
		}
		outsheet using Binscatters`mm'_FatherSon`t'.csv, replace comma			
	}
}

// // Ranks of father in x axis and moments of children in the y axis
// foreach oo of local vlist{
// 	use "S_L_v`oo'_LTF.dta", clear 
// 	merge 1:1 rankt_LTF male using "PC_L_v`oo'_LTF.dta", nogenerate
// 	erase "S_L_v`oo'_LTF.dta"
// 	erase "PC_L_v`oo'_LTF.dta"
// 	save "L_v`oo'_LTF.dta", replace
// }	
// clear 
// foreach oo of local vlist{
// 	append using "L_v`oo'_LTF.dta"
// 	erase "L_v`oo'_LTF.dta"
// }
// outsheet using Rank_mome_FatherSon_LTF.csv, replace comma	


// Moments
clear 
foreach varx of local vlist{	
	use S_L_v_f`varx'_f.dta, clear 
	merge 1:1 vari_f using PC_L_v_f`varx'_f.dta, nogenerate 
	save L_v_f`varx'_f.dta, replace
	erase S_L_v_f`varx'_f.dta
	erase PC_L_v_f`varx'_f.dta
}	
clear 
foreach varx of local vlist{	
	append using L_v_f`varx'_f.dta
	erase L_v_f`varx'_f.dta
}
outsheet using moments_fathers.csv, replace comma 

clear 
foreach varx of local vlist{	
	use S_L_v`varx'.dta, clear 
	merge 1:1 vari male using PC_L_v`varx'.dta, nogenerate 
	save L_v`varx'.dta, replace
	erase S_L_v`varx'.dta
	erase PC_L_v`varx'.dta
}	
clear 
foreach varx of local vlist{	
	append using L_v`varx'.dta
	erase L_v`varx'.dta
}
outsheet using moments_childrens.csv, replace comma 

}
}	// END long regressions 

if "${runshortols}" == "yes"{	
	
	
// // Load data	
// use "$maindir${sep}wk24${sep}dataforregressions_dec02.dta", clear
	
	
// // Which variables are going to be in the binscatter
// local vlist = "LTinc lLTinc LTwlt lLTwlt tot${varoi}L beta b_cons b_age"
// foreach ii in 1 5 {
// 	foreach vv in log resid{
// 		local vlist = "`vlist'" + " mean`vv'${varoi}L`ii'_id sd`vv'${varoi}L`ii'_id skew`vv'${varoi}L`ii'_id kurt`vv'${varoi}L`ii'_id cku`vv'${varoi}L`ii'_id"
// 		local vlist = "`vlist'" + " p50`vv'${varoi}L`ii'_id  ksk`vv'${varoi}L`ii'_id p9010`vv'${varoi}L`ii'_id p9050`vv'${varoi}L`ii'_id p5010`vv'${varoi}L`ii'_id"
// 	}
// }
// disp "`vlist'"
	
// // Binscatters 
// foreach varx of local vlist{		
// 	preserve 
// 		//Gen vari 
// 		gen vari = "`varx'"
// 		gen v = `varx'
		
// 		// Drop if missing vari 
// 		drop if `varx' == .
// 		drop if `varx'_f == .
					
// 		// Calculate Binscatters--PARENTS IN THE X-AXIS
			
// 		// All
// 		reg `varx' `varx'_f
// 		local b`varx' = _b[`varx'_f]
// 		local se`varx' = _se[`varx'_f]
// 		local n`varx' = e(N)
		
// 		// Men
// 		reg `varx' `varx'_f if male == 1
// 		local b`varx'm1 = _b[`varx'_f]
// 		local se`varx'm1 = _se[`varx'_f]
// 		local n`varx'm1 = e(N)
		

// 		// Women
// 		reg `varx' `varx'_f if male == 0
// 		local b`varx'm0 = _b[`varx'_f]
// 		local se`varx'm0 = _se[`varx'_f]
// 		local n`varx'm0 = e(N)
		
		
					
// 		drop vari v 
// 	restore 		
// }

// // Save coefs
// clear
// set obs 1
// gen i = 1
// foreach varx of local vlist{		
// 	gen b`varx' = `b`varx''
// 	gen se`varx' = `se`varx''
// 	gen n`varx' = `n`varx''
	
// 	gen b`varx'm1 = `b`varx'm1'
// 	gen se`varx'm1 = `se`varx'm1'
// 	gen n`varx'm1 = `n`varx'm1'
	
// 	gen b`varx'm0 =  `b`varx'm0'
// 	gen se`varx'm0 = `se`varx'm0'
// 	gen n`varx'm0 = `n`varx'm0'
// }	

// reshape long b se n, i(i) j(vari) string 
// outsheet using binscatter_elasticities.csv, replace comma	



// Regressions for table 
use "$maindir${sep}wk24${sep}dataforregressions_dec02.dta", clear

foreach smpl in "_WL"{	// "_NWL" "_BL"

	local wvar = ""
	if "`smpl'" == "_WL"{
		preserve 
		keep if LTwlt_f != . 		
		local wvar = "lLTwlt_f"
		gen lLTwlt_f2 = lLTwlt_f^2
	}	
	if "`smpl'" == "_NWL"{
		preserve 
		keep if lLTwlt_f != . 		
		gen lLTwlt_f2 = lLTwlt_f^2
	}	
	
	// Moment Regressions
	foreach vv in log{			// resid
		foreach ii in 1{		//  3 5
			foreach mome in mean p50 sd p9010 skew ksk{
				
				if inlist("`mome'","mean","p50"){
					local regvar1 = "p9010"
					local regvar2 = "ksk"
				}
				if inlist("`mome'","sd","p9010"){
					local regvar1 = "p50"
					local regvar2 = "ksk"
				}
				if inlist("`mome'","skew","ksk"){
					local regvar1 = "p50"
					local regvar2 = "p9010"
				}
				
				// Baseline only education and public dummies				
				foreach xcontrols in "" "lLTinc2 lLTinc_f2 lLTwlt_f2"{ // "i.educ public" "i.educ public lLTinc2 lLTinc_f2 lLTwlt_f2"
					
				if "`xcontrols'" == ""{
					local lxname = "base"
				}
				else if "`xcontrols'" == "i.educ public"{
					local lxname = "educdumm"
				}
				else if "`xcontrols'" == "i.educ public lLTinc2 lLTinc_f2 lLTwlt_f2"{
					local lxname = "sqrt"
				}
				else if "`xcontrols'" == "lLTinc2 lLTinc_f2 lLTwlt_f2"{
					local lxname = "sqrtONLY"
				}
					
				eststo clear
				eststo model_all1: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f `wvar'  `xcontrols'
				eststo model_all2: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc `wvar' `xcontrols'
				eststo model_all3: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc_f `wvar' `xcontrols'
				eststo model_all4: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar' `xcontrols'
				eststo model_all5: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f `xcontrols'
				eststo model_all6: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id `regvar2'`vv'${varoi}L`ii'_id `regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f ///
							`xcontrols'
											
				foreach mm in 1 0{
				eststo model_male`mm'1: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f `wvar' `xcontrols' if male == `mm'  
				eststo model_male`mm'2: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc `wvar' `xcontrols' if male == `mm'
				eststo model_male`mm'3: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc_f `wvar' `xcontrols' if male == `mm'
				eststo model_male`mm'4: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar' `xcontrols' if male == `mm'
				eststo model_male`mm'5: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f `xcontrols' if male == `mm'
				eststo model_male`mm'6: regress `mome'`vv'${varoi}L`ii'_id  `mome'`vv'${varoi}L`ii'_id_f lLTinc lLTinc_f `wvar'  ///
						`regvar1'`vv'${varoi}L`ii'_id `regvar2'`vv'${varoi}L`ii'_id `regvar1'`vv'${varoi}L`ii'_id_f `regvar2'`vv'${varoi}L`ii'_id_f `xcontrols' if male == `mm'
						
				}
				
				esttab model_all* model_male0* model_male1* using  "Table_`mome'_`ii'_`vv'`smpl'_DEC03_`lxname'.tex", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se			
				esttab model_all* model_male0* model_male1* using  "Table_`mome'_`ii'_`vv'`smpl'_DEC03_`lxname'.csv", replace   ///
				stats(r2 N, labels(R2 "N"))  star(* 0.1 ** 0.05 *** 0.01) se
				eststo clear
				}
																						
			}
						
		}
	}	// END of moments loop
	
	if "`smpl'" == "_WL" |  "`smpl'" == "_NWL"{
		restore
	}
	
}	// END of slp loop	


}	// Drop regressions
	
timer off 1
timer list 1		

// END OF THE CODE
