// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the core figures for the draft
// This version November 26, 2021
// Serdar Ozkan and Sergio Salgado
// This file replicates the plots for the Norway Specific Section of the paper
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

// Main dirs
global maindir ="..."
global maindir_fs ="..."


// Where the data is stored Fathers and Children
global bindata = 	 "12 Nov 2020/12 Nov 2020 FatherSampleIndReg"
global bindata3yrs = "19 Jan 2021/19 Jan 2021 IndReg_NumDec_20"		// Only for one bin scatter data, Figure 1 of the intergenerational
global bindataperm = "19 Jan 2021/17 Jan 2020 IndReg_NumDec_20"	
global bindata3yrsTRAN = "19 Jan 2021/3 Feb 2021 IndReg_NumDec_20"		
global bindata3yrsAGE = "19 Jan 2021/4 Feb 2021 IndReg_NumDec_20"		
global bindatamin25 = "19 Jan 2021/5 Feb 2021 IndReg_NumDec_20"		// New results with 25 yrs of data (more restrictive)


global bindatat_nw = "16 Dec 2020/16 Dec 2020 IndReg_NumDec_20"
global mobidata_fs = "14 Nov 2020/14 Nov 2020 Mobility_FS"
global voladata_fs = "29 Sep 2021 Volatility"				// Data on Volatility (currrent data)
global woladata_fs = "30 Sep 2021 WealthFS_2021"			// Data on Volatility (currrent data)


// Data December 2021 with 23 of age of data and 20+10 years of data
global voladata_fsDEC = 		"Dec 1 2021/1 Dec 2021 Volatility"		// Data on Volatility
global woladata_fsDEC = 		"Dec 1 2021/1 Dec 2021 WealthFS_minage23_dec2021"			// D (currrent data)
global bindatamin23_normDEC = 	"Dec 1 2021/1 Dec 2021 IndReg_EDUCMORE_PP_20"			// New results with 23 yrs of data
global bindatamin23_normDEC2 =  "Dec 1 2021/2 Dec 2021 IndReg_EDUCMORE_DEC02_20"		// This has the binscatters

global wlthdata_fs = "17 Dec 2020/17 Dec 2020 WealthFS"				// 
global wlthdata_fs25yrs = "5 Feb 2021/5 Feb 2021 WealthFS"			// Data on heterogeneoty with 25 years of min age
global wlthdata_fs23yrs = "9 Feb 2021/9 Feb 2021 WealthFS"			// Data on heterogeneoty with 25 years of min age

global bindatamin25_norm = "5 Feb 2021/6 Feb 2021 IndReg_NumDec_20"		// New results with 25 yrs of data
global bindatamin23_norm = "9 Feb 2021/8 Feb 2021 IndReg_NumDec_23"		// New results with 23 yrs of data
global bindataminDEC01 = "results/Dec 1 2021/1 Dec 2021 IndReg_EDUCBASE_20"				// Rsults of Dec 01, 2021

// Where the figures are going to be saved 
global outfolder="figs_Spt2021"			
global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	
	
// Read initialize and plotting code. Do not change myplots.do
do "$maindir/doDec2020_NO/0_Initialize.do"
do "$maindir${sep}doDec2020_NO${sep}myplots.do"		

// Define these variables for your dataset
global yrfirst = 1967 		// First year in the dataset 
global yrlast =  2017 		// Last year in the dataset

// How many years to keep in the heterogeity process 
global keepyrs = 20

// What years are we using to nrmalize 
global normyear = 1993

// Recession years
global receyears = "1975,1988,1989,1990,1993,1993,1995,2002,2003,2004,2009,2010,2015"	

// Define some common charactristics of the plots 
global xtitlesize =   "vlarge" 
global ytitlesize =   "vlarge" 
global xlabsize =     "vlarge" 
global ylabsize =     "vlarge" 
global titlesize  =   "vlarge" 
global subtitlesize = "medium" 
global formatfile  =  "pdf"
global fontface   =   "Times New Roman"
global marksize =     "medlarge"	
global legesize =     "vlarge"	
global linewidth = "thick"

// Where the figs are going to be saved
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaperLNG"
   
// Cd to folder with out 
cd "$maindir${sep}" // Cd to the folder containing the files

/*--------------------------------------------------- ---------------------------------------------------	
	Fathers and Children Section
--------------------------------------------------- ---------------------------------------------------	*/

*Folder to save figures 
global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
global yrfirst = 1967
global receyears = "1975,1982,1983,1988,1989,1990,1992,2002,2003,2009,2010,2015"
global figvol_fs  = "no"
global figineq_fs = "yes"


if "${figineq_fs}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	
	foreach subgp in fem male{	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn researn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "$maindir_fs${sep}out${sep}${ineqdata_fs}${sep}L_`var'_sumstat.csv", clear
		local labname = "All"
	}
	if "`subgp'" == "male"{
		insheet using "$maindir_fs${sep}out${sep}${ineqdata_fs}${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local labname = "Men"
	}
		
	if "`subgp'" == "fem"{
		insheet using "$maindir_fs${sep}out${sep}${ineqdata_fs}${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	
	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
// Figure 2 (Inequality)	
	if "${vari}" == "logearn"{
		local y1 = 1.6
		local y2 = 2.2
		local y3 = 0.2
	}
	if "${vari}" == "researn"{
		local y1 = 1.6
		local y2 = 2.2
		local y3 = 0.2
	}
	if "${vari}" == "researne" {
		local y1 = 1.6
		local y2 = 2.2
		local y3 = 0.2
	}
		   		   
	tspltAREALimPA "sd$vari p9010$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "2.56*{&sigma}" "P90-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2A_`subgp'_${vari}_FS"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	if "${vari}" == "logearn"{
		local y1 = 0.4
		local y2 = 1.6
		local y3 = 0.2
	} 
	if "${vari}" == "researn"{
		local y1 = 0.4
		local y2 = 1.6
		local y3 = 0.2
	}
	if "${vari}" == "researne" {
		local y1 = 0.4
		local y2 = 1.6
		local y3 = 0.2
	}
	 tspltAREALimPA "p9050$vari  p5010$vari " /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2B_`subgp'_${vari}_FS"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 	  		
	   
	   }	// END of loop over subgroups
	   
}		// END loop over variables
}	// END of inequality section



if "${figvol_fs}" == "yes"{		
foreach pref in res{
	*Plot One-year changes
	foreach jj in 1{ 
		
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	global vari = "`pref'earn`jj'F"
	
	*Figure 4
	foreach subgp in men women {
		
		if "${vari}" == "researn1F" | "${vari}" == "arcearn1F"{
			local lyear = ${yrfirst}+3
			local ryear = ${yrlast}-2
			local labtitle = "g{sup:1}{sub:it}"
		}			
		if "${vari}" == "arcearn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}-5
			local labtitle = "arc{sup:1}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
		}
		if "${vari}" == "arcearn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "arc{sup:5}{sub:it}" // ?? what labels here?
		}
		
		*Load data 				
		insheet using "$maindir_fs${sep}out${sep}${voladata_fs}${sep}L_${vari}_male_sumstat.csv", case clear
		
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}				
		gen rece = inlist(year,${receyears})
		
		gen p9050$vari = p90$vari - p50$vari
		gen p5010$vari = p50$vari - p10$vari
		
		if "${vari}" == "researn1F" |  "${vari}" == "arcearn1F"{
			local ylimlo = 0.2
			local ylimup = 0.75
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.4
			local ylimup = 1.0
			local ylimdf = 0.2	
			replace year = year + 2		// This is to center the 5-year changes
		}
		
		   tspltAREALimPA "p9050$vari  p5010$vari" /// Which variables?
		   "year" ///
		   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		   "Dispersion of `labtitle'" /// y axis title 
		   "" ///  Plot title
		   "" ///
		   "fig4_`subgp'_${vari}_FS"	/// Figure name
		   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
		   "" 						/// If legend is active or nor	
		   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
		   "O S" 			   
	}
	
	*Figure 5
	insheet using "$maindir_fs${sep}out${sep}${voladata_fs}${sep}L_${vari}_male_sumstat.csv", case clear
	gen p9010${vari} = (p90$vari - p10${vari})
	gen ksk${vari} = ( (p90${vari}-p50${vari} ) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91	
	replace kurt${vari} = kurt${vari} - 3.00
		
	
	keep year male p9010${vari} ksk${vari} cku${vari} sd${vari} skew${vari} kurt${vari}
	reshape wide sd${vari} skew${vari} kurt${vari} p9010${vari} ksk${vari} cku${vari} , i(year) j(male)
			
	merge 1:1 year using "agg/aggregate_nor.dta", nogenerate keep(1 3)
	gen rece = inlist(year,${receyears})
										
	*Dispersion for men and women separately 
	if "${vari}" == "`pref'earn1F"{
		local ylimlo = 0.4
		local ylimup = 0.7
		local ylimdf = 0.1			
	}		
	if "${vari}" == "`pref'earn5F"{
		local ylimlo = 0.8
		local ylimup = 2.0
		local ylimdf = 0.2			
		replace year = year + 2		// This is to center the 5-year changes
	}
		
	 tspltAREALimPA "p9010${vari}1 sd${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P10" "Standard Deviation" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5O_${vari}_male_FS"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "no"	
	   
	
	if "${vari}" == "`pref'earn1F"{
		local ylimlo = 0.4
		local ylimup = 1.4
		local ylimdf = 0.2			
	}		
	if "${vari}" == "`pref'earn5F"{
		local ylimlo = 0.8
		local ylimup = 2.0
		local ylimdf = 0.2			
		replace year = year + 2		// This is to center the 5-year changes
	}
	
	 tspltAREALimPA "p9010${vari}0 sd${vari}0" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P10" "Standard Deviation" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5O_${vari}_women_FS"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "no"	
	
					
	*Dispersion
	if "${vari}" == "`pref'earn1F"{
		local ylimlo = 0.4
		local ylimup = 1.4
		local ylimdf = 0.20			
	}		
	if "${vari}" == "`pref'earn5F"{
		local ylimlo = 0.8
		local ylimup = 2.0
		local ylimdf = 0.2			
		replace year = year + 2		// This is to center the 5-year changes
	}
	
	 tspltAREALimPA "p9010${vari}0 p9010${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "P90-P10 of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5O_${vari}_FS"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "no" 
	*Kelley skewness 
	if "${vari}" == "`pref'earn1F"{
		local ylimlo = -0.2
		local ylimup = 0.25
		local ylimdf = 0.10			
	}		
	if "${vari}" == "`pref'earn5F"{
		local ylimlo = -0.05
		local ylimup = 0.20
		local ylimdf = 0.05		
		replace year = year + 2		// This is to center the 5-year changes
	}
	
	 tspltAREALimPA "ksk${vari}0 ksk${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Kelley Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_${vari}_FS"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes" "1966.5" "2016.5"
	   
	 *Skewness
	 	if "${vari}" == "`pref'earn1F"{
		local ylimlo = -2.0
		local ylimup = 0
		local ylimdf = 0.5		
	}		
	if "${vari}" == "`pref'earn5F"{
		local ylimlo = -0.05
		local ylimup = 0.20
		local ylimdf = 0.05		
		replace year = year + 2		// This is to center the 5-year changes
	}
	
	 tspltAREALimPA "skew${vari}0 skew${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_${vari}_cent_FS"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes" "1966.5" "2016.5"	
	   
	   
	*Kurtosis   
	if "${vari}" == "researn1F"{
		local ylimlo = 4
		local ylimup = 16
		local ylimdf = 2	
	}	
	if "${vari}" == "arcearn1F"{
		local ylimlo = 7
		local ylimup = 11
		local ylimdf = 1	
	}	
	if "${vari}" == "researn5F"{
		local ylimlo = 4
		local ylimup = 8
		local ylimdf = 2			
	}
	if "${vari}" == "arcearn5F"{
		local ylimlo = 2
		local ylimup = 7
		local ylimdf = 1			
	}
 	 
	 tspltAREALimPA "kurt${vari}0 kurt${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "3" ///
	   "" /// x axis title
	   "Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5B_${vari}_cent_FS"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S"   
	   	   
	*Crow-Siddiqui Kurtosis   
	if "${vari}" == "researn1F"{
		local ylimlo = 8
		local ylimup = 12
		local ylimdf = 1	
	}	
	if "${vari}" == "arcearn1F"{
		local ylimlo = 7
		local ylimup = 11
		local ylimdf = 1	
	}	
	if "${vari}" == "researn5F"{
		local ylimlo = 4
		local ylimup = 8
		local ylimdf = 2			
	}
	if "${vari}" == "arcearn5F"{
		local ylimlo = 2
		local ylimup = 7
		local ylimdf = 1			
	}
 	 
	 tspltAREALimPA "cku${vari}0 cku${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 5 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Excess Crow-Siddiqui Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5B_${vari}_FS"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	   }	// END loop jumps
	   }	// END loop arc res
	   
}	// END of FS time series	   
	
	
*Figure income vs. moment 
	global vari = "researn1F"  // Or 5F
	foreach sampl in men women {
		*Load data 
		
		if "`sampl'" == "all"{
			insheet using "$maindir_fs${sep}out${sep}${voladata_fs}${sep}L_${vari}_fsallrank.csv", clear case
			local tlabel = "All"
		}
		if "`sampl'" == "men"{
			insheet using "$maindir_fs${sep}out${sep}${voladata_fs}${sep}L_${vari}_fsallrank_male.csv", clear case
			keep if male == 1
			local tlabel = "Men"
			local dlabel "Sons"
			local mclr = "navy"
			local llabel = "off"
			local sdlim = "0.55(0.1)0.85"
			
			local sdlim = ""
		}
		if "`sampl'" == "women"{
			insheet using "$maindir_fs${sep}out${sep}${voladata_fs}${sep}L_${vari}_fsallrank_male.csv", clear case
			keep if male == 0
			local tlabel = "Women"
			local dlabel "Daugthers"
			local mclr = "navy"
			local llabel = ""
			local sdlim = "0.6(0.1)1.1"			
			local sdlim = ""
		}
		
		if "${vari}" == "researn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
			local labtitle = "g{sup:1}{sub:it}"			
		}		
		if "${vari}" == "researn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
			local labtitle = "g{sup:5}{sub:it}"			
		}
		if "${vari}" == "arcearn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
		}		
		if "${vari}" == "arcearn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
		}
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
		
		*By decade impact
		replace year = 1970 if year <= 1979 
		replace year = 1980 if year <= 1999 & year >=1980
// 		replace year = 1990 if year <= 1999 & year >=1990
// 		replace year = 2000 if year <= 2009 & year >=2000
		replace year = 2000 if year >= 2000
		
		*Averagegin statistics over time 
		*This can be changed to seperate recession to expansion periods
		collapse  p10${vari}  p50${vari}  p90${vari}  p9010${vari}  sd${vari} ksk${vari} skew${vari} ///
			cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank year)
		
		*Reshape to have a cleaner plot 
		reshape wide  p10${vari}  p50${vari}  p90${vari} p9010${vari}  sd${vari} ksk${vari} skew${vari} ///
			cku${vari} kurt${vari} , i(fpermrank) j(year)
		replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
		replace fpermrank = 2.5*fpermrank
		
		*Gen year averages
		egen p90${vari}all = rowmean(p90${vari}*)
		egen p50${vari}all = rowmean(p50${vari}*)
		egen p10${vari}all = rowmean(p10${vari}*)
		egen p9010${vari}all = rowmean(p9010${vari}*)
		egen sd${vari}all = rowmean(sd${vari}*)
		egen ksk${vari}all = rowmean(ksk${vari}*)
		egen skew${vari}all = rowmean(skew${vari}*)
		egen cku${vari}all = rowmean(cku${vari}*)
		egen kurt${vari}all = rowmean(kurt${vari}*)
		
		*Ploting: Dispersion		
// 		tw connected sd${vari}all sd${vari}1970 sd${vari}1980 sd${vari}1990 sd${vari}2000 sd${vari}2010 fpermrank, ///
		tw connected sd${vari}all sd${vari}1970 sd${vari}1980 sd${vari}2000 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Standard Deviation of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Lifetime Income", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(`sdlim',labsize(large)) xlabel( 0(10)100,labsize(large)) ///
	legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1970" 3 "1980/1990" 4 "2000/2010") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_sd${vari}_FS_`sampl'_NL.pdf", replace
		
// 		tw connected p9010${vari}all p9010${vari}1970 p9010${vari}1980 p9010${vari}1990 p9010${vari}2000 p9010${vari}2010 fpermrank, ///
		tw connected p9010${vari}all p9010${vari}1970 p9010${vari}1980 p9010${vari}2000 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("P90-P10 of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Lifetime Income", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
	legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1970" 3 "1980/1990" 4 "2000/2010") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_p9010${vari}_FS_`sampl'_NL.pdf", replace
		
		*Ploting: Skewness		
		tw connected skew${vari}all skew${vari}1970 skew${vari}1980 skew${vari}2000 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Skewness of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Lifetime Income", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(-2(0.5)0,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
	legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1970" 3 "1980/1990" 4 "2000/2010") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_skew${vari}_FS_`sampl'_NL.pdf", replace
		
		tw connected ksk${vari}all ksk${vari}1970 ksk${vari}1980 ksk${vari}2000 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Kelley Skewness of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Lifetime Income", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
	legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1970" 3 "1980/1990" 4 "2000/2010") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_ksk${vari}_FS_`sampl'_NL.pdf", replace
		
		*Ploting: Kurtosis		
		tw connected kurt${vari}all kurt${vari}1970 kurt${vari}1980 kurt${vari}2000 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Lifetime Income", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel( 6(6)30,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
	legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1970" 3 "1980/1990" 4 "2000/2010") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_kurt${vari}_FS_`sampl'_NL.pdf", replace
		
		
		tw connected cku${vari}all cku${vari}1970 cku${vari}1980 cku${vari}2000 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Crow-Siddiqui of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Lifetime Income", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
	legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1970" 3 "1980/1990" 4 "2000/2010") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_cku${vari}_FS_`sampl'_NL.pdf", replace
		
	}	
	
HERE	

/*
	Results for Dec 2021, sample of 25 age and 20 + 10 years of data
*/

global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaperLNG"	
foreach vv in 1 5{				   // or 5
	global vari = "researn`vv'F"  // Or 5F				
	*Load data 						
	insheet using "$maindir_fs${sep}results${sep}${voladata_fsDEC}${sep}L_${vari}_fsallrank_male.csv", clear case			
	local tlabel = "Men"
	local dlabel "Sons"
	local mclr = "navy"
	local llabel = "off"
	local sdlim = "0.55(0.1)0.85"
	local sdlim = ""
	

	if "${vari}" == "researn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,1}{sub:i,t}"			
	}		
	if "${vari}" == "researn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,5}{sub:i,t}"			
	}
	if "${vari}" == "arcearn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	}		
	if "${vari}" == "arcearn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	}

	*Calculate additional moments 
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	
	gen p9550${vari} = p95${vari} - p50${vari}
	gen p5005${vari} = p50${vari} - p5${vari}		
	
	gen p9950${vari} = p99${vari} - p50${vari}
	gen p5001${vari} = p50${vari} - p1${vari}
				
	gen p7525${vari} = p75${vari} - p25${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen kskP5${vari} = (p9550${vari} - p5005${vari})/(p95${vari} - p5${vari})			
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
	
	*We need to drop years before 1980 (or even earlier?) because less than 100 obs within a quantile
	drop if year < 1990 
	drop if year > 2012
	
	
	*Averagegin statistics over time 
	*This can be changed to seperate recession to expansion periods
	collapse  mean${vari}  p10${vari}  p50${vari}  p90${vari}  p9010${vari} p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank male)
	
	*Reshape to have a cleaner plot 
	reshape wide mean${vari}  p10${vari}  p50${vari}  p90${vari} p9010${vari}  p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  , i(fpermrank) j(male)
	*replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
	replace fpermrank = 2.5*fpermrank
	replace fpermrank = 101 if fpermrank == 102.5
	gen idex = _n 
	
	
	*P90-P50
	if `vv' == 1{
		local y1 = 0.32
		local x1 = 87.7
		local y2 = 0.32
		local x2 =  99			
		
		local labtext = "0.32 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 0.92
		local x1 = 87.7
		local y2 = 0.92
		local x2 =  99								
		local labtext = "0.92 87"
		local lsize = ""
	}
	
	tw (line p9050${vari}0  p9050${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p9050${vari}0  p9050${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P50 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p9050${vari}_FS_NLMW_Dec2021.pdf", replace	
	
	
	*P50-P10
	if `vv' == 1{
		local y1 = 0.28
		local x1 = 87.7
		local y2 = 0.28
		local x2 =  99			
		
		local labtext = "0.28 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 0.92
		local x1 = 87.7
		local y2 = 0.92
		local x2 =  99								
		local labtext = "0.92 87"
		local lsize = ""
	}
	
	tw (line p5010${vari}0  p5010${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5010${vari}0  p5010${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5010${vari}_FS_NLMW_Dec2021.pdf", replace
		
	
	*Average
	if `vv' == 1{
		local y1 = 0.02
		local x1 = 87.7
		local y2 = 0.02
		local x2 =  99			
		local y3 = .072
		local labtext = "0.02 87"
		local lsize = "-0.02(0.01)0.025"
	}
	if `vv' == 5{
		local y1 = 0.05
		local x1 = 87.7
		local y2 = 0.05
		local x2 =  99			
		local y3 = .072
		local labtext = "0.05 87"
		local lsize = ""
	}
		
	sum mean${vari}0
	replace mean${vari}0 = mean${vari}0 - r(mean)
	
	sum mean${vari}1
	replace mean${vari}1 =mean${vari}1 - r(mean)	
	tw (line mean${vari}0  mean${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter mean${vari}0 mean${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Average of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_mean${vari}_FS_NLMW_Dec2021.pdf", replace	
	
	
	if `vv' == 1{
		local y1 = 0.012
		local x1 = 87.7
		local y2 = 0.012
		local x2 =  99			
		local y3 = .072
		local labtext = "0.012 87"
		local lsize = ""
	}
	if `vv' == 5{
		local y1 = 0.05
		local x1 = 87.7
		local y2 = 0.05
		local x2 =  99			
		local y3 = .072
		local labtext = "0.05 87"
		local lsize = ""
	}
		
	sum p50${vari}0
	replace p50${vari}0 =p50${vari}0 - r(mean)
	
	sum p50${vari}1
	replace p50${vari}1 =p50${vari}1 - r(mean)	
				
	tw (line p50${vari}0  p50${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p50${vari}0 p50${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Median of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_p50${vari}_FS_NLMW_Dec2021.pdf", replace	
	
	
	*Ploting: Dispersion	
	if `vv' == 1{
		local y1 = 0.44
		local x1 = 87.7
		local y2 = 0.44
		local x2 =  99			
		local y3 = .072
		local labtext = "0.44 87"
		local lsize = "0.3(0.05)0.475"
	}
	if `vv' == 5{
		local y1 = 0.65
		local x1 = 87.7
		local y2 = 0.65
		local x2 =  99			
		local y3 = .072
		local labtext = "0.65 87"
		local lsize = ""
	}
	
					
	tw (line sd${vari}0  sd${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter sd${vari}0 sd${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Standard Deviation of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize',  angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_sd${vari}_FS_NLMW_Dec2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.60
		local x1 = 87.7
		local y2 = 0.60
		local x2 =  99			
		local labtext = "0.60 87"
		local lsize = "0.45(0.10)0.65"
	}
	if `vv' == 5{
		local y1 = 1.1
		local x1 = 87.7
		local y2 = 1.1
		local x2 =  99			
		local y3 = .072
		local labtext = "1.1 87"
		local lsize = ""
	}
	
	tw (line p9010${vari}0  p9010${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p9010${vari}0 p9010${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ) , ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_p9010${vari}_FS_NLMW_Dec2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.525
		local x1 = 87.7
		local y2 = 0.525
		local x2 =  99			
		
		local labtext = "0.525 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 0.92
		local x1 = 87.7
		local y2 = 0.92
		local x2 =  99								
		local labtext = "0.92 87"
		local lsize = ""
	}
	
	tw (line p5005${vari}0  p5005${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5005${vari}0  p5005${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P5 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5005${vari}_FS_NLMW_Dec2021.pdf", replace
	
	if `vv' == 1{
		local y1 = 0.575
		local x1 = 87.7
		local y2 = 0.575
		local x2 =  99			
		local y3 = .072
		local labtext = "0.575 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 0.93
		local x1 = 87.7
		local y2 = 0.93
		local x2 =  99								
		local labtext = "0.93 87"
		local lsize = ""
	}
	tw (line p9550${vari}0  p9550${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p9550${vari}0  p9550${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${legesize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P95-P50 of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_p9550${vari}_FS_NLMW_Dec2021.pdf", replace
	
	
	*Ploting: Skewness	
	if `vv' == 1{
		local y1 = -1.0
		local x1 = 87.75
		local y2 = -1.0
		local x2 =  99			
		local labtext = "-1.0 87"
	}
	if `vv' == 5{
		local y1 = -0.9
		local x1 = 87.75
		local y2 = -0.9
		local x2 =  99			
		local labtext = "-0.9 87"
	}
	tw (line skew${vari}0  skew${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter skew${vari}0 skew${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Skewness of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(-1.75(0.25)-0.75, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_skew${vari}_FS_NLMW_Dec2021.pdf", replace

	if `vv' == 1{
		local y1 = 0.082
		local x1 = 87.75
		local y2 = 0.082
		local x2 =  99			
		local labtext = "0.082 87"
	}
	if `vv' == 5{
		local y1 = 0.025
		local x1 = 87.75
		local y2 = 0.025
		local x2 =  99			
		local labtext = "0.025 87"
	}
	tw (line ksk${vari}0  ksk${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter ksk${vari}0 ksk${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", margin(r-2) color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_ksk${vari}_FS_NLMW_Dec2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.02
		local x1 = 87.75
		local y2 = 0.02
		local x2 =  99			
		local labtext = "0.02 87"
	}
	if `vv' == 5{
		local y1 = -0.01
		local x1 = 87.75
		local y2 = -0.01
		local x2 =  99			
		local labtext = "-0.01 87"
	}
	tw (line kskP5${vari}0  kskP5${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kskP5${vari}0 kskP5${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", margin(r-2) color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_kskP5${vari}_FS_NLMW_Dec2021.pdf", replace
		
	*Ploting: Kurtosis		
	if `vv' == 1{
		local y1 = 21.0
		local x1 = 87.75
		local y2 = 21.0
		local x2 =  99			
		local labtext = "21 87"
		local lsize = "20(6)42"
	}
	if `vv' == 5{
		local y1 = 13
		local x1 = 87.75
		local y2 = 13
		local x2 =  99			
		local labtext = "13 87"
		local lsize = ""
	}
	tw (line kurt${vari}0  kurt${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kurt${vari}0 kurt${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(7) region(color(none)))								
	graph export "${folderfile}/F5B_kurt${vari}_FS_NLMW_Dec2021.pdf", replace

	if `vv' == 1{
		local y1 = 9.5
		local x1 = 87.75
		local y2 = 9.5
		local x2 =  97			
		local labtext = "9.5 87"
		local lsize = "9.5(0.5)11.5"
	}
	if `vv' == 5{
		local y1 = 7
		local x1 = 87.75
		local y2 = 7
		local x2 =  97			
		local labtext = "7 87"
		local lsize = ""
	}
	tw (line cku${vari}0  cku${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter cku${vari}0 cku${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Crow-Siddiqui Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) ///
	xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_cku${vari}_FS_NLMW_Dec2021.pdf", replace
	
}


*SECTION WITH WEALTH WITH NEW DEC DATA 
foreach vv in 1 5{				   // or 5
	global vari = "researn`vv'F"  // Or 5F				
	*Load data 						
	insheet using "$maindir_fs${sep}results${sep}${woladata_fsDEC}${sep}stats_LTwlt_f_${vari}_fsallrank_male.csv", clear case				
	local tlabel = "Men"
	local dlabel "Sons"
	local mclr = "navy"
	local llabel = "off"
	local sdlim = "0.55(0.1)0.85"
	local sdlim = ""
	

	if "${vari}" == "researn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,1}{sub:i,t}"			
	}		
	if "${vari}" == "researn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,5}{sub:i,t}"			
	}
	if "${vari}" == "arcearn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	}		
	if "${vari}" == "arcearn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	}

	*Calculate additional moments 
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	
	gen p9550${vari} = p95${vari} - p50${vari}
	gen p5005${vari} = p50${vari} - p5${vari}		
	
	gen p9950${vari} = p99${vari} - p50${vari}
	gen p5001${vari} = p50${vari} - p1${vari}
				
	gen p7525${vari} = p75${vari} - p25${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen kskP5${vari} = (p9550${vari} - p5005${vari})/(p95${vari} - p5${vari})			
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
	
	*We need to drop years before 1980 (or even earlier?) because less than 100 obs within a quantile
	drop if year < 1990 
	drop if year > 2012
	
	
	*Averagegin statistics over time 
	*This can be changed to seperate recession to expansion periods
	collapse  mean${vari}  p10${vari}  p50${vari}  p90${vari}  p9010${vari} p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank male)
	
	*Reshape to have a cleaner plot 
	reshape wide mean${vari}  p10${vari}  p50${vari}  p90${vari} p9010${vari}  p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  , i(fpermrank) j(male)
	*replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
	replace fpermrank = 2.5*fpermrank
	replace fpermrank = 101 if fpermrank == 102.5
	gen idex = _n 
	
	
	*P90-P50
	if `vv' == 1{
		local y1 = 0.315
		local x1 = 87.7
		local y2 = 0.315
		local x2 =  99			
		
		local labtext = "0.315 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 1.0
		local x1 = 87.7
		local y2 = 1.0
		local x2 =  99								
		local labtext = "1.0 87"
		local lsize = ""
	}
	
	tw (line p9050${vari}0  p9050${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5010${vari}0  p5010${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P50 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p9050${vari}_LTwlt_NLMW_Dec2021.pdf", replace
	
	*P50-P10
	if `vv' == 1{
		local y1 = 0.3
		local x1 = 87.7
		local y2 = 0.3
		local x2 =  99			
		
		local labtext = "0.3 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 1.0
		local x1 = 87.7
		local y2 = 1.0
		local x2 =  99								
		local labtext = "1.0 87"
		local lsize = ""
	}
	
	tw (line p5010${vari}0  p5010${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5010${vari}0  p5010${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5010${vari}_LTwlt_NLMW_Dec2021.pdf", replace
		
	
	*Average
	if `vv' == 1{
		local y1 = -0.0025
		local x1 = 87.7
		local y2 = -0.0025
		local x2 =  99			
		local y3 = .072
		local labtext = "-0.0025 87"
		local lsize = "-0.02(0.01)0.015"
	}
	if `vv' == 5{
		local y1 = -0.0025
		local x1 = 87.7
		local y2 = -0.0025
		local x2 =  99			
		local y3 = .072
		local labtext = "-0.0025 87"
		local lsize = ""
	}
		
	sum mean${vari}0
	replace mean${vari}0 =mean${vari}0 - r(mean)
	
	sum mean${vari}1
	replace mean${vari}1 =mean${vari}1 - r(mean)	
				
	tw (line mean${vari}0  mean${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter mean${vari}0 mean${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Average of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize',angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))	
	graph export "${folderfile}/F5B_mean${vari}_LTwlt_NLMW_Dec2021.pdf", replace		
	
	*Median
	if `vv' == 1{
		local y1 = 0.004
		local x1 = 87.7
		local y2 = 0.004
		local x2 =  99			
		local y3 = .072
		local labtext = "0.004 87"
		local lsize = "-0.005(0.0025)0.005"
	}
	if `vv' == 5{
		local y1 = 0.02
		local x1 = 87.7
		local y2 = 0.02
		local x2 =  99			
		local y3 = .072
		local labtext = "0.02 87"
		local lsize = ""
	}
		
	sum p50${vari}0
	replace p50${vari}0 =p50${vari}0 - r(mean)
	
	sum p50${vari}1
	replace p50${vari}1 =p50${vari}1 - r(mean)	
				
	tw (line p50${vari}0  p50${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p50${vari}0 p50${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Median of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))	
	graph export "${folderfile}/F5B_p50${vari}_LTwlt_NLMW_Dec2021.pdf", replace		
			
	*Ploting: Dispersion	
	if `vv' == 1{
		local y1 = 0.45
		local x1 = 87.7
		local y2 = 0.45
		local x2 =  99			
		local y3 = .072
		local labtext = "0.45 87"
		local lsize = "0.3(0.05)0.475"
	}
	if `vv' == 5{
		local y1 = 0.68
		local x1 = 87.7
		local y2 = 0.68
		local x2 =  99			
		local y3 = .072
		local labtext = "0.68 87"		
		local lsize = ""
	}
	
					
	tw (line sd${vari}0  sd${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter sd${vari}0 sd${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Standard Deviation of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_sd${vari}_LTwlt_NLMW_Dec2021.pdf", replace
	
	if `vv' == 1{
		local y1 = 0.60
		local x1 = 87.7
		local y2 = 0.60
		local x2 =  99			
		local labtext = "0.60 87"
		local lsize = "0.45(0.10)0.65"
	}
	if `vv' == 5{
		local y1 = 1.15
		local x1 = 87.7
		local y2 = 1.15
		local x2 =  99			
		local labtext = "1.15 87"
		local lsize = ""
	}
	
	tw (line p9010${vari}0  p9010${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p9010${vari}0 p9010${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ) , ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_p9010${vari}_LTwlt_NLMW_Dec2021.pdf", replace				
		
	if `vv' == 1{
		local y1 = 0.55
		local x1 = 87.7
		local y2 = 0.55
		local x2 =  99			
		
		local labtext = "0.55 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 1.0
		local x1 = 87.7
		local y2 = 1.0
		local x2 =  99								
		local labtext = "1.0 87"
		local lsize = ""
	}
	
	tw (line p5005${vari}0  p5005${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5005${vari}0  p5005${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P5 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5005${vari}_LTwlt_NLMW_Dec2021.pdf", replace
	
	if `vv' == 1{
		local y1 = 0.6
		local x1 = 87.7
		local y2 = 0.6
		local x2 =  99			
		local y3 = .072
		local labtext = "0.6 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 0.95
		local x1 = 87.7
		local y2 = 0.95
		local x2 =  99								
		local labtext = "0.95 87"
		local lsize = ""
	}
	tw (line p9550${vari}0  p9550${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p9550${vari}0  p9550${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${legesize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P95-P50 of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_p9550${vari}_LTwlt_NLMW_Dec2021.pdf", replace
	
	
	*Ploting: Skewness	
	if `vv' == 1{
		local y1 = -1.0
		local x1 = 87.75
		local y2 = -1.0
		local x2 =  99			
		local labtext = "-1.0 87"
	}
	if `vv' == 5{
		local y1 = -1.25
		local x1 = 87.75
		local y2 = -1.25
		local x2 =  99			
		local labtext = "-1.25 87"
	}
	tw (line skew${vari}0  skew${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter skew${vari}0 skew${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Skewness of `labtitle'", margin(r-2) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(-1.75(0.25)-0.75, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_skew${vari}_LTwlt_NLMW_Dec2021.pdf", replace

	if `vv' == 1{
		local y1 = 0.038
		local x1 = 87.75
		local y2 = 0.038
		local x2 =  99			
		local labtext = "0.038 87"
	}
	if `vv' == 5{
		local y1 = 0.0
		local x1 = 87.75
		local y2 = 0.0
		local x2 =  99			
		local labtext = "0.0 87"
	}
	tw (line ksk${vari}0  ksk${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter ksk${vari}0 ksk${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(,  angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_ksk${vari}_LTwlt_NLMW_Dec2021.pdf", replace
	oooo
	
	if `vv' == 1{
		local y1 = 0.02
		local x1 = 87.75
		local y2 = 0.02
		local x2 =  99			
		local labtext = "0.02 87"
	}
	if `vv' == 5{
		local y1 = 0.2
		local x1 = 87.75
		local y2 = 0.2
		local x2 =  99			
		local labtext = "0.2 87"
	}
	tw (line kskP5${vari}0  kskP5${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kskP5${vari}0 kskP5${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", margin(r-3) color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_kskP5${vari}_LTwlt_NLMW_Dec2021.pdf", replace
			
	*Ploting: Kurtosis		
	if `vv' == 1{
		local y1 = 26.0
		local x1 = 87.75
		local y2 = 26.0
		local x2 =  99			
		local labtext = "26 87"
		local lsize = "20(6)42"
	}
	if `vv' == 5{
		local y1 = 12.0
		local x1 = 87.75
		local y2 = 12.0
		local x2 =  99			
		local labtext = "12 87"
		local lsize = ""
	}
	tw (line kurt${vari}0  kurt${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kurt${vari}0 kurt${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(7) region(color(none)))								
	graph export "${folderfile}/F5B_kurt${vari}_LTwlt_NLMW_Dec2021.pdf", replace

	if `vv' == 1{
		local y1 = 9.5
		local x1 = 87.75
		local y2 = 9.5
		local x2 =  97			
		local labtext = "9.5 87"
		local lsize = "9.5(0.5)11.5"
	}
	if `vv' == 5{
		local y1 = 7.0
		local x1 = 87.75
		local y2 = 7.0
		local x2 =  97			
		local labtext = "7.0 87"
		local lsize = ""
	}
	tw (line cku${vari}0  cku${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter cku${vari}0 cku${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Crow-Siddiqui Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_cku${vari}_LTwlt_NLMW_Dec2021.pdf", replace	
	
}
	
OOOO

/*
*PLOTS WITH INCOME AND WEALTH PERCENTILES OF FATHERS IN THE X AXIS AND MOMENTS OF THE 
GROWTH DISTRIBUTION IN THE Y AXIS
*/
ddd
global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaperLNG"	
foreach vv in 1 5{				   // or 5
	global vari = "researn`vv'F"  // Or 5F				
	*Load data 						
	insheet using "$maindir_fs${sep}results${sep}${voladata_fs}${sep}L_${vari}_fsallrank_male.csv", clear case			
	local tlabel = "Men"
	local dlabel "Sons"
	local mclr = "navy"
	local llabel = "off"
	local sdlim = "0.55(0.1)0.85"
	local sdlim = ""
	

	if "${vari}" == "researn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,1}{sub:i,t}"			
	}		
	if "${vari}" == "researn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,5}{sub:i,t}"			
	}
	if "${vari}" == "arcearn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	}		
	if "${vari}" == "arcearn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	}

	*Calculate additional moments 
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	
	gen p9550${vari} = p95${vari} - p50${vari}
	gen p5005${vari} = p50${vari} - p5${vari}		
	
	gen p9950${vari} = p99${vari} - p50${vari}
	gen p5001${vari} = p50${vari} - p1${vari}
				
	gen p7525${vari} = p75${vari} - p25${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen kskP5${vari} = (p9550${vari} - p5005${vari})/(p95${vari} - p5${vari})			
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
	
	*We need to drop years before 1980 (or even earlier?) because less than 100 obs within a quantile
	drop if year < 1990 
	drop if year > 2012
	
	
	*Averagegin statistics over time 
	*This can be changed to seperate recession to expansion periods
	collapse  mean${vari}  p10${vari}  p50${vari}  p90${vari}  p9010${vari} p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank male)
	
	*Reshape to have a cleaner plot 
	reshape wide mean${vari}  p10${vari}  p50${vari}  p90${vari} p9010${vari}  p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  , i(fpermrank) j(male)
	*replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
	replace fpermrank = 2.5*fpermrank
	replace fpermrank = 101 if fpermrank == 102.5
	gen idex = _n 
	
	
	*P90-P50
	if `vv' == 1{
		local y1 = 0.32
		local x1 = 87.7
		local y2 = 0.32
		local x2 =  99			
		
		local labtext = "0.32 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 0.92
		local x1 = 87.7
		local y2 = 0.92
		local x2 =  99								
		local labtext = "0.92 87"
		local lsize = ""
	}
	
	tw (line p9050${vari}0  p9050${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p9050${vari}0  p9050${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P50 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p9050${vari}_FS_NLMW_N2021.pdf", replace	
	
	
	*P50-P10
	if `vv' == 1{
		local y1 = 0.28
		local x1 = 87.7
		local y2 = 0.28
		local x2 =  99			
		
		local labtext = "0.28 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 0.92
		local x1 = 87.7
		local y2 = 0.92
		local x2 =  99								
		local labtext = "0.92 87"
		local lsize = ""
	}
	
	tw (line p5010${vari}0  p5010${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5010${vari}0  p5010${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5010${vari}_FS_NLMW_N2021.pdf", replace
		sss
	
	*Average
	if `vv' == 1{
		local y1 = 0.02
		local x1 = 87.7
		local y2 = 0.02
		local x2 =  99			
		local y3 = .072
		local labtext = "0.02 87"
		local lsize = "-0.02(0.01)0.025"
	}
	if `vv' == 5{
		local y1 = 0.05
		local x1 = 87.7
		local y2 = 0.05
		local x2 =  99			
		local y3 = .072
		local labtext = "0.05 87"
		local lsize = ""
	}
		
	sum mean${vari}0
	replace mean${vari}0 = mean${vari}0 - r(mean)
	
	sum mean${vari}1
	replace mean${vari}1 =mean${vari}1 - r(mean)	
	tw (line mean${vari}0  mean${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter mean${vari}0 mean${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Average of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_mean${vari}_FS_NLMW_N2021.pdf", replace	
	
	
	if `vv' == 1{
		local y1 = 0.012
		local x1 = 87.7
		local y2 = 0.012
		local x2 =  99			
		local y3 = .072
		local labtext = "0.012 87"
		local lsize = ""
	}
	if `vv' == 5{
		local y1 = 0.05
		local x1 = 87.7
		local y2 = 0.05
		local x2 =  99			
		local y3 = .072
		local labtext = "0.05 87"
		local lsize = ""
	}
		
	sum p50${vari}0
	replace p50${vari}0 =p50${vari}0 - r(mean)
	
	sum p50${vari}1
	replace p50${vari}1 =p50${vari}1 - r(mean)	
				
	tw (line p50${vari}0  p50${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p50${vari}0 p50${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Median of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_p50${vari}_FS_NLMW_N2021.pdf", replace	
	
	
	*Ploting: Dispersion	
	if `vv' == 1{
		local y1 = 0.44
		local x1 = 87.7
		local y2 = 0.44
		local x2 =  99			
		local y3 = .072
		local labtext = "0.44 87"
		local lsize = "0.3(0.05)0.475"
	}
	if `vv' == 5{
		local y1 = 0.65
		local x1 = 87.7
		local y2 = 0.65
		local x2 =  99			
		local y3 = .072
		local labtext = "0.65 87"
		local lsize = ""
	}
	
					
	tw (line sd${vari}0  sd${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter sd${vari}0 sd${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Standard Deviation of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize',  angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_sd${vari}_FS_NLMW_N2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.60
		local x1 = 87.7
		local y2 = 0.60
		local x2 =  99			
		local labtext = "0.60 87"
		local lsize = "0.45(0.10)0.65"
	}
	if `vv' == 5{
		local y1 = 1.1
		local x1 = 87.7
		local y2 = 1.1
		local x2 =  99			
		local y3 = .072
		local labtext = "1.1 87"
		local lsize = ""
	}
	
	tw (line p9010${vari}0  p9010${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p9010${vari}0 p9010${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ) , ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_p9010${vari}_FS_NLMW_N2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.525
		local x1 = 87.7
		local y2 = 0.525
		local x2 =  99			
		
		local labtext = "0.525 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 0.92
		local x1 = 87.7
		local y2 = 0.92
		local x2 =  99								
		local labtext = "0.92 87"
		local lsize = ""
	}
	
	tw (line p5005${vari}0  p5005${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5005${vari}0  p5005${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P5 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5005${vari}_FS_NLMW_N2021.pdf", replace
	
	if `vv' == 1{
		local y1 = 0.575
		local x1 = 87.7
		local y2 = 0.575
		local x2 =  99			
		local y3 = .072
		local labtext = "0.575 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 0.93
		local x1 = 87.7
		local y2 = 0.93
		local x2 =  99								
		local labtext = "0.93 87"
		local lsize = ""
	}
	tw (line p9550${vari}0  p9550${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p9550${vari}0  p9550${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${legesize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P95-P50 of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_p9550${vari}_FS_NLMW_N2021.pdf", replace
	
	
	*Ploting: Skewness	
	if `vv' == 1{
		local y1 = -1.0
		local x1 = 87.75
		local y2 = -1.0
		local x2 =  99			
		local labtext = "-1.0 87"
	}
	if `vv' == 5{
		local y1 = -0.9
		local x1 = 87.75
		local y2 = -0.9
		local x2 =  99			
		local labtext = "-0.9 87"
	}
	tw (line skew${vari}0  skew${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter skew${vari}0 skew${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Skewness of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(-1.75(0.25)-0.75, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_skew${vari}_FS_NLMW_N2021.pdf", replace

	if `vv' == 1{
		local y1 = 0.082
		local x1 = 87.75
		local y2 = 0.082
		local x2 =  99			
		local labtext = "0.082 87"
	}
	if `vv' == 5{
		local y1 = 0.025
		local x1 = 87.75
		local y2 = 0.025
		local x2 =  99			
		local labtext = "0.025 87"
	}
	tw (line ksk${vari}0  ksk${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter ksk${vari}0 ksk${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", margin(r-2) color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_ksk${vari}_FS_NLMW_N2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.02
		local x1 = 87.75
		local y2 = 0.02
		local x2 =  99			
		local labtext = "0.02 87"
	}
	if `vv' == 5{
		local y1 = -0.01
		local x1 = 87.75
		local y2 = -0.01
		local x2 =  99			
		local labtext = "-0.01 87"
	}
	tw (line kskP5${vari}0  kskP5${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kskP5${vari}0 kskP5${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", margin(r-2) color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_kskP5${vari}_FS_NLMW_N2021.pdf", replace
		
	*Ploting: Kurtosis		
	if `vv' == 1{
		local y1 = 21.0
		local x1 = 87.75
		local y2 = 21.0
		local x2 =  99			
		local labtext = "21 87"
		local lsize = "20(6)42"
	}
	if `vv' == 5{
		local y1 = 13
		local x1 = 87.75
		local y2 = 13
		local x2 =  99			
		local labtext = "13 87"
		local lsize = ""
	}
	tw (line kurt${vari}0  kurt${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kurt${vari}0 kurt${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(7) region(color(none)))								
	graph export "${folderfile}/F5B_kurt${vari}_FS_NLMW_N2021.pdf", replace

	if `vv' == 1{
		local y1 = 9.5
		local x1 = 87.75
		local y2 = 9.5
		local x2 =  97			
		local labtext = "9.5 87"
		local lsize = "9.5(0.5)11.5"
	}
	if `vv' == 5{
		local y1 = 7
		local x1 = 87.75
		local y2 = 7
		local x2 =  97			
		local labtext = "7 87"
		local lsize = ""
	}
	tw (line cku${vari}0  cku${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter cku${vari}0 cku${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Crow-Siddiqui Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Lifetime Income, LI{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of LI{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_cku${vari}_FS_NLMW_N2021.pdf", replace
	
}


// END of section with income		

*SECTION WITH WEALTH
foreach vv in 1 5{				   // or 5
	global vari = "researn`vv'F"  // Or 5F				
	*Load data 						
	insheet using "$maindir_fs${sep}results${sep}${woladata_fs}${sep}stats_LTwlt_f_${vari}_fsallrank_male.csv", clear case				
	local tlabel = "Men"
	local dlabel "Sons"
	local mclr = "navy"
	local llabel = "off"
	local sdlim = "0.55(0.1)0.85"
	local sdlim = ""
	

	if "${vari}" == "researn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,1}{sub:i,t}"			
	}		
	if "${vari}" == "researn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	local labtitle = "g{sup:I,5}{sub:i,t}"			
	}
	if "${vari}" == "arcearn1F"{
	local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
	}		
	if "${vari}" == "arcearn5F"{
	local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
	}

	*Calculate additional moments 
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	
	gen p9550${vari} = p95${vari} - p50${vari}
	gen p5005${vari} = p50${vari} - p5${vari}		
	
	gen p9950${vari} = p99${vari} - p50${vari}
	gen p5001${vari} = p50${vari} - p1${vari}
				
	gen p7525${vari} = p75${vari} - p25${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen kskP5${vari} = (p9550${vari} - p5005${vari})/(p95${vari} - p5${vari})			
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
	
	*We need to drop years before 1980 (or even earlier?) because less than 100 obs within a quantile
	drop if year < 1990 
	drop if year > 2012
	
	
	*Averagegin statistics over time 
	*This can be changed to seperate recession to expansion periods
	collapse  mean${vari}  p10${vari}  p50${vari}  p90${vari}  p9010${vari} p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank male)
	
	*Reshape to have a cleaner plot 
	reshape wide mean${vari}  p10${vari}  p50${vari}  p90${vari} p9010${vari}  p9050${vari} p5010${vari}  ///
		p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
		sd${vari} ksk${vari} kskP5${vari} skew${vari} cku${vari} kurt${vari}  , i(fpermrank) j(male)
	*replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
	replace fpermrank = 2.5*fpermrank
	replace fpermrank = 101 if fpermrank == 102.5
	gen idex = _n 
	
	
	*P90-P50
	if `vv' == 1{
		local y1 = 0.315
		local x1 = 87.7
		local y2 = 0.315
		local x2 =  99			
		
		local labtext = "0.315 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 1.0
		local x1 = 87.7
		local y2 = 1.0
		local x2 =  99								
		local labtext = "1.0 87"
		local lsize = ""
	}
	
	tw (line p9050${vari}0  p9050${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5010${vari}0  p5010${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P50 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p9050${vari}_LTwlt_NLMW_N2021.pdf", replace
	
	*P50-P10
	if `vv' == 1{
		local y1 = 0.3
		local x1 = 87.7
		local y2 = 0.3
		local x2 =  99			
		
		local labtext = "0.3 87"
		local lsize = "0.15(0.05)0.35"
	}
	if `vv' == 5{
		local y1 = 1.0
		local x1 = 87.7
		local y2 = 1.0
		local x2 =  99								
		local labtext = "1.0 87"
		local lsize = ""
	}
	
	tw (line p5010${vari}0  p5010${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5010${vari}0  p5010${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5010${vari}_LTwlt_NLMW_N2021.pdf", replace
		sss
	
	*Average
	if `vv' == 1{
		local y1 = -0.0025
		local x1 = 87.7
		local y2 = -0.0025
		local x2 =  99			
		local y3 = .072
		local labtext = "-0.0025 87"
		local lsize = "-0.02(0.01)0.015"
	}
	if `vv' == 5{
		local y1 = -0.0025
		local x1 = 87.7
		local y2 = -0.0025
		local x2 =  99			
		local y3 = .072
		local labtext = "-0.0025 87"
		local lsize = ""
	}
		
	sum mean${vari}0
	replace mean${vari}0 =mean${vari}0 - r(mean)
	
	sum mean${vari}1
	replace mean${vari}1 =mean${vari}1 - r(mean)	
				
	tw (line mean${vari}0  mean${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter mean${vari}0 mean${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Average of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize',angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))	
	graph export "${folderfile}/F5B_mean${vari}_LTwlt_NLMW_N2021.pdf", replace		
	
	*Median
	if `vv' == 1{
		local y1 = 0.004
		local x1 = 87.7
		local y2 = 0.004
		local x2 =  99			
		local y3 = .072
		local labtext = "0.004 87"
		local lsize = "-0.005(0.0025)0.005"
	}
	if `vv' == 5{
		local y1 = 0.02
		local x1 = 87.7
		local y2 = 0.02
		local x2 =  99			
		local y3 = .072
		local labtext = "0.02 87"
		local lsize = ""
	}
		
	sum p50${vari}0
	replace p50${vari}0 =p50${vari}0 - r(mean)
	
	sum p50${vari}1
	replace p50${vari}1 =p50${vari}1 - r(mean)	
				
	tw (line p50${vari}0  p50${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p50${vari}0 p50${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Median of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))	
	graph export "${folderfile}/F5B_p50${vari}_LTwlt_NLMW_N2021.pdf", replace		
			
	*Ploting: Dispersion	
	if `vv' == 1{
		local y1 = 0.45
		local x1 = 87.7
		local y2 = 0.45
		local x2 =  99			
		local y3 = .072
		local labtext = "0.45 87"
		local lsize = "0.3(0.05)0.475"
	}
	if `vv' == 5{
		local y1 = 0.68
		local x1 = 87.7
		local y2 = 0.68
		local x2 =  99			
		local y3 = .072
		local labtext = "0.68 87"		
		local lsize = ""
	}
	
					
	tw (line sd${vari}0  sd${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter sd${vari}0 sd${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Standard Deviation of `labtitle'", margin(r-3) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_sd${vari}_LTwlt_NLMW_N2021.pdf", replace
	
	if `vv' == 1{
		local y1 = 0.60
		local x1 = 87.7
		local y2 = 0.60
		local x2 =  99			
		local labtext = "0.60 87"
		local lsize = "0.45(0.10)0.65"
	}
	if `vv' == 5{
		local y1 = 1.15
		local x1 = 87.7
		local y2 = 1.15
		local x2 =  99			
		local labtext = "1.15 87"
		local lsize = ""
	}
	
	tw (line p9010${vari}0  p9010${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter p9010${vari}0 p9010${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ) , ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P90-P10 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))							
	graph export "${folderfile}/F5B_p9010${vari}_LTwlt_NLMW_N2021.pdf", replace				
		
	if `vv' == 1{
		local y1 = 0.55
		local x1 = 87.7
		local y2 = 0.55
		local x2 =  99			
		
		local labtext = "0.55 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 1.0
		local x1 = 87.7
		local y2 = 1.0
		local x2 =  99								
		local labtext = "1.0 87"
		local lsize = ""
	}
	
	tw (line p5005${vari}0  p5005${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p5005${vari}0  p5005${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P50-P5 of `labtitle'", color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_p5005${vari}_LTwlt_NLMW_N2021.pdf", replace
	
	if `vv' == 1{
		local y1 = 0.6
		local x1 = 87.7
		local y2 = 0.6
		local x2 =  99			
		local y3 = .072
		local labtext = "0.6 87"
		local lsize = "0.35(0.05)0.65"
	}
	if `vv' == 5{
		local y1 = 0.95
		local x1 = 87.7
		local y2 = 0.95
		local x2 =  99								
		local labtext = "0.95 87"
		local lsize = ""
	}
	tw (line p9550${vari}0  p9550${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   dash   dash   longdash   longdash )) ///
	(scatter p9550${vari}0  p9550${vari}1 fpermrank if idex==41, ///
	color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${legesize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("P95-P50 of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_p9550${vari}_LTwlt_NLMW_N2021.pdf", replace
	
	
	*Ploting: Skewness	
	if `vv' == 1{
		local y1 = -1.0
		local x1 = 87.75
		local y2 = -1.0
		local x2 =  99			
		local labtext = "-1.0 87"
	}
	if `vv' == 5{
		local y1 = -1.25
		local x1 = 87.75
		local y2 = -1.25
		local x2 =  99			
		local labtext = "-1.25 87"
	}
	tw (line skew${vari}0  skew${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter skew${vari}0 skew${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Skewness of `labtitle'", margin(r-2) color(black) size(${legesize})) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(-1.75(0.25)-0.75, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))								
	graph export "${folderfile}/F5B_skew${vari}_LTwlt_NLMW_N2021.pdf", replace

	if `vv' == 1{
		local y1 = 0.028
		local x1 = 87.75
		local y2 = 0.028
		local x2 =  99			
		local labtext = "0.028 87"
	}
	if `vv' == 5{
		local y1 = 0.0
		local x1 = 87.75
		local y2 = 0.0
		local x2 =  99			
		local labtext = "0.0 87"
	}
	tw (line ksk${vari}0  ksk${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter ksk${vari}0 ksk${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(,  angle(360)  labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_ksk${vari}_LTwlt_NLMW_N2021.pdf", replace
	
	
	if `vv' == 1{
		local y1 = 0.02
		local x1 = 87.75
		local y2 = 0.02
		local x2 =  99			
		local labtext = "0.02 87"
	}
	if `vv' == 5{
		local y1 = 0.2
		local x1 = 87.75
		local y2 = 0.2
		local x2 =  99			
		local labtext = "0.2 87"
	}
	tw (line kskP5${vari}0  kskP5${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kskP5${vari}0 kskP5${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kelley Skewness of `labtitle'", margin(r-3) color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_kskP5${vari}_LTwlt_NLMW_N2021.pdf", replace
			
	*Ploting: Kurtosis		
	if `vv' == 1{
		local y1 = 26.0
		local x1 = 87.75
		local y2 = 26.0
		local x2 =  99			
		local labtext = "26 87"
		local lsize = "20(6)42"
	}
	if `vv' == 5{
		local y1 = 12.0
		local x1 = 87.75
		local y2 = 12.0
		local x2 =  99			
		local labtext = "12 87"
		local lsize = ""
	}
	tw (line kurt${vari}0  kurt${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter kurt${vari}0 kurt${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(7) region(color(none)))								
	graph export "${folderfile}/F5B_kurt${vari}_LTwlt_NLMW_N2021.pdf", replace

	if `vv' == 1{
		local y1 = 9.5
		local x1 = 87.75
		local y2 = 9.5
		local x2 =  97			
		local labtext = "9.5 87"
		local lsize = "9.5(0.5)11.5"
	}
	if `vv' == 5{
		local y1 = 7.0
		local x1 = 87.75
		local y2 = 7.0
		local x2 =  97			
		local labtext = "7.0 87"
		local lsize = ""
	}
	tw (line cku${vari}0  cku${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
	color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
	lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
	(scatter cku${vari}0 cku${vari}1 fpermrank if idex==41, ///
	color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
	(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
	graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
	ytitle("Crow-Siddiqui Kurtosis of `labtitle'", color(black) size(large)) ///
	xtitle("Quantiles of Fathers' Net Wealth, W{sub:i,c}", color(black) size(large)) title("", color(black) size(large)) ///
	ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
	text(`labtext' "Top 1% of W{sub:i,c}", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
	legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))									
	graph export "${folderfile}/F5B_cku${vari}_LTwlt_NLMW_N2021.pdf", replace
	ssss
	
}
	
	
		stop
		 
*****
	
	
*Figure 1: Income Level Ranks (Probably here we want a rank-rank)
	foreach mm in men women {
		
		insheet using "$maindir_fs${sep}out${sep}${bindata}${sep}bs_`mm'_LTinc.csv", clear 			
		drop if ltinc_f >2
		tw (scatter ltinc ltinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess ltinc ltinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Children Residual Lifetime Income", color(black) size(vlarge)) ///
		xtitle("Fathers' Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(1(0.1)1.4,labsize(large)) xlabel(0.25(0.25)2,labsize(large))
		graph export "${folderfile}/F1A_LTinc_`mm'.pdf", replace 	
		
	}
	
	*Binscatter using three years
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	foreach mm in men women {
		insheet using "$maindir_fs${sep}out${sep}${bindata3yrs}${sep}bs_3yrs_`mm'_LTinc.csv", clear 			
		drop if ltinc_f >2
		
		if "`mm'" == "men"{
			local nlabel = "Sons"
		}
		else{
			local nlabel = "Daughter"
		}
		
		tw (scatter ltinc ltinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess ltinc ltinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("`nlabel'' Residual Lifetime Income", color(black) size(vlarge)) ///
		xtitle("Fathers' Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(0.8(0.1)1.2,labsize(vlarge)) xlabel(0(0.5)2,labsize(vlarge))
		graph export "${folderfile}/F1A_3yrs_LTinc_`mm'.pdf", replace 	
	}
	
	
	*Binscatters using the 25 age
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	foreach mm in men women {
		insheet using "$maindir_fs${sep}out${sep}${bindatamin25}${sep}bs_3yrs_`mm'_LTinc.csv", clear 			
		drop if ltinc_f >2
		
		if "`mm'" == "men"{
			local nlabel = "Sons"
		}
		else{
			local nlabel = "Daughter"
		}
		
		tw (scatter ltinc ltinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess ltinc ltinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("`nlabel''s Residual Lifetime Income", color(black) size(vlarge)) ///
		xtitle("Fathers' Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(0.9(0.1)1.4,labsize(vlarge)) xlabel(0.0(0.25)2,labsize(vlarge))
		graph export "${folderfile}/F1A_25age_LTinc_`mm'.pdf", replace 	
	}
	
	*Binscatters using the 23 age (RESULTS IN OLD VERSION OF PAPER)
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	foreach mm in men women {
		insheet using "$maindir_fs${sep}out${sep}${bindatamin23_norm}${sep}bs_3yrs_`mm'_LTinc.csv", clear 					
		if "`mm'" == "men"{
			local nlabel = "Sons"
		}
		else{
			local nlabel = "Daughter"
		}
		
		tw (scatter ltinc ltinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess ltinc ltinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("`nlabel''s Residual Lifetime Income", color(black) size(vlarge)) ///
		xtitle("Fathers' Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(0.9(0.1)1.55,labsize(vlarge)) xlabel(0.0(0.5)3,labsize(vlarge))	
		graph export "${folderfile}/F1A_23age_LTinc_`mm'.pdf", replace 	
	}
	
		
	*Binscatters using the 23 age (RESULTS DECEMBER DATA)
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	foreach mm in men women {
		insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC}${sep}bs_3yrs_`mm'_LTinc.csv", clear 					
		if "`mm'" == "men"{
			local nlabel = "Sons"
		}
		else{
			local nlabel = "Daughter"
		}
		
		tw (scatter ltinc ltinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess ltinc ltinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("`nlabel''s Residual Lifetime Income", color(black) size(vlarge)) ///
		xtitle("Fathers' Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(0.8(0.2)1.6,labsize(vlarge)) xlabel(0.0(0.5)3,labsize(vlarge))			
		ddd
		graph export "${folderfile}/F1A_23age_LTinc_`mm'_Dec2021.pdf", replace 			
	}
	
	foreach mm in men women   {
		insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC}${sep}bs_3yrs_`mm'_lLTinc.csv", clear 	case				
		if "`mm'" == "men"{
			local nlabel = "Sons"
		}
		else{
			local nlabel = "Daughter"
		}
		
		tw (scatter lLTinc lLTinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess lLTinc lLTinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Log Residual Lifetime Income",  color(black) size(vlarge)) ///
		xtitle("Fathers' Log Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(-0.4(0.2)0.2,angle(360) labsize(vlarge)) xlabel(-1.5(0.5)1,labsize(vlarge))			
		graph export "${folderfile}/F1A_23age_lLTinc_`mm'_Dec2021.pdf", replace 			
		
	}
	
	
	
	foreach mm in men women   {
		insheet using "$maindir_fs/results/Dec 1 2021/1 Dec 2021 IndReg_EDUCBASE_20/Rank_Rank_male_FatherSon.csv", clear case
		keep if vari == "lLTinc"
		if "`mm'" == "men"{
			local nlabel = "Sons"
			keep if male ==1 
		}
		else{
			local nlabel = "Daughter"
			keep if male ==0
		}
		
		tw (scatter meanrankt rankt_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess meanrankt rankt_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Average `nlabel's' rank", color(black) size(vlarge)) ///
		xtitle("Fathers' Lifetime Income Rank", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(,labsize(vlarge)) xlabel(,labsize(vlarge))		
		ddd
		graph export "${folderfile}/F1A_23age_RANK_lLTinc_`mm'_Dec2021.pdf", replace 			
		
	}
	
	
	 
	
	*RESULTS ON NOV/DEC 2021 VERSION OF THE PAPER 
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	global datafol = "/Users/ssalgado/Dropbox/NORWAY_QE/STATAFS/results/Dec 1 2021/1 Dec 2021 IndReg_EDUCBASE_20"
	foreach mm in men women {
		insheet using "${datafol}/bs_3yrs_`mm'_LTinc.csv", clear 			
// 		drop if ltinc_f >2
		
		if "`mm'" == "men"{
			local nlabel = "Sons"
		}
		else{
			local nlabel = "Daughter"
		}
		
		tw (scatter ltinc ltinc_f, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
		(lowess ltinc ltinc_f, color(maroon) lpattern(dash) lwidth(thick)) , ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("`nlabel''s Residual Lifetime Income", color(black) size(vlarge)) ///
		xtitle("Fathers' Residual Lifetime Income", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		legend(off) ylabel(0.9(0.1)1.55,labsize(vlarge)) xlabel(0.0(0.5)3,labsize(vlarge))
		sss
		graph export "${folderfile}/F1A_23age_LTinc_`mm'.pdf", replace 	
	}
	
	
	
	
	sss
*Figure 2: Income Transission Matrix
		insheet using "$maindir_fs${sep}out${sep}${mobidata_fs}${sep}T_LTincrankt_male.csv", clear
		
		foreach vv in ltinc_frankt ltincrankt{
				replace `vv' = 1 if `vv' == 2
				replace `vv' = 3 if `vv' == 4
				replace `vv' = 5 if `vv' == 6
				replace `vv' = 7 if `vv' == 8
				replace `vv' = 9 if `vv' == 10
		}	
		bys male ltinc_frankt: egen sume = sum (movecount)
		replace share = 100*movecount/sume
		drop sume 
		collapse (sum) movecount share, by(male ltinc_frankt ltincrankt)
		
		reshape wide movecount share, i(male ltinc_frankt) j(ltincrankt)
		order ltinc_frankt share* move*
		sort ltinc_frankt
		
		mkmat  share* if male == 1, matrix(xyzmat)		
		global colors = "maroon*0.1 maroon"
		heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
		xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", grid labsize(medsmall) ) ///
		ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
		graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentile in year t", color(black) size(medium))	 ///
		graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentiles of Fathers' Lifetime Income", color(black) size(large)) ///
		xtitle("Percentiles of Sons' Lifetime Income", color(black) size(large)) title("", color(black) size(medium))
		graph export "${folderfile}/fig11A_Tran_parents_male_exfor_SH.pdf", replace 	

		mkmat  share* if male == 0, matrix(xyzmat)	
		global colors = "dkgreen*0.1 dkgreen"
		heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
		xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", grid labsize(medsmall) ) ///
		ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
		graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentile in year t", color(black) size(medium))	 ///
		graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
			ytitle("Percentiles of Fathers' Lifetime Income", color(black) size(large)) ///
		xtitle("Percentiles of Daughters' Lifetime Income", color(black) size(large)) title("", color(black) size(medium))
		graph export "${folderfile}/fig11A_Tran_parents_women_exfor_SH.pdf", replace 	
	
	
	*Dec 16: Log earnings 
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	foreach gg in  1 5{
			foreach mm in   men women {					
			if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}out${sep}${bindatat_nw}${sep}Binscatters_men_FatherSon.csv", clear 
			}
			else {
					insheet using "$maindir_fs${sep}out${sep}${bindatat_nw}${sep}Binscatters_women_FatherSon.csv", clear 
			}	
				
				
*Figure 2: Fathers and Children Avergae Income Growth 
			 
			tw (scatter totlaborl totlaborl_f if totlaborl_f >= -0.1, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess totlaborl totlaborl_f if totlaborl_f >= -0.1, color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Children's Lifetime Income Growth", color(black) size(vlarge)) ///
			xtitle("Fathers' Lifetime Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(-0.1(0.05)0.1,labsize(large))		
			graph export "${folderfile}/F1A_totlaborl_`mm'_DEC16.pdf", replace 					
						
			global gvar = "log"
			tw (scatter mean${gvar}laborl`gg'_id mean${gvar}laborl`gg'_id_f if mean${gvar}laborl`gg'_id_f >= -0.1, msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess mean${gvar}laborl`gg'_id mean${gvar}laborl`gg'_id_f if mean${gvar}laborl`gg'_id_f >= -0.1, color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Mean of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("Mean of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(-0.1(0.05)0.1,labsize(large))		
			graph export "${folderfile}/F1A_MEAN${gvar}laborL`gg'_`mm'_DEC16.pdf", replace 	
			
*Figure 3: Fathers and Children Income Risk							
			*insheet using "$maindir_fs${sep}out${sep}${bindata}${sep}bs_`mm'_P9010loglaborL1_id.csv", clear 					
			tw (scatter p9010loglaborl`gg'_id p9010loglaborl`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess p9010loglaborl`gg'_id p9010loglaborl`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("P90-P10 of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("P90-P10 of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(0(1)4,labsize(large))		
			graph export "${folderfile}/F1A_P9010loglaborL`gg'_`mm'_DEC16.pdf", replace 					
			
			tw (scatter sdloglaborl`gg'_id sdloglaborl`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess sdloglaborl`gg'_id sdloglaborl`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Std. Deviation of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("Std. Deviation of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(,labsize(large))		
			graph export "${folderfile}/F1A_SDloglaborL`gg'_`mm'_DEC16.pdf", replace 					
		sss
*Figure 4: Fathers and Children Income Skewness	
			tw (scatter kskloglaborl`gg'_id kskloglaborl`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess kskloglaborl`gg'_id kskloglaborl`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kelley of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("Kelley of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(-0.6(0.2)0.8,labsize(large))					
			graph export "${folderfile}/F1A_KSKloglaborL`gg'_`mm'_DEC16.pdf", replace 					
			
			tw (scatter skewloglaborl`gg'_id skewloglaborl`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess skewloglaborl`gg'_id skewloglaborl`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Skewness of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("Skewness of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(-0.6(0.2)0.8,labsize(large))					
			graph export "${folderfile}/F1A_SKEWloglaborL`gg'_`mm'_DEC16.pdf", replace 					
				
*Figure NOT FOT PAPER: Fathers and Children kurtosis			
			*insheet using "$maindir_fs${sep}out${sep}${bindata}${sep}bs_`mm'_CKUloglaborL`gg'_id.csv", clear 									
			tw (scatter ckuloglaborl`gg'_id ckuloglaborl`gg'_id_f  , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess ckuloglaborl`gg'_id ckuloglaborl`gg'_id_f  , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kurtosis of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("Kurtosis of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(,labsize(large))											
			graph export "${folderfile}/F1A_CKUloglaborL`gg'_`mm'_DEC16.pdf", replace 			
			
			tw (scatter kurtloglaborl`gg'_id kurtloglaborl`gg'_id_f  , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess kurtloglaborl`gg'_id kurtloglaborl`gg'_id_f  , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kurtosis of Children' Income Growth", color(black) size(vlarge)) ///
			xtitle("Kurtosis of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,labsize(large)) xlabel(,labsize(large))											
			graph export "${folderfile}/F1A_KURTloglaborL`gg'_`mm'_DEC16.pdf", replace 			
			
			}		
		}
		
		
	*Permanent Eearnings (20 and 25 years) (THESE ARE THE OLD RESULTS, FOR FIRST DRAFT)
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"
	global gvar = "log"
	global vvar = "perminc"
	foreach smpl in  "23yrs" {			// "3yrs" for the baseline with three-years and 20 years of age
										// "25yrs" results with 25 years of age
										// "23yrs" results with 23 years of age
			foreach gg in 1 5{
			foreach mm in  women men  {	
			
			*Load data
			if "`smpl'" == "3yrs"{	
				if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}out${sep}${bindataperm}${sep}Binscatters_men_FatherSon.csv", clear 
				}
				else {
					insheet using "$maindir_fs${sep}out${sep}${bindataperm}${sep}Binscatters_women_FatherSon.csv", clear 
				}					
			}
			if "`smpl'" == "25yrs"{	
				if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}out${sep}${bindatamin25_norm}${sep}Binscatters_men_FatherSon.csv", clear 
				}
				else {
					insheet using "$maindir_fs${sep}out${sep}${bindatamin25_norm}${sep}Binscatters_women_FatherSon.csv", clear 
				}					
			}
			if "`smpl'" == "23yrs"{	
				if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}out${sep}${bindatamin23_norm}${sep}Binscatters_men_FatherSon.csv", clear 
				}
				else {
					insheet using "$maindir_fs${sep}out${sep}${bindatamin23_norm}${sep}Binscatters_women_FatherSon.csv", clear 
				}					
			}
			
			*Label
			if "`mm'" == "men"{
				local nlabel = "Sons"
			}
			if "`mm'" == "women"{
				local nlabel = "Daughters"
			}

			*Figure 2: Fathers and Children Avergae Income Growth 			 				
			local condi = "if mean${gvar}${vvar}l`gg'_id_f >= -0.1 & mean${gvar}${vvar}l`gg'_id_f <= 0.1"
			local xcondi = "-0.1(0.05)0.1"
			tw (scatter mean${gvar}${vvar}l`gg'_id mean${gvar}${vvar}l`gg'_id_f `condi', msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess mean${gvar}${vvar}l`gg'_id mean${gvar}${vvar}l`gg'_id_f `condi', color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Mean of `nlabel'' Income Growth", color(black) size(vlarge)) ///
			xtitle("Mean of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,angle(360) labsize(large)) xlabel(`xcondi',labsize(large))					
			graph export "${folderfile}/F1A_MEAN${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 	
			
			local condi = "if p50${gvar}${vvar}l`gg'_id_f >= -0.04 & p50${gvar}${vvar}l`gg'_id_f <= 0.1"
			local xcondi = "-0.05(0.05)0.1"
			tw (scatter p50${gvar}${vvar}l`gg'_id p50${gvar}${vvar}l`gg'_id_f `condi', msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess p50${gvar}${vvar}l`gg'_id p50${gvar}${vvar}l`gg'_id_f `condi', color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("P50 of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("P50 of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(0.025(0.005)0.05, angle(360)  labsize(large)) xlabel(`xcondi',labsize(large))								
			graph export "${folderfile}/F1A_P50${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 	
			

			*Figure 3: Fathers and Children Income Risk		
			local condi = "if p50${gvar}${vvar}l`gg'_id_f >= -0.05 & p50${gvar}${vvar}l`gg'_id_f <= 0.1"
			local xcondi = "-0.05(0.05)0.1"
			tw (scatter p9010${gvar}${vvar}l`gg'_id p9010${gvar}${vvar}l`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess p9010${gvar}${vvar}l`gg'_id p9010${gvar}${vvar}l`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("P90-P10 of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("P90-P10 of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(0.3(0.1)0.65, angle(360) labsize(large)) xlabel(,labsize(large))		
			graph export "${folderfile}/F1A_P9010${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 					
			
			
			tw (scatter sd${gvar}${vvar}l`gg'_id sd${gvar}${vvar}l`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess sd${gvar}${vvar}l`gg'_id sd${gvar}${vvar}l`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Std. Dev. of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Std. Dev. of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(, angle(360) labsize(large)) xlabel(,labsize(large))					
			graph export "${folderfile}/F1A_SD${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 					
			

			*Figure 4: Fathers and Children Income Skewness	
			local condi = "if ksk${gvar}${vvar}l`gg'_id_f >= -0.25 & ksk${gvar}${vvar}l`gg'_id_f <= 0.75"
			local xcondi = "-0.25(0.25)0.75"
			tw (scatter ksk${gvar}${vvar}l`gg'_id ksk${gvar}${vvar}l`gg'_id_f `condi', msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess ksk${gvar}${vvar}l`gg'_id ksk${gvar}${vvar}l`gg'_id_f `condi', color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kelley of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Kelley of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(0.1(0.05)0.325, angle(360) labsize(large)) xlabel(`xcondi',labsize(large))					
			graph export "${folderfile}/F1A_KSK${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 					

			tw (scatter skew${gvar}${vvar}l`gg'_id skew${gvar}${vvar}l`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess skew${gvar}${vvar}l`gg'_id skew${gvar}${vvar}l`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Skewness of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Skewness of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(, angle(360) labsize(large)) xlabel(,labsize(large))					
			graph export "${folderfile}/F1A_SKEW${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 					
			
			*Figure NOT FOT PAPER: Fathers and Children kurtosis			
			tw (scatter cku${gvar}${vvar}l`gg'_id cku${gvar}${vvar}l`gg'_id_f  , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess cku${gvar}${vvar}l`gg'_id cku${gvar}${vvar}l`gg'_id_f  , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kurtosis of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Kurtosis of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(, angle(360)  labsize(large)) xlabel(,labsize(large))											
			graph export "${folderfile}/F1A_CKU${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 			

			tw (scatter kurt${gvar}${vvar}l`gg'_id kurt${gvar}${vvar}l`gg'_id_f  , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess kurt${gvar}${vvar}l`gg'_id kurt${gvar}${vvar}l`gg'_id_f  , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kurtosis of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Kurtosis of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,angle(360)  labsize(large)) xlabel(,labsize(large))											
			graph export "${folderfile}/F1A_KURT${gvar}${vvar}L`gg'_`mm'_`smpl'.pdf", replace 			
			

			}		
			assdsd
			}
	}	
	
	// THESE ARE THE RESULTS DECEMBER 02, 2021
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"
	global gvar = "log"
	global vvar = "perminc"
	foreach smpl in  "23yrs" {			// "3yrs" for the baseline with three-years and 20 years of age
										// "25yrs" results with 25 years of age
										// "23yrs" results with 23 years of age
			foreach gg in 1 {			// 5
			foreach mm in  women men    {	
			
			*Load data
			if "`smpl'" == "3yrs"{	
				if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC2}${sep}Binscatters_men_FatherSon.csv", clear 
				}
				else {
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC2}${sep}Binscatters_women_FatherSon.csv", clear 
				}					
			}
			if "`smpl'" == "25yrs"{	
				if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC2}${sep}Binscatters_men_FatherSon.csv", clear 
				}
				else {
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC2}${sep}Binscatters_women_FatherSon.csv", clear 
				}					
			}
			if "`smpl'" == "23yrs"{	
				if "`mm'" == "men"{
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC2}${sep}Binscatters_men_FatherSon.csv", clear 
				}
				else {
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC2}${sep}Binscatters_women_FatherSon.csv", clear 
				}					
			}
			
			*Label
			if "`mm'" == "men"{
				local nlabel = "Sons"
			}
			if "`mm'" == "women"{
				local nlabel = "Daughters"
			}

			*Figure 2: Fathers and Children Avergae Income Growth 			 				
			local condi = "if mean${gvar}${vvar}l`gg'_id_f >= -0.1 & mean${gvar}${vvar}l`gg'_id_f <= 0.1"
			local xcondi = "-0.1(0.05)0.1"
			tw (scatter mean${gvar}${vvar}l`gg'_id mean${gvar}${vvar}l`gg'_id_f `condi', msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess mean${gvar}${vvar}l`gg'_id mean${gvar}${vvar}l`gg'_id_f `condi', color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Mean of `nlabel'' Income Growth", color(black) size(vlarge)) ///
			xtitle("Mean of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,angle(360) labsize(large)) xlabel(`xcondi',labsize(large))					
			graph export "${folderfile}/F1A_MEAN${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 	
			
			local condi = "if p50${gvar}${vvar}l`gg'_id_f >= -0.04 & p50${gvar}${vvar}l`gg'_id_f <= 0.1"
			local xcondi = "-0.05(0.05)0.1"
			tw (scatter p50${gvar}${vvar}l`gg'_id p50${gvar}${vvar}l`gg'_id_f `condi', msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess p50${gvar}${vvar}l`gg'_id p50${gvar}${vvar}l`gg'_id_f `condi', color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("P50 of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("P50 of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(0.025(0.005)0.042, angle(360)  labsize(large)) xlabel(`xcondi',labsize(large))								
			graph export "${folderfile}/F1A_P50${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 	
			

			*Figure 3: Fathers and Children Income Risk		
			local condi = "if p50${gvar}${vvar}l`gg'_id_f >= -0.05 & p50${gvar}${vvar}l`gg'_id_f <= 0.1"
			local xcondi = "-0.05(0.05)0.1"
			tw (scatter p9010${gvar}${vvar}l`gg'_id p9010${gvar}${vvar}l`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess p9010${gvar}${vvar}l`gg'_id p9010${gvar}${vvar}l`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("P90-P10 of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("P90-P10 of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(0.3(0.1)0.65, angle(360) labsize(large)) xlabel(,labsize(large))		
			graph export "${folderfile}/F1A_P9010${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 					
			
			
			tw (scatter sd${gvar}${vvar}l`gg'_id sd${gvar}${vvar}l`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess sd${gvar}${vvar}l`gg'_id sd${gvar}${vvar}l`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Std. Dev. of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Std. Dev. of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(, angle(360) labsize(large)) xlabel(,labsize(large))					
			graph export "${folderfile}/F1A_SD${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 					
			

			*Figure 4: Fathers and Children Income Skewness	
			local condi = "if ksk${gvar}${vvar}l`gg'_id_f >= -0.25 & ksk${gvar}${vvar}l`gg'_id_f <= 0.75"
			local xcondi = "-0.25(0.25)0.75"
			tw (scatter ksk${gvar}${vvar}l`gg'_id ksk${gvar}${vvar}l`gg'_id_f `condi', msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess ksk${gvar}${vvar}l`gg'_id ksk${gvar}${vvar}l`gg'_id_f `condi', color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kelley of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Kelley of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(0.12(0.04)0.26, angle(360) labsize(large)) xlabel(`xcondi',labsize(large))					
			graph export "${folderfile}/F1A_KSK${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 					
ddd
			tw (scatter skew${gvar}${vvar}l`gg'_id skew${gvar}${vvar}l`gg'_id_f , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess skew${gvar}${vvar}l`gg'_id skew${gvar}${vvar}l`gg'_id_f , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Skewness of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Skewness of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(, angle(360) labsize(large)) xlabel(,labsize(large))								
			graph export "${folderfile}/F1A_SKEW${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 					
			
			*Figure NOT FOT PAPER: Fathers and Children kurtosis			
			tw (scatter cku${gvar}${vvar}l`gg'_id cku${gvar}${vvar}l`gg'_id_f  , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess cku${gvar}${vvar}l`gg'_id cku${gvar}${vvar}l`gg'_id_f  , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kurtosis of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Kurtosis of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(, angle(360)  labsize(large)) xlabel(,labsize(large))											
			graph export "${folderfile}/F1A_CKU${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 			

			tw (scatter kurt${gvar}${vvar}l`gg'_id kurt${gvar}${vvar}l`gg'_id_f  , msize(large) msymbol(O) color(navy)  mfcolor(navy*.25))  ///
			(lowess kurt${gvar}${vvar}l`gg'_id kurt${gvar}${vvar}l`gg'_id_f  , color(maroon) lpattern(dash) lwidth(thick)) , ///
			graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
			ytitle("Kurtosis of `nlabel'' Income Growth", margin(r-2) color(black) size(vlarge)) ///
			xtitle("Kurtosis of Fathers' Income Growth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
			legend(off) ylabel(,angle(360)  labsize(large)) xlabel(,labsize(large))											
			graph export "${folderfile}/F1A_KURT${gvar}${vvar}L`gg'_`mm'_`smpl'_Dec02.pdf", replace 			
			

			}		
			
			}
	}
	

*Figure Transsion Matrix OLD for 20 years
		insheet using "$maindir_fs${sep}out${sep}${mobidata_fs}${sep}T_LTincrankt_male.csv", clear
		
		foreach vv in ltinc_frankt ltincrankt{
				replace `vv' = 1 if `vv' == 2
				replace `vv' = 3 if `vv' == 4
				replace `vv' = 5 if `vv' == 6
				replace `vv' = 7 if `vv' == 8
				replace `vv' = 9 if `vv' == 10
		}	
		bys male ltinc_frankt: egen sume = sum (movecount)
		replace share = 100*movecount/sume
		drop sume 
		collapse (sum) movecount share, by(male ltinc_frankt ltincrankt)
		
		reshape wide movecount share, i(male ltinc_frankt) j(ltincrankt)
		order ltinc_frankt share* move*
		sort ltinc_frankt
		
		mkmat  share* if male == 1, matrix(xyzmat)		
		global colors = "gray*0.1 gray"
		heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
		xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", alt grid labsize(medsmall) ) ///
		ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
		graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentile in year t", color(black) size(medium))	 ///
		graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentiles of Fathers' of LI{sub:i,c}", color(black) size(medium)) ///
		xtitle("Percentiles of Sons' of LI{sub:i,c}", color(black) size(medium)) title("", color(black) size(medium))
		graph export "${folderfile}/fig11A_Tran_FS_men.pdf", replace 	

		mkmat  share* if male == 0, matrix(xyzmat)	
		global colors = "gray*0.1 gray "
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
		xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", alt grid labsize(medsmall) ) ///
		ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
		graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentile in year t", color(black) size(medium))	 ///
		graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentiles of Fathers' of LI{sub:i,c}", color(black) size(medium)) ///
		xtitle("Percentiles of Daughters' of LI{sub:i,c}", color(black) size(medium)) title("", color(black) size(medium))
		graph export "${folderfile}/fig11A_Tran_FS_women.pdf", replace 	
		
		*Figure Transsion Matrix for 3 years and 25 age				
		foreach smpl in  "23yrs" { // "3yrs" for three years "25yrs" for indivdiauls with 25 yrs 
			foreach vari in LTinc LTwlt{
				
				if "`smpl'" == "3yrs"{
					insheet using "$maindir_fs${sep}out${sep}${bindata3yrsTRAN}${sep}R_3yrs_rank_varimale.csv", clear
				}
				if "`smpl'" == "25yrs"{
					insheet using "$maindir_fs${sep}out${sep}${bindatamin25}${sep}R_8yrs_rank_varimale.csv", clear
				}								
				if "`smpl'" == "23yrs"{
					insheet using "$maindir_fs${sep}out${sep}${bindatamin23_norm}${sep}R_10yrs_rank_varimale.csv", clear
				}
				keep if vari == "`vari'"
				
				if "`vari'" == "LTinc"{
					local nname = "LI{sub:i,c}"
				}		
				if "`vari'" == "LTwlt"{
					local nname = "W{sub:i,c}"
				}
				
				keep if frankt != .
				foreach vv in rank frankt{
						replace `vv' = 1 if `vv' == 2
						replace `vv' = 3 if `vv' == 4
						replace `vv' = 5 if `vv' == 6
						replace `vv' = 7 if `vv' == 8
						replace `vv' = 9 if `vv' == 10
				}	
				bys male frankt: egen sume = sum (movecount)
				replace share = 100*movecount/sume
				drop sume 
				collapse (sum) movecount share, by(male rank frankt)
				
				gen rshare = share
				replace rshare = rshare/20 if rank <= 7
				replace rshare = rshare/15 if rank ==9
				replace rshare = rshare/4 if rank ==11
				replace rshare = rshare/0.9 if rank ==12
				replace rshare = rshare/0.1 if rank ==13
				
				
				reshape wide movecount share rshare, i(male frankt) j(rank)
				order frankt share* move* rshare*
				sort male frankt
				
				*Levels 
				mkmat  share* if male == 1, matrix(xyzmat)		
				global colors = "navy*0.1 navy*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", alt grid labsize(medsmall) ) ///
				ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Sons' of `nname'", color(black) size(medium)) title("", color(black) size(medium))								
				graph export "${folderfile}/fig11A_Tran_`smpl'_FS_`vari'_men.pdf", replace
				
				*Ratio 
				mkmat  rshare* if male == 1, matrix(xyzmat)		
				global colors = "navy*0.1 navy*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", alt grid labsize(medsmall) ) ///
				ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Sons' of `nname'", color(black) size(medium)) title("", color(black) size(medium))								
				graph export "${folderfile}/fig11A_RAT_Tran_`smpl'_FS_`vari'_men.pdf", replace
				
				
				*Level 												
				mkmat  share* if male == 0, matrix(xyzmat)		
				global colors = "maroon*0.1 maroon*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", alt grid labsize(medsmall) ) ///
				ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Daughters' of `nname'", color(black) size(medium)) title("", color(black) size(medium))
				graph export "${folderfile}/fig11A_Tran_`smpl'_FS_`vari'_women.pdf", replace
				
				*Ratio
				mkmat  rshare* if male == 0, matrix(xyzmat)		
				global colors = "maroon*0.1 maroon*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1", alt grid labsize(medsmall) ) ///
				ylabel(1 "[0-20]" 2 "[21-40]" 3 "[41-60]" 4 "[61-80]" 5 "[81-95]" 6 "[96-99]" 7 "[99.1-99.9]" 8 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Daughters' of `nname'", color(black) size(medium)) title("", color(black) size(medium))
				graph export "${folderfile}/fig11A_RAT_Tran_`smpl'_FS_`vari'_women.pdf", replace
				sss
				
				
			}
		}
		
		****
		*Figure Transsion Matrix for 3 years and 25 age: AGGREGATED	(THESE ARE THE RESULTS IN THE OLD DRAFT)
		foreach smpl in  "23yrs" { // "3yrs" for three years "25yrs" for indivdiauls with 25 yrs 
			foreach vari in LTinc { // LTwlt
				
				if "`smpl'" == "3yrs"{
					insheet using "$maindir_fs${sep}out${sep}${bindata3yrsTRAN}${sep}R_3yrs_rank_varimale.csv", clear
				}
				if "`smpl'" == "25yrs"{
					insheet using "$maindir_fs${sep}out${sep}${bindatamin25}${sep}R_8yrs_rank_varimale.csv", clear
				}								
				if "`smpl'" == "23yrs"{
					insheet using "$maindir_fs${sep}out${sep}${bindatamin23_norm}${sep}R_10yrs_rank_varimale.csv", clear
				}
				keep if vari == "`vari'"
				
				if "`vari'" == "LTinc"{
					local nname = "LI{sub:i,c}"
				}		
				if "`vari'" == "LTwlt"{
					local nname = "W{sub:i,c}"
				}
				
				keep if frankt != .
				foreach vv in rank frankt{
						replace `vv' = 1 if `vv' <= 4				
						replace `vv' = 5 if `vv' >= 5 & `vv' <= 8						
						replace `vv' = 9 if `vv' == 10
				}	
				bys male frankt: egen sume = sum (movecount)
				replace share = 100*movecount/sume
				drop sume 
				collapse (sum) movecount share, by(male rank frankt)				
				
				gen rshare = share
				replace rshare = rshare/40 if rank <= 8
				replace rshare = rshare/15 if rank ==9
				replace rshare = rshare/4 if rank ==11
				replace rshare = rshare/0.9 if rank ==12
				replace rshare = rshare/0.1 if rank ==13
				
				
				reshape wide movecount share rshare, i(male frankt) j(rank)
				order frankt share* move* rshare*
				sort male frankt
						
				mkmat  share* if male == 1, matrix(xyzmat)		
				global colors = "navy*0.1 navy"
				global colors = "navy navy*0.1"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Sons' of `nname'", color(black) size(medium)) title("", color(black) size(medium))				
				graph export "${folderfile}/fig11A_COLL_Tran_`smpl'_FS_`vari'_men.pdf", replace		
				
				
				mkmat  rshare* if male == 1, matrix(xyzmat)		
				global colors = "navy*0.1 navy"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medium)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(large)) ///
				xtitle("Percentiles of Sons' of `nname'", color(black) size(large)) title("", color(black) size(medium))								
				graph export "${folderfile}/fig11A_RAT_COLL_Tran_`smpl'_FS_`vari'_men.pdf", replace
				
																
				mkmat  share* if male == 0, matrix(xyzmat)		
				global colors = "maroon*0.1 maroon"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Daughters' of `nname'", color(black) size(medium)) title("", color(black) size(medium))
				graph export "${folderfile}/fig11A_COLL_Tran_`smpl'_FS_`vari'_women.pdf", replace	
				
				mkmat  rshare* if male == 0, matrix(xyzmat)		
				global colors = "maroon*0.1 maroon"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medium)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(large)) ///
				xtitle("Percentiles of Daughters' of `nname'", color(black) size(large)) title("", color(black) size(medium))
				graph export "${folderfile}/fig11A_RAT_COLL_Tran_`smpl'_FS_`vari'_women.pdf", replace	
				
				
			}
		}
		
		
		
		****
		*Figure Transsion Matrix for 3 years and 25 age: AGGREGATED	
		*THESE ARE THE RESULTS IN THE NEW DRAFT
		foreach smpl in  "23yrs" { // "3yrs" for three years "25yrs" for indivdiauls with 25 yrs 
			foreach vari in LTinc   { // LTwlt
				
				if "`smpl'" == "3yrs"{
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC}${sep}R_3yrs_rank_varimale.csv", clear
				}
				if "`smpl'" == "25yrs"{
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC}${sep}R_8yrs_rank_varimale.csv", clear
				}								
				if "`smpl'" == "23yrs"{
					insheet using "$maindir_fs${sep}results${sep}${bindatamin23_normDEC}${sep}R_10yrs_rank_varimale.csv", clear
				}
				keep if vari == "`vari'"
				
				if "`vari'" == "LTinc"{
					local nname = "LI{sub:i,c}"
				}		
				if "`vari'" == "LTwlt"{
					local nname = "W{sub:i,c}"
				}
				
				keep if frankt != .
				foreach vv in rank frankt{
						replace `vv' = 1 if `vv' <= 4				
						replace `vv' = 5 if `vv' >= 5 & `vv' <= 8						
						replace `vv' = 9 if `vv' == 10
				}	
				bys male frankt: egen sume = sum (movecount)
				replace share = 100*movecount/sume
				drop sume 
				collapse (sum) movecount share, by(male rank frankt)				
				
				gen rshare = share
				replace rshare = rshare/40 if rank <= 8
				replace rshare = rshare/15 if rank ==9
				replace rshare = rshare/4 if rank ==11
				replace rshare = rshare/0.9 if rank ==12
				replace rshare = rshare/0.1 if rank ==13
				
				
				reshape wide movecount share rshare, i(male frankt) j(rank)
				order frankt share* move* rshare*
				sort male frankt
						
				mkmat  share* if male == 1, matrix(xyzmat)		
				global colors = "navy*0.1 navy*0.75"
// 				global colors = "navy navy*0.1"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Sons' of `nname'", color(black) size(medium)) title("", color(black) size(medium))								
				graph export "${folderfile}/fig11A_COLL_Tran_`smpl'_FS_`vari'_men_Dec2021.pdf", replace		
				
				
				mkmat  rshare* if male == 1, matrix(xyzmat)		
				global colors = "navy*0.1 navy*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medium)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(large)) ///
				xtitle("Percentiles of Sons' of `nname'", color(black) size(large)) title("", color(black) size(medium))								
				graph export "${folderfile}/fig11A_RAT_COLL_Tran_`smpl'_FS_`vari'_men_Dec2021.pdf", replace
				
																
				mkmat  share* if male == 0, matrix(xyzmat)		
				global colors = "maroon*0.1 maroon*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medsmall)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(medium)) ///
				xtitle("Percentiles of Daughters' of `nname'", color(black) size(medium)) title("", color(black) size(medium))
				graph export "${folderfile}/fig11A_COLL_Tran_`smpl'_FS_`vari'_women_Dec2021.pdf", replace	
				
				mkmat  rshare* if male == 0, matrix(xyzmat)		
				global colors = "maroon*0.1 maroon*0.75"
				heatplot xyzmat, values(format(%9.1f) mlabsize(medium)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
				xlabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1", grid labsize(medsmall) ) ///
				ylabel(1 "[0-40]" 2 "[41-80]" 3  "[81-95]" 4 "[96-99]" 5 "[99.1-99.9]" 6 "Top 0.1" , grid labsize(medsmall) ) ///
				graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentile in year t", color(black) size(medium))	 ///
				graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
				ytitle("Percentiles of Fathers' of `nname'", color(black) size(large)) ///
				xtitle("Percentiles of Daughters' of `nname'", color(black) size(large)) title("", color(black) size(medium))
				graph export "${folderfile}/fig11A_RAT_COLL_Tran_`smpl'_FS_`vari'_women_Dec2021.pdf", replace									
				ddd
				
			}
		}
		
		

		
		
		*Plotting the age distribution in different cells 
		insheet using "$maindir_fs${sep}out${sep}${bindata3yrsAGE}${sep}S_3yrs_yob_LTinc.csv", clear
		label var rank ""
		tw (connected p50yob rankt if frankt == 1) (connected p50yob rankt if frankt == 5) ///
			(connected p50yob rankt if frankt == 10) ///
				(connected p50yob rankt if frankt == 12) ///
					(connected p50yob rankt if frankt == 13), by(male) xlabel(1(1)13) legend(rows(1) ///
						order(1 "1st dlc" 2 "5 dlc" 3 "90/97th pct" 4 "99/99.9th pct" 5 "Top 0.1 pct")) ///
				xtitle("Children's Lifetime Income Rank'") ytitle("Average YOB")
				
				
		insheet using "$maindir_fs${sep}out${sep}${bindata3yrsAGE}${sep}S_3yrs_yob_LTwlt.csv", clear
		label var rank ""
		tw (connected p50yob rankt if frankt == 1) (connected p50yob rankt if frankt == 5) ///
			(connected p50yob rankt if frankt == 10) ///
				(connected p50yob rankt if frankt == 12) ///
					(connected p50yob rankt if frankt == 13), by(male) xlabel(1(1)13) legend(rows(1) ///
						order(1 "1st dlc" 2 "5 dlc" 3 "90/97th pct" 4 "99/99.9th pct" 5 "Top 0.1 pct")) ///
				xtitle("Children's Lifetime Wealth Rank'") ytitle("Average YOB")		
				
// 		tw (connected p50yob frankt if rankt == 1) (connected p50yob frankt if rankt == 5) ///
// 		(connected p50yob frankt if rankt == 10) ///
// 			(connected p50yob frankt if rankt == 13), by(male) xlabel(1(1)13) legend(rows(1) order(1 "1st dlc" 2 "5 dlc" 3 "90/97th pct" 4 "Top 0.1 pct")) ///
// 			xtitle("Fathers' Lifetime Income Rank'") ytitle("Average YOB")
			
			
			
			
		
*Figure Wealth vs. moments
	global vari = "researn1F"
	foreach sampl in men women{
		*Load data 
		
		if "`sampl'" == "all"{
			insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}L_${vari}_fsallrank.csv", clear case
			local tlabel = "All"
		}
		if "`sampl'" == "men"{
			insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}stats_LTwlt_f_${vari}_fsallrank_male.csv", clear case
			keep if male == 1
			local tlabel = "Men"
			local dlabel "Sons"
			local mclr = "maroon"
			local llabel = "off"
			local sdlim = "0.4(0.05)0.55"
		}
		if "`sampl'" == "women"{
			insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}stats_LTwlt_f_${vari}_fsallrank_male.csv", clear case
			keep if male == 0
			local tlabel = "Women"
			local dlabel "Daugthers"
			local mclr = "dkgreen"
			local llabel = "off"
			local sdlim = "0.4(0.05)0.55"
		}
		
		if "${vari}" == "researn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
			local labtitle = "g{sup:1}{sub:it}"			
		}		
		if "${vari}" == "researn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
			local labtitle = "g{sup:5}{sub:it}"			
		}
		if "${vari}" == "arcearn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
		}		
		if "${vari}" == "arcearn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
		}
		
		*Drop data before 1993
		drop if year < 1990 		
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
		
		*Averagegin statistics over time 
		*This can be changed to seperate recession to expansion periods
		collapse  p10${vari}  p50${vari}  p90${vari}  p9010${vari}  sd${vari} ksk${vari} skew${vari} ///
			cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank year)
		
		*Reshape to have a cleaner plot 
		reshape wide  p10${vari}  p50${vari}  p90${vari} p9010${vari}  sd${vari} ksk${vari} skew${vari} ///
			cku${vari} kurt${vari} , i(fpermrank) j(year)
		replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
		replace fpermrank = 2.5*fpermrank
		
		*Gen year averages
		egen p90${vari}all = rowmean(p90${vari}*)
		egen p50${vari}all = rowmean(p50${vari}*)
		egen p10${vari}all = rowmean(p10${vari}*)
		egen p9010${vari}all = rowmean(p9010${vari}*)
		egen sd${vari}all = rowmean(sd${vari}*)
		egen ksk${vari}all = rowmean(ksk${vari}*)
		egen skew${vari}all = rowmean(skew${vari}*)
		egen cku${vari}all = rowmean(cku${vari}*)
		egen kurt${vari}all = rowmean(kurt${vari}*)
		
		
		*Ploting: Dispersion		
// 		tw connected sd${vari}all sd${vari}1990 sd${vari}2000 sd${vari}2010 fpermrank, ///
		tw connected sd${vari}all fpermrank, ///
			msymbol(S x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Standard Deviation of `labtitle'", color(black) size(vlarge)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(vlarge)) title("", color(black) size(vlarge)) ///
		ylabel(`sdlim',labsize(vlarge)) xlabel( 0(10)100,labsize(vlarge)) ///
		legend(`llabel' size(vlarge) symxsize(7) order(1 "Average" 2 "1990" 3 "2000" 4 "2012") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_sd${vari}_FS_`sampl'_WL.pdf", replace
		
// 		tw connected p9010${vari}all p9010${vari}1990 p9010${vari}2000 p9010${vari}2010 fpermrank, ///
		tw connected p9010${vari}all fpermrank, ///
			msymbol(S x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("P90-P10 of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1990" 3 "2000" 4 "2012") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_p9010${vari}_FS_`sampl'_WL.pdf", replace
		
		*Ploting: Skewness		
// 		tw connected skew${vari}all skew${vari}1990 skew${vari}2000 skew${vari}2010 fpermrank, ///
		tw connected skew${vari}all  fpermrank, ///
			msymbol(S x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Skewness of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(-1.5(0.25)-0.5,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1990" 3 "2000" 4 "2012") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_skew${vari}_FS_`sampl'_WL.pdf", replace
		
// 		tw connected ksk${vari}all ksk${vari}1990 ksk${vari}2000 ksk${vari}2010 fpermrank, ///
		tw connected ksk${vari}all fpermrank, ///
			msymbol(S x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Kelley Skewness of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1990" 3 "2000" 4 "2012") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_ksk${vari}_FS_`sampl'_WL.pdf", replace
		
		*Ploting: Kurtosis		
// 		tw connected kurt${vari}all kurt${vari}1990 kurt${vari}2000 kurt${vari}2010 fpermrank, ///
		tw connected kurt${vari}all fpermrank, ///
			msymbol(S x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel( 12(4)24,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1990" 3 "2000" 4 "2012") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_kurt${vari}_FS_`sampl'_WL.pdf", replace
				
// 		tw connected cku${vari}all cku${vari}1990 cku${vari}2000 cku${vari}2010 fpermrank, ///
		tw connected cku${vari}all fpermrank, ///
			msymbol(S x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Crow-Siddiqui of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "1990" 3 "2000" 4 "2012") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_cku${vari}_FS_`sampl'_WL.pdf", replace
		
	}
	
		global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
		foreach spl in "23yrs"{		// "20yrs" for results with min age of 20			
			foreach base in LTinc LTwlt   {  //
			
				if "`base'" == "LTinc"{
					local labl0 = "Lifetime Income"
					local labl1 = "LI{sub:i,c}"					
				}
				if "`base'" == "LTwlt"{
					local labl0 = "Net Wealth"
					local labl1 = "W{sub:i,c}"					
				}			
			
			foreach vv in 1{ // 1 5
				* Two lines in the same plot
				global vari = "researn`vv'F"
			
				*Load data 
				if "`spl'" == "25yrs"{					
					insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs25yrs}${sep}stats_`base'_f_${vari}_fsallrank_male.csv", clear case
				}
				else if "`spl'" == "23yrs"{					
					insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs23yrs}${sep}stats_`base'_f_${vari}_fsallrank_male.csv", clear case
				}
				else{
					insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}stats_`base'_f_${vari}_fsallrank_male.csv", clear case
				}
						
				local tlabel = "Men"
				local dlabel "Sons"
				local mclr = "maroon"
						
				
				if "${vari}" == "researn1F"{
					local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
					local labtitle = "g{sup:I,1}{sub:i,t}"		
					local sdlim = "0.37(0.05)0.55"
				}		
				if "${vari}" == "researn5F"{
					local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
					local labtitle = "g{sup:I,5}{sub:i,t}"		
					local sdlim = ""
				}
				if "${vari}" == "arcearn1F"{
					local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
				}		
				if "${vari}" == "arcearn5F"{
					local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
				}
				
				*Drop data before 1993
				drop if year < 1990 		
				
				*Calculate additional moments 
				gen p9010${vari} = p90${vari} - p10${vari}
				gen p9050${vari} = p90${vari} - p50${vari}
				gen p5010${vari} = p50${vari} - p10${vari}
				
				gen p9550${vari} = p95${vari} - p50${vari}
				gen p5005${vari} = p50${vari} - p5${vari}		
				
				gen p9950${vari} = p99${vari} - p50${vari}
				gen p5001${vari} = p50${vari} - p1${vari}
							
				gen p7525${vari} = p75${vari} - p25${vari}
				gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
				
				gen kskp9901${vari} = (p9950${vari}- p5001${vari})/(p99${vari} - p1${vari})
				
				gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
				
				*Averagegin statistics over time 
				*This can be changed to seperate recession to expansion periods
				collapse  mean${vari}  p10${vari}  p50${vari}  p90${vari}  p9010${vari} p9050${vari} p5010${vari}  ///
					p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
					sd${vari} ksk${vari} kskp9901${vari} skew${vari} cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank male)
				
				*Reshape to have a cleaner plot 
				reshape wide mean${vari}  p10${vari}  p50${vari}  p90${vari} p9010${vari}  p9050${vari} p5010${vari}  ///
					p9550${vari} p5005${vari}  p9950${vari} p5001${vari} ///
					sd${vari} ksk${vari} kskp9901${vari} skew${vari} cku${vari} kurt${vari}  , i(fpermrank) j(male)
				*replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
				replace fpermrank = 2.5*fpermrank
				replace fpermrank = 101 if fpermrank == 102.5
				gen idex = _n 
				
				
				*P99-P50 
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
						if `vv' == 1{
							local y1 = 1.60
							local x1 = 87.7
							local y2 = 1.60
							local x2 =  99			
							local labtext = "1.60 87"
							local lsize = "1.2(0.2)2.0"
						}
						if `vv' == 5{
							local y1 = 0.97
							local x1 = 87.7
							local y2 = 0.97
							local x2 =  99			
							local labtext = "0.97 87"
							local lsize = ""
						}
					}
					if "`base'" == "LTwlt"{
						if `vv' == 1{
							local y1 = 1.60
							local x1 = 87.7
							local y2 = 1.60
							local x2 =  99			
							local labtext = "1.60 87"
							local lsize = "1.2(0.2)2.0"
						}
						if `vv' == 5{
							local y1 = 1.1
							local x1 = 87.7
							local y2 = 1.1
							local x2 =  99			
							local labtext = "1.1 87"
							local lsize = ""
						}
					}
					
				}
				else{
					if `vv' == 1{
						local y1 = 0.7
						local x1 = 87.7
						local y2 = 0.7
						local x2 =  99			
						local y3 = .072
						local labtext = "0.7 87"
						local lsize = "0.4(0.1)0.85"
					}
					if `vv' == 5{
						local y1 = 1.15
						local x1 = 87.7
						local y2 = 1.15
						local x2 =  99			
						local labtext = "1.15 87"
						local lsize = ""
					}	
				}
				
				tw (line p9950${vari}0  p9950${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   dash   dash   longdash   longdash )) ///
				(scatter p9950${vari}0  p9950${vari}1 fpermrank if idex==41, ///
				color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("P99-P50 of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(${legesize})) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(p9950, replace)				
				graph export "${folderfile}/F5B_p9950${vari}_`spl'_`base'_NLMW.pdf", replace
								
				dddd
				*P50-P01 
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
						if `vv' == 1{
							local y1 = 1.70
							local x1 = 87.7
							local y2 = 1.70
							local x2 =  99			
							local labtext = "1.70 87"
							local lsize = "1.2(0.2)2.0"
						}
						if `vv' == 5{
							local y1 = 0.97
							local x1 = 87.7
							local y2 = 0.97
							local x2 =  99			
							local labtext = "0.97 87"
							local lsize = ""
						}
					}
					if "`base'" == "LTwlt"{
						if `vv' == 1{
							local y1 = 1.80
							local x1 = 87.7
							local y2 = 1.80
							local x2 =  99			
							local labtext = "1.80 87"
							local lsize = "1.2(0.2)2.0"
						}
						if `vv' == 5{
							local y1 = 1.1
							local x1 = 87.7
							local y2 = 1.1
							local x2 =  99			
							local labtext = "1.1 87"
							local lsize = ""
						}
					}
					
				}
				else{
					if `vv' == 1{
						local y1 = 0.7
						local x1 = 87.7
						local y2 = 0.7
						local x2 =  99			
						local y3 = .072
						local labtext = "0.7 87"
						local lsize = "0.4(0.1)0.85"
					}
					if `vv' == 5{
						local y1 = 1.15
						local x1 = 87.7
						local y2 = 1.15
						local x2 =  99			
						local labtext = "1.15 87"
						local lsize = ""
					}	
				}
				
				tw (line p5001${vari}0  p5001${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   dash   dash   longdash   longdash )) ///
				(scatter p5001${vari}0  p5001${vari}1 fpermrank if idex==41, ///
				color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("P50-P1 of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(${legesize})) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(p5001, replace)				
				graph export "${folderfile}/F5B_p5001${vari}_`spl'_`base'_NLMW.pdf", replace
				stop 
				
				*Average	
				if "`base'" == "LTinc"{
					if `vv' == 1{
							local y1 = 0.02
							local x1 = 87.7
							local y2 = 0.02
							local x2 =  99			
							local y3 = .072
							local labtext = "0.02 87"
							local lsize = "-0.02(0.01)0.03"
					}
					if `vv' == 5{
							local y1 = 0.1
							local x1 = 87.7
							local y2 = 0.1
							local x2 =  99								
							local labtext = "0.1 87"
							local lsize = ""
					}
				}
				if "`base'" == "LTwlt"{
					if `vv' == 1{
							local y1 = 0.01
							local x1 = 87.7
							local y2 = 0.01
							local x2 =  99			
							local y3 = .072
							local labtext = "0.01 87"
							local lsize = "-0.02(0.01)0.03"
					}
					if `vv' == 5{
							local y1 = 0.05
							local x1 = 87.7
							local y2 = 0.05
							local x2 =  99								
							local labtext = "0.05 87"
							local lsize = ""
					}
				}
					
				sum mean${vari}0
				replace mean${vari}0 =mean${vari}0 - r(mean)
				
				sum mean${vari}1
				replace mean${vari}1 =mean${vari}1 - r(mean)
				
				tw (line mean${vari}0  mean${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash )) ///
				(scatter mean${vari}0 mean${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Average of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(${legesize})) title("", color(black) size(${legesize})) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) ///
					xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))					
				graph export "${folderfile}/F5B_mean${vari}_`spl'_`base'_NLMW.pdf", replace
								
				*Ploting: Median 
				if "`base'" == "LTinc"{
					if `vv' == 1{
							local y1 = 0.01
							local x1 = 87.7
							local y2 = 0.01
							local x2 =  99			
							local y3 = .072
							local labtext = "0.01 87"
							local lsize = "-0.01(0.01)0.02"
					}
					if `vv' == 5{
							local y1 = 0.1
							local x1 = 87.7
							local y2 = 0.1
							local x2 =  99								
							local labtext = "0.1 87"
							local lsize = ""
					}
				}
				if "`base'" == "LTwlt"{
					if `vv' == 1{
							local y1 = 0.005
							local x1 = 87.7
							local y2 = 0.005
							local x2 =  99			
							local y3 = .072
							local labtext = "0.005 87"
							local lsize = "-0.02(0.01)0.03"
					}
					if `vv' == 5{
							local y1 = 0.05
							local x1 = 87.7
							local y2 = 0.05
							local x2 =  99								
							local labtext = "0.05 87"
							local lsize = ""
					}
				}
					
				sum p50${vari}0
				replace p50${vari}0 =p50${vari}0 - r(mean)
				
				sum p50${vari}1
				replace p50${vari}1 =p50${vari}1 - r(mean)
				
				tw (line p50${vari}0  p50${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash )) ///
				(scatter p50${vari}0 p50${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(${marksize} ${marksize} medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Median of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(${legesize})) title("", color(black) size(${legesize})) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) ///
					xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none)))					
				graph export "${folderfile}/F5B_p50${vari}_`spl'_`base'_NLMW.pdf", replace
				
				*Ploting: Dispersion						
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
					if `vv' == 1{
						local y1 = 0.485
						local x1 = 87.7
						local y2 = 0.485
						local x2 =  99	
						local labtext = "0.485 87"
						local lsize = "0.35(0.05)0.5"
					}
					if `vv' == 5{
						local y1 = 0.75
						local x1 = 87.7
						local y2 = 0.75
						local x2 =  99								
						local labtext = "0.75 87"
						local lsize = ""
					}
					}
					
					if "`base'" == "LTwlt"{
					if `vv' == 1{
						local y1 = 0.51
						local x1 = 87.7
						local y2 = 0.51
						local x2 =  99	
						local labtext = "0.51 87"
						local lsize = "0.35(0.05)0.5"
					}
					if `vv' == 5{
						local y1 = 0.77
						local x1 = 87.7
						local y2 = 0.77
						local x2 =  99			
						local labtext = "0.77 87"
						local lsize = ""
					}
					}
					
					
				}
				else{
					if `vv' == 1{
						local y1 = 0.525
						local x1 = 87.7
						local y2 = 0.525
						local x2 =  99	
						local labtext = "0.525 87"
						local lsize = "0.4(0.05)0.55"
					}
					if `vv' == 5{
						local y1 = 0.8
						local x1 = 87.7
						local y2 = 0.81
						local x2 =  99			
						local y3 = .072
						local labtext = "0.8 87"
						local lsize = ""
					}
				}
								
				tw (line sd${vari}0  sd${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash )) ///
				(scatter sd${vari}0 sd${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Standard Deviation of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0',`labl1'", color(black) size(${legesize})) title("", color(black) size(${legesize})) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) ///
					xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) name(sd, replace)
				graph export "${folderfile}/F5B_sd${vari}_`spl'_`base'_NLMW.pdf", replace
					
					
				if "`base'" == "LTinc"{	
					local y1 = 0.72
					local x1 = 87.7
					local y2 = 0.72
					local x2 =  99			
					local labtext = "0.72 87"
				}
				if "`base'" == "LTwlt"{
					local y1 = 0.70
					local x1 = 87.7
					local y2 = 0.70
					local x2 =  99			
					local labtext = "0.70 87"
				}
				
				tw (line p9010${vari}0  p9010${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
				(scatter p9010${vari}0 p9010${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ) , ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("P90-P10 of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0',`labl1'", color(black) size(${legesize})) title("", color(black) size(${legesize})) ///
				ylabel(, angle(360) labsize(${legesize})) ///
					xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(p9010, replace)												
				graph export "${folderfile}/F5B_p9010${vari}_`spl'_`base'_NLMW.pdf", replace
									
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{											
				if `vv' == 1{
					local y1 = 0.75
					local x1 = 87.7
					local y2 = 0.75
					local x2 =  99			
					local y3 = .072
					local labtext = "0.75 87"
					local lsize = "0.4(0.1)0.75"
				}
				if `vv' == 5{
					local y1 = 1.47
					local x1 = 87.7
					local y2 = 1.47
					local x2 =  99			
					local y3 = .072
					local labtext = "1.47 87"
					local lsize = ""
				}																
				}
				else{
					if `vv' == 1{
					local y1 = 0.75
					local x1 = 87.7
					local y2 = 0.75
					local x2 =  99			
					local y3 = .072
					local labtext = "0.75 87"
					local lsize = "0.4(0.1)0.85"
					}
					if `vv' == 5{
						local y1 = 1.47
						local x1 = 87.7
						local y2 = 1.47
						local x2 =  99			
						local y3 = .072
						local labtext = "1.47 87"
						local lsize = ""
					}
				}
				tw (line p9550${vari}0  p9550${vari}1 p5005${vari}0  p5005${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
				color(red blue maroon navy) mfcolor( red*0.25 blue*0.25 maroon*0.25 navy*0.25) lwidth(medthick medthick medthick medthick ) ///
				lpattern(solid  dash   dash   dash   longdash   longdash )) ///
				(scatter p9550${vari}0  p9550${vari}1 p5005${vari}0  p5005${vari}1 fpermrank if idex==41, ///
				color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ) , ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("P95-P50 and P50-P5 of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0',`labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend( size(${legesize}) cols(1)  symxsize(7) order(1 "Women P95-P50" 2 "Men P95-P50" 3 "Women 50-P5" 4 "Men P50-P5") ring(0) position(11) region(color(none)))  ///
				name(p9550, replace)					
				graph export "${folderfile}/F5B_p905005${vari}_`spl'_`base'_NLMW.pdf", replace
					
				
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
						if `vv' == 1{
							local y1 = 0.60
							local x1 = 87.7
							local y2 = 0.60
							local x2 =  99			
							local labtext = "0.60 87"
							local lsize = "0.35(0.05)0.75"
						}
						if `vv' == 5{
							local y1 = 0.97
							local x1 = 87.7
							local y2 = 0.97
							local x2 =  99			
							local labtext = "0.97 87"
							local lsize = ""
						}
					}
					if "`base'" == "LTwlt"{
						if `vv' == 1{
							local y1 = 0.65
							local x1 = 87.7
							local y2 = 0.65
							local x2 =  99										
							local labtext = "0.65 87"
							local lsize = "0.35(0.05)0.75"
						}
						if `vv' == 5{
							local y1 = 1.1
							local x1 = 87.7
							local y2 = 1.1
							local x2 =  99			
							local labtext = "1.1 87"
							local lsize = ""
						}
					}
					
				}
				else{
					if `vv' == 1{
						local y1 = 0.7
						local x1 = 87.7
						local y2 = 0.7
						local x2 =  99			
						local y3 = .072
						local labtext = "0.7 87"
						local lsize = "0.4(0.1)0.85"
					}
					if `vv' == 5{
						local y1 = 1.15
						local x1 = 87.7
						local y2 = 1.15
						local x2 =  99			
						local labtext = "1.15 87"
						local lsize = ""
					}	
				}
				
				tw (line p5005${vari}0  p5005${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   dash   dash   longdash   longdash )) ///
				(scatter p5005${vari}0  p5005${vari}1 fpermrank if idex==41, ///
				color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("P50-P5 of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(${legesize})) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(p9550, replace)				
				graph export "${folderfile}/F5B_p5005${vari}_`spl'_`base'_NLMW.pdf", replace
				
				
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
						if `vv' == 1{
							local y1 = 0.75
							local x1 = 87.7
							local y2 = 0.75
							local x2 =  99			
							local labtext = "0.75 87"
							local lsize = "0.40(0.05)0.75"
						}
						if `vv' == 5{
							local y1 = 1.35
							local x1 = 87.7
							local y2 = 1.35
							local x2 =  99			
							local y3 = .072
							local labtext = "1.35 87"
							local lsize = ""	
						}
					}
					if "`base'" == "LTwlt"{
						if `vv' == 1{
							local y1 = 0.76
							local x1 = 87.7
							local y2 = 0.76
							local x2 =  99			
							local labtext = "0.76 87"
							local lsize = "0.40(0.05)0.75"
						}
						if `vv' == 5{
							local y1 = 1.35
							local x1 = 87.7
							local y2 = 1.35
							local x2 =  99			
							local y3 = .072
							local labtext = "1.35 87"
							local lsize = ""	
						}
					}
					
				}
				else{	
					if `vv' == 1{
						local y1 = 0.8
						local x1 = 87.7
						local y2 = 0.8
						local x2 =  99			
						local y3 = .072
						local labtext = "0.8 87"
						local lsize = "0.4(0.1)0.85"
					}
					if `vv' == 5{
						local y1 = 1.47
						local x1 = 87.7
						local y2 = 1.47
						local x2 =  99			
						local y3 = .072
						local labtext = "1.47 87"
						local lsize = ""	
					}
				}
				tw (line p9550${vari}0  p9550${vari}1 fpermrank if idex<=40, msymbol(O S D T )  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   dash   dash   longdash   longdash )) ///
				(scatter p9550${vari}0  p9550${vari}1 fpermrank if idex==41, ///
				color(red blue maroon navy) lpattern(dash dash dash) msymbol(O S D T ) mfcolor( red blue) msize(large large large large)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${legesize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("P95-P50 of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(p9550, replace)						
				graph export "${folderfile}/F5B_p9550${vari}_`spl'_`base'_NLMW.pdf", replace
								
				
				*Ploting: Skewness	
				
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
					if `vv' == 1{
						local y1 = -0.50
						local x1 = 87.75
						local y2 = -0.5
						local x2 =  99			
						local labtext = "-0.50 87"
						local lsize = "-1.5(0.25)-.5"
					}
					if `vv' == 5{
						local y1 = -0.4
						local x1 = 87.75
						local y2 = -0.4
						local x2 =  99			
						local labtext = "-0.4 87"
						local lsize = ""
					}	
					}
					
					if "`base'" == "LTwlt"{
					if `vv' == 1{
						local y1 = -1.0
						local x1 = 87.75
						local y2 = -0.75
						local x2 =  99			
						local labtext = "-1.0 87"
						local lsize = "-1.5(0.25)-.5"
					}
					if `vv' == 5{
						local y1 = -0.85
						local x1 = 87.75
						local y2 = -0.76
						local x2 =  99			
						local labtext = "-0.85 87"
						local lsize = ""
					}	
					}
					
				}
				else{
				if `vv' == 1{
					local y1 = -0.85
					local x1 = 87.75
					local y2 = -0.62
					local x2 =  99			
					local labtext = "-0.85 87"
				}
				if `vv' == 5{
					local y1 = -0.85
					local x1 = 87.75
					local y2 = -0.4
					local x2 =  99			
					local labtext = "-0.5 87"
				}
				}
				
				tw (line skew${vari}0  skew${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
				(scatter skew${vari}0 skew${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Skewness of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(${legesize})) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(skew, replace)													
				graph export "${folderfile}/F5B_skew${vari}_`spl'_`base'_NLMW.pdf", replace
				
				*Kelley skewness 9901
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
					if `vv' == 1{
							local y1 = -0.04
							local x1 = 87.75
							local y2 = -0.04
							local x2 =  99			
							local labtext = "-0.04 87"
					}
					if `vv' == 5{
						local y1 = 0.18
						local x1 = 87.75
						local y2 = 0.18
						local x2 =  99			
						local labtext = "0.18 87"
					}
					}
					
										
					if "`base'" == "LTwlt"{
					if `vv' == 1{
							local y1 = 0.1
							local x1 = 87.75
							local y2 = 0.1
							local x2 =  99			
							local labtext = "0.1 87"
					}
					if `vv' == 5{
						local y1 = 0.12
						local x1 = 87.75
						local y2 = 0.12
						local x2 =  99			
						local labtext = "0.12 87"
					}
					}
					
				}
				else{
					if `vv' == 1{
							local y1 = 0.08
							local x1 = 87.75
							local y2 = 0.09
							local x2 =  99			
							local labtext = "0.08 87"
					}
					if `vv' == 5{
						local y1 = 0.12
						local x1 = 87.75
						local y2 = 0.14
						local x2 =  99			
						local labtext = "0.12 87"
					}					
				}
				
				tw (line kskp9901${vari}0  kskp9901${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
				(scatter kskp9901${vari}0 kskp9901${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Kelley Skewness of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(, angle(360) labsize(${legesize})) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(ksk, replace)							
				graph export "${folderfile}/F5B_kskp9901${vari}_`spl'_`base'_NLMW.pdf", replace
sssss
				
				*Kelley skewness
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					
					if "`base'" == "LTinc"{
					if `vv' == 1{
							local y1 = 0.12
							local x1 = 87.75
							local y2 = 0.12
							local x2 =  99			
							local labtext = "0.12 87"
					}
					if `vv' == 5{
						local y1 = 0.18
						local x1 = 87.75
						local y2 = 0.18
						local x2 =  99			
						local labtext = "0.18 87"
					}
					}
					
										
					if "`base'" == "LTwlt"{
					if `vv' == 1{
							local y1 = 0.1
							local x1 = 87.75
							local y2 = 0.1
							local x2 =  99			
							local labtext = "0.1 87"
					}
					if `vv' == 5{
						local y1 = 0.12
						local x1 = 87.75
						local y2 = 0.12
						local x2 =  99			
						local labtext = "0.12 87"
					}
					}
					
				}
				else{
					if `vv' == 1{
							local y1 = 0.08
							local x1 = 87.75
							local y2 = 0.09
							local x2 =  99			
							local labtext = "0.08 87"
					}
					if `vv' == 5{
						local y1 = 0.12
						local x1 = 87.75
						local y2 = 0.14
						local x2 =  99			
						local labtext = "0.12 87"
					}					
				}
				
				tw (line ksk${vari}0  ksk${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
				(scatter ksk${vari}0 ksk${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Kelley Skewness of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(, angle(360) labsize(${legesize})) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(ksk, replace)					
				graph export "${folderfile}/F5B_ksk${vari}_`spl'_`base'_NLMW.pdf", replace
				
				
				
				
				*Ploting: Kurtosis					
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					if `vv' == 1{
						local y1 = 18.0
						local x1 = 87.75
						local y2 = 18.0
						local x2 =  99			
						local labtext = "18 87"
						local lsize = "12(4)32"
					}
					if `vv' == 5{
						local y1 = 10
						local x1 = 87.75
						local y2 = 10
						local x2 =  99			
						local labtext = "10 87"
						local lsize = ""
					}
				}								
				else{	
					if `vv' == 1{
						local y1 = 13.0
						local x1 = 87.75
						local y2 = 14.0
						local x2 =  99			
						local labtext = "13 87"
						local lsize = "12(2)24"
					}
					if `vv' == 5{
						local y1 = 10
						local x1 = 87.75
						local y2 = 10
						local x2 =  99			
						local labtext = "10 87"
						local lsize = ""
					}
				}
				
				tw (line kurt${vari}0  kurt${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
				(scatter kurt${vari}0 kurt${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Kurtosis of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(`lsize', angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(7) region(color(none))) ///
				name(kurt, replace)								
				graph export "${folderfile}/F5B_kurt${vari}_`spl'_`base'_NLMW.pdf", replace
				
				if "`spl'" == "25yrs" | "`spl'" == "23yrs"{		
					if `vv' == 1{
						local y1 = 10
						local x1 = 87.75
						local y2 = 10
						local x2 =  97			
						local labtext = "10 87"
					}
					if `vv' == 5{
						local y1 = 12.0
						local x1 = 87.75
						local y2 = 12.0
						local x2 =  97			
						local labtext = "12.0 87"
					}
				}
				else{
					if `vv' == 1{
						local y1 = 9.75
						local x1 = 87.75
						local y2 = 9.5
						local x2 =  97			
						local labtext = "9.75 87"
					}
					if `vv' == 5{
						local y1 = 12.0
						local x1 = 87.75
						local y2 = 12.0
						local x2 =  97			
						local labtext = "12.0 87"
					}
				}
				tw (line cku${vari}0  cku${vari}1 fpermrank if idex<=40, msymbol(O S  s + d t)  ///
				color( red blue red gray magenta) mfcolor( red*0.25 blue*0.25) lwidth(${linewidth} ${linewidth} ) msize(${marksize} ${marksize}) ///
				lpattern(solid  dash   longdash   longdash   longdash   longdash )) ///
				(scatter cku${vari}0 cku${vari}1 fpermrank if idex==41, ///
				color(red blue green) lpattern(dash dash dash) msymbol(O S O) mfcolor( red blue) msize(large large medlarge)) ///
				(pcarrowi `y1' `x1' `y2' `x2', msize(${marksize}) mlwidth(${linewidth}) mlcolor(black) lcolor(black) lwidth(${linewidth}) ), ///
				graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
				ytitle("Crow-Siddiqui Kurtosis of `labtitle'", color(black) size(${legesize})) ///
				xtitle("Quantiles of Fathers' `labl0', `labl1'", color(black) size(large)) title("", color(black) size(large)) ///
				ylabel(, angle(360) labsize(${legesize})) xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "99",labsize(${legesize})) ///
				text(`labtext' "Top 1% of `labl1'", place(w) size(large)) graphregion(margin(small) color(white)) plotregion(lcolor(black)) ///
				legend(size(${legesize}) cols(1) symxsize(7) order(1 "Daughters" 2 "Sons") ring(0) position(11) region(color(none))) ///
				name(kurt, replace)										
				graph export "${folderfile}/F5B_cku${vari}_`spl'_`base'_NLMW.pdf", replace	
				
			}	
			}	// END loop wealth or income
		}	// END sample loop
sss
	global vari = "researn5F"
	foreach sampl in men women{
		*Load data 
		
		if "`sampl'" == "all"{
			insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}L_${vari}_fsallrank.csv", clear case
			local tlabel = "All"
		}
		if "`sampl'" == "men"{
			insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}stats_LTwlt_f_${vari}_fsallrank_male_agegp.csv", clear case
			keep if male == 1
			local tlabel = "Men"
			local dlabel "Sons"
			local mclr = "navy"
			local llabel = ""
			local sdlim = ""
		}
		if "`sampl'" == "women"{
			insheet using "$maindir_fs${sep}out${sep}${wlthdata_fs}${sep}stats_LTwlt_f_${vari}_fsallrank_male_agegp.csv", clear case
			keep if male == 0
			local tlabel = "Women"
			local dlabel "Daugthers"
			local mclr = "navy"
			local llabel = "off"
			local sdlim = ""
		}
		
		if "${vari}" == "researn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
			local labtitle = "g{sup:1}{sub:it}"			
		}		
		if "${vari}" == "researn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
			local labtitle = "g{sup:5}{sub:it}"			
		}
		if "${vari}" == "arcearn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"			
		}		
		if "${vari}" == "arcearn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"			
		}
		
		*Drop data before 1993
		drop if year < 1990 		
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
		
		*Averagegin statistics over time 
		*This can be changed to seperate recession to expansion periods
		collapse  p10${vari}  p50${vari}  p90${vari}  p9010${vari}  sd${vari} ksk${vari} skew${vari} ///
			cku${vari} kurt${vari}  [w=N${vari}], by(fpermrank agegp)
		
		*Reshape to have a cleaner plot 
		reshape wide  p10${vari}  p50${vari}  p90${vari} p9010${vari}  sd${vari} ksk${vari} skew${vari} ///
			cku${vari} kurt${vari} , i(fpermrank) j(agegp)
		replace fpermrank = fpermrank - 1	// Just to have better plot starting from 0
		replace fpermrank = 2.5*fpermrank
		
		*Gen year averages
		egen p90${vari}all = rowmean(p90${vari}*)
		egen p50${vari}all = rowmean(p50${vari}*)
		egen p10${vari}all = rowmean(p10${vari}*)
		egen p9010${vari}all = rowmean(p9010${vari}*)
		egen sd${vari}all = rowmean(sd${vari}*)
		egen ksk${vari}all = rowmean(ksk${vari}*)
		egen skew${vari}all = rowmean(skew${vari}*)
		egen cku${vari}all = rowmean(cku${vari}*)
		egen kurt${vari}all = rowmean(kurt${vari}*)
		
		*Ploting: Dispersion		
		tw connected sd${vari}all  sd${vari}1  sd${vari}2  sd${vari}3 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Standard Deviation of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(`sdlim',labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "[25-34]" 3 "[35-44]" 4 "[45-55]") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_sd${vari}_FS_`sampl'_WLA.pdf", replace
		
		tw connected p9010${vari}all p9010${vari}1 p9010${vari}2 p9010${vari}3 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("P90-P10 of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "[25-34]" 3 "[35-44]" 4 "[45-55]") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_p9010${vari}_FS_`sampl'_WLA.pdf", replace
		
		*Ploting: Skewness		
		tw connected skew${vari}all  skew${vari}1  skew${vari}2  skew${vari}3  fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Skewness of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(-2(0.5)0.5,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "[25-34]" 3 "[35-44]" 4 "[45-55]") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_skew${vari}_FS_`sampl'_WLA.pdf", replace
		
		tw connected ksk${vari}all ksk${vari}1 ksk${vari}2 ksk${vari}3 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Kelley Skewness of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "[25-34]" 3 "[35-44]" 4 "[45-55]") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_ksk${vari}_FS_`sampl'_WLA.pdf", replace
		
		*Ploting: Kurtosis		
		tw connected kurt${vari}all kurt${vari}1 kurt${vari}2 kurt${vari}3 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Kurtosis of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel( 4(4)20,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "[25-34]" 3 "[35-44]" 4 "[45-55]") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_kurt${vari}_FS_`sampl'_WLA.pdf", replace
				
		tw connected cku${vari}all cku${vari}1 cku${vari}2 cku${vari}3 fpermrank, ///
			msymbol(O x s + d t) msize(medlarge) ///
			color(`mclr' blue green red gray magenta) mfcolor(`mclr'*0.25 ) lwidth(thick ) ///
			lpattern(solid  longdash   longdash   longdash   longdash   longdash ) ///
		graphregion(color(white) margin(small)) plotregion(lcolor(black)) xlabel(,grid) ///
		ytitle("Crow-Siddiqui of `labtitle'", color(black) size(large)) ///
		xtitle("Quantiles of Fathers' Net Wealth", color(black) size(large)) title("", color(black) size(large)) ///
		ylabel(,labsize(large)) xlabel( 0(10)100,labsize(large)) ///
		legend(`llabel' size(large) symxsize(7) order(1 "Average" 2 "[25-34]" 3 "[35-44]" 4 "[45-55]") ring(0) position(11) region(color(none)))
		graph export "${folderfile}/F5B_cku${vari}_FS_`sampl'_WLA.pdf", replace
		
	}

*** New Transission Matrices
	*Tranission Matrix (there is not much more info in the tran matrix, the rank-rank are enough)
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	
	insheet using "$maindir_fs${sep}out${sep}${bindatat_nw}${sep}Tran_mat_male_FatherSon.csv", clear 			
	keep if vari == "LTinc"
	
// 	foreach oo in frankt rank{
// 		replace `oo' = 1 if `oo' == 2
// 		replace `oo' = 3 if `oo' == 4
// 		replace `oo' = 5 if `oo' == 6
// 		replace `oo' = 7 if `oo' == 8
// 		replace `oo' = 9 if `oo' == 10
// 	}
// 	collapse (sum) movecount, by(frankt rank male)
	
// 	bys male frank: egen sume = sum(movecount)
// 	gen share = 100*movecount/sume
// 	drop sume 
		
	reshape wide movecount share, i(male frankt) j(rank)
	order frankt share* move*
	sort frankt

	mkmat  share* if male == 1, matrix(xyzmat)		
	global colors = "maroon*0.1 maroon"
	heatplot xyzmat, values(format(%9.1f) mlabsize(small)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
	xlabel(1 "[0-10]" 2 "[11-20]" 3 "[21-30]" 4 "[31-40]" 5 "[41-50]" 6 "[51-60]" 7 "[61-70]" 8 "[71-80]" 9 "[81-90]" 10 "[91-100]", alt grid labsize(medsmall) ) ///
	ylabel(1 "[0-10]" 2 "[11-20]" 3 "[21-30]" 4 "[31-40]" 5 "[41-50]" 6 "[51-60]" 7 "[61-70]" 8 "[71-80]" 9 "[81-90]" 10 "[91-100]" , grid labsize(medsmall) ) ///
	graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
	ytitle("Percentile in year t", color(black) size(medium))	 ///
	graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentiles of Fathers' Lifetime Income", color(black) size(medium)) ///
	xtitle("Percentiles of Sons' Lifetime Income", color(black) size(medium)) title("", color(black) size(medium))
	graph export "${folderfile}/TMat_LTInc_men.pdf", replace
	
	mkmat  share* if male == 0, matrix(xyzmat)		
	global colors = "dkgreen*0.1 dkgreen"
	heatplot xyzmat, values(format(%9.1f) mlabsize(small)) legend(off) colors(${colors}, n(20) ipolate(20)) xscale(alt) ///
	xlabel(1 "[0-10]" 2 "[11-20]" 3 "[21-30]" 4 "[31-40]" 5 "[41-50]" 6 "[51-60]" 7 "[61-70]" 8 "[71-80]" 9 "[81-90]" 10 "[91-100]", alt grid labsize(medsmall) ) ///
	ylabel(1 "[0-10]" 2 "[11-20]" 3 "[21-30]" 4 "[31-40]" 5 "[41-50]" 6 "[51-60]" 7 "[61-70]" 8 "[71-80]" 9 "[81-90]" 10 "[91-100]" , grid labsize(medsmall) ) ///
	graphregion(color(white)  margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
	ytitle("Percentile in year t", color(black) size(medium))	 ///
	graphregion(color(white) margin(tiny)) plotregion(lcolor(black) margin(tiny)) ///
		ytitle("Percentiles of Fathers' Lifetime Income", color(black) size(medium)) ///
	xtitle("Percentiles of Daughters' Lifetime Income", color(black) size(medium)) title("", color(black) size(medium))
	graph export "${folderfile}/TMat_LTInc_women.pdf", replace
	
*END OF THE CODE
